@@ -15,7 +15,7 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
- 
+
 #include "../dsputil.h"
 #include "../mpegvideo.h"
 #include <time.h>
@@ -23,11 +23,10 @@
 #ifdef HAVE_ALTIVEC
 #include "dsputil_altivec.h"
 #endif
-#if 0 //MEANX
-extern int dct_quantize_altivec(MpegEncContext *s,  
+
+extern int dct_quantize_altivec(MpegEncContext *s,
         DCTELEM *block, int n,
         int qscale, int *overflow);
-#endif
 extern void dct_unquantize_h263_altivec(MpegEncContext *s,
                                         DCTELEM *block, int n, int qscale);
 
@@ -40,6 +39,8 @@ void MPV_common_init_ppc(MpegEncContext *s)
 #ifdef HAVE_ALTIVEC
     if (has_altivec())
     {
+      if (s->avctx->lowres==0)
+      {
         if ((s->avctx->idct_algo == FF_IDCT_AUTO) ||
                 (s->avctx->idct_algo == FF_IDCT_ALTIVEC))
         {
@@ -51,6 +52,7 @@ void MPV_common_init_ppc(MpegEncContext *s)
             s->dsp.idct_permutation_type = FF_NO_IDCT_PERM;
 #endif /* ALTIVEC_USE_REFERENCE_C_CODE */
         }
+      }
 
         // Test to make sure that the dct required alignments are met.
         if ((((long)(s->q_intra_matrix) & 0x0f) != 0) ||
