@@ -21,7 +21,7 @@
 /**
  * @file ratecontrol.c
  * Rate control for video encoders.
- */ 
+ */
 
 #include "avcodec.h"
 #include "dsputil.h"
@@ -38,9 +38,9 @@ static int init_pass2(MpegEncContext *s);
 static double get_qscale(MpegEncContext *s, RateControlEntry *rce, double rate_factor, int frame_num);
 
 void ff_write_pass1_stats(MpegEncContext *s){
-    snprintf(s->avctx->stats_out,256, "in:%d out:%d type:%d q:%d itex:%d ptex:%d mv:%d misc:%d fcode:%d bcode:%d mc-var:%d var:%d icount:%d;\n",
-            s->current_picture_ptr->display_picture_number, s->current_picture_ptr->coded_picture_number, s->pict_type, 
-            s->current_picture.quality, s->i_tex_bits, s->p_tex_bits, s->mv_bits, s->misc_bits, 
+    snprintf(s->avctx->stats_out, 256, "in:%d out:%d type:%d q:%d itex:%d ptex:%d mv:%d misc:%d fcode:%d bcode:%d mc-var:%d var:%d icount:%d;\n",
+            s->current_picture_ptr->display_picture_number, s->current_picture_ptr->coded_picture_number, s->pict_type,
+            s->current_picture.quality, s->i_tex_bits, s->p_tex_bits, s->mv_bits, s->misc_bits,
             s->f_code, s->b_code, s->current_picture.mc_mb_var_sum, s->current_picture.mb_var_sum, s->i_count);
 }
 
@@ -53,7 +53,7 @@ int ff_rate_control_init(MpegEncContext *s)
     for(i=0; i<5; i++){
         rcc->pred[i].coeff= FF_QP2LAMBDA * 7.0;
         rcc->pred[i].count= 1.0;
-    
+
         rcc->pred[i].decay= 0.4;
         rcc->i_cplx_sum [i]=
         rcc->p_cplx_sum [i]=
@@ -74,18 +74,20 @@ int ff_rate_control_init(MpegEncContext *s)
             p= strchr(p+1, ';');
         }
         i+= s->max_b_frames;
+        if(i<=0 || i>=INT_MAX / sizeof(RateControlEntry))
+            return -1;
         rcc->entry = (RateControlEntry*)av_mallocz(i*sizeof(RateControlEntry));
         rcc->num_entries= i;
-        
-        /* init all to skiped p frames (with b frames we might have a not encoded frame at the end FIXME) */
+
+        /* init all to skipped p frames (with b frames we might have a not encoded frame at the end FIXME) */
         for(i=0; i<rcc->num_entries; i++){
             RateControlEntry *rce= &rcc->entry[i];
             rce->pict_type= rce->new_pict_type=P_TYPE;
             rce->qscale= rce->new_qscale=FF_QP2LAMBDA * 2;
             rce->misc_bits= s->mb_num + 10;
             rce->mb_var_sum= s->mb_num*100;
-        }        
-        
+        }
+
         /* read stats */
         p= s->avctx->stats_in;
         for(i=0; i<rcc->num_entries - s->max_b_frames; i++){
@@ -106,7 +108,7 @@ int ff_rate_control_init(MpegEncContext *s)
             rce= &rcc->entry[picture_number];
 
             e+=sscanf(p, " in:%*d out:%*d type:%d q:%f itex:%d ptex:%d mv:%d misc:%d fcode:%d bcode:%d mc-var:%d var:%d icount:%d",
-                   &rce->pict_type, &rce->qscale, &rce->i_tex_bits, &rce->p_tex_bits, &rce->mv_bits, &rce->misc_bits, 
+                   &rce->pict_type, &rce->qscale, &rce->i_tex_bits, &rce->p_tex_bits, &rce->mv_bits, &rce->misc_bits,
                    &rce->f_code, &rce->b_code, &rce->mc_mb_var_sum, &rce->mb_var_sum, &rce->i_count);
             if(e!=12){
                 av_log(s->avctx, AV_LOG_ERROR, "statistics are damaged at line %d, parser out=%d\n", i, e);
@@ -114,25 +116,25 @@ int ff_rate_control_init(MpegEncContext *s)
             }
             p= next;
         }
-        
+
         if(init_pass2(s) < 0) return -1;
     }
-     
+
     if(!(s->flags&CODEC_FLAG_PASS2)){
 
         rcc->short_term_qsum=0.001;
         rcc->short_term_qcount=0.001;
-    
+
         rcc->pass1_rc_eq_output_sum= 0.001;
         rcc->pass1_wanted_bits=0.001;
-        
+
         /* init stuff with the user specified complexity */
         if(s->avctx->rc_initial_cplx){
             for(i=0; i<60*30; i++){
                 double bits= s->avctx->rc_initial_cplx * (i/10000.0 + 1.0)*s->mb_num;
                 RateControlEntry rce;
                 double q;
-                
+
                 if     (i%((s->gop_size+3)/4)==0) rce.pict_type= I_TYPE;
                 else if(i%(s->max_b_frames+1))    rce.pict_type= B_TYPE;
                 else                              rce.pict_type= P_TYPE;
@@ -164,12 +166,12 @@ int ff_rate_control_init(MpegEncContext *s)
                 bits= rce.i_tex_bits + rce.p_tex_bits;
 
                 q= get_qscale(s, &rce, rcc->pass1_wanted_bits/rcc->pass1_rc_eq_output_sum, i);
-                rcc->pass1_wanted_bits+= s->bit_rate/(s->avctx->frame_rate / (double)s->avctx->frame_rate_base);
+                rcc->pass1_wanted_bits+= s->bit_rate/(1/av_q2d(s->avctx->time_base)); //FIXME missbehaves a little for variable fps
             }
         }
 
     }
-    
+
     return 0;
 }
 
@@ -194,14 +196,14 @@ static inline double bits2qp(RateControlEntry *rce, double bits){
     }
     return rce->qscale * (double)(rce->i_tex_bits + rce->p_tex_bits+1)/ bits;
 }
-    
+
 int ff_vbv_update(MpegEncContext *s, int frame_size){
     RateControlContext *rcc= &s->rc_context;
-    const double fps= (double)s->avctx->frame_rate / (double)s->avctx->frame_rate_base;
+    const double fps= 1/av_q2d(s->avctx->time_base);
     const int buffer_size= s->avctx->rc_buffer_size;
     const double min_rate= s->avctx->rc_min_rate/fps;
     const double max_rate= s->avctx->rc_max_rate/fps;
-    
+
 //printf("%d %f %d %f %f\n", buffer_size, rcc->buffer_index, frame_size, min_rate, max_rate);
     if(buffer_size){
         int left;
@@ -217,11 +219,11 @@ int ff_vbv_update(MpegEncContext *s, int frame_size){
 
         if(rcc->buffer_index > buffer_size){
             int stuffing= ceil((rcc->buffer_index - buffer_size)/8);
-            
+
             if(stuffing < 4 && s->codec_id == CODEC_ID_MPEG4)
                 stuffing=4;
             rcc->buffer_index -= 8*stuffing;
-            
+
             if(s->avctx->debug & FF_DEBUG_RC)
                 av_log(s->avctx, AV_LOG_DEBUG, "stuffing %d bytes\n", stuffing);
 
@@ -239,7 +241,7 @@ static double get_qscale(MpegEncContext *s, RateControlEntry *rce, double rate_f
     AVCodecContext *a= s->avctx;
     double q, bits;
     const int pict_type= rce->new_pict_type;
-    const double mb_num= s->mb_num;  
+    const double mb_num= s->mb_num;
     int i;
 
     double const_values[]={
@@ -308,32 +310,32 @@ static double get_qscale(MpegEncContext *s, RateControlEntry *rce, double rate_f
     };
 
     bits= ff_eval(s->avctx->rc_eq, const_values, const_names, func1, func1_names, NULL, NULL, rce);
-    
+
     rcc->pass1_rc_eq_output_sum+= bits;
     bits*=rate_factor;
     if(bits<0.0) bits=0.0;
     bits+= 1.0; //avoid 1/0 issues
-    
+
     /* user override */
     for(i=0; i<s->avctx->rc_override_count; i++){
         RcOverride *rco= s->avctx->rc_override;
         if(rco[i].start_frame > frame_num) continue;
         if(rco[i].end_frame   < frame_num) continue;
-    
-        if(rco[i].qscale) 
+
+        if(rco[i].qscale)
             bits= qp2bits(rce, rco[i].qscale); //FIXME move at end to really force it?
         else
             bits*= rco[i].quality_factor;
     }
 
     q= bits2qp(rce, bits);
-    
+
     /* I/B difference */
     if     (pict_type==I_TYPE && s->avctx->i_quant_factor<0.0)
         q= -q*s->avctx->i_quant_factor + s->avctx->i_quant_offset;
     else if(pict_type==B_TYPE && s->avctx->b_quant_factor<0.0)
         q= -q*s->avctx->b_quant_factor + s->avctx->b_quant_offset;
-        
+
     return q;
 }
 
@@ -343,7 +345,7 @@ static double get_diff_limited_q(MpegEncContext *s, RateControlEntry *rce, doubl
     const int pict_type= rce->new_pict_type;
     const double last_p_q    = rcc->last_qscale_for[P_TYPE];
     const double last_non_b_q= rcc->last_qscale_for[rcc->last_non_b_pict_type];
-    
+
     if     (pict_type==I_TYPE && (a->i_quant_factor>0.0 || rcc->last_non_b_pict_type==P_TYPE))
         q= last_p_q    *ABS(a->i_quant_factor) + a->i_quant_offset;
     else if(pict_type==B_TYPE && a->b_quant_factor>0.0)
@@ -359,7 +361,7 @@ static double get_diff_limited_q(MpegEncContext *s, RateControlEntry *rce, doubl
     }
 
     rcc->last_qscale_for[pict_type]= q; //Note we cant do that after blurring
-    
+
     if(pict_type!=B_TYPE)
         rcc->last_non_b_pict_type= pict_type;
 
@@ -370,9 +372,9 @@ static double get_diff_limited_q(MpegEncContext *s, RateControlEntry *rce, doubl
  * gets the qmin & qmax for pict_type
  */
 static void get_qminmax(int *qmin_ret, int *qmax_ret, MpegEncContext *s, int pict_type){
-    int qmin= s->avctx->lmin;                                                       
+    int qmin= s->avctx->lmin;
     int qmax= s->avctx->lmax;
-    
+
     assert(qmin <= qmax);
 
     if(pict_type==B_TYPE){
@@ -387,22 +389,34 @@ static void get_qminmax(int *qmin_ret, int *qmax_ret, MpegEncContext *s, int pic
     qmax= clip(qmax, 1, FF_LAMBDA_MAX);
 
     if(qmax<qmin) qmax= qmin;
-    
+
     *qmin_ret= qmin;
     *qmax_ret= qmax;
 }
-// MEANX
-double bitrate_constraint(MpegEncContext *s, RateControlEntry *rce, double q, int frame_num)
-{
-  const double buffer_size= s->avctx->rc_buffer_size;
-  const double fps= (double)s->avctx->frame_rate / (double)s->avctx->frame_rate_base;
-  const double min_rate= s->avctx->rc_min_rate / fps;
-  const double max_rate= s->avctx->rc_max_rate / fps;    
-  
-  double q_limit;
-  RateControlContext *rcc= &s->rc_context;
-  double expected_size= rcc->buffer_index;
-  
+
+static double modify_qscale(MpegEncContext *s, RateControlEntry *rce, double q, int frame_num){
+    RateControlContext *rcc= &s->rc_context;
+    int qmin, qmax;
+    double bits;
+    const int pict_type= rce->new_pict_type;
+    const double buffer_size= s->avctx->rc_buffer_size;
+    const double fps= 1/av_q2d(s->avctx->time_base);
+    const double min_rate= s->avctx->rc_min_rate / fps;
+    const double max_rate= s->avctx->rc_max_rate / fps;
+
+    get_qminmax(&qmin, &qmax, s, pict_type);
+
+    /* modulation */
+    if(s->avctx->rc_qmod_freq && frame_num%s->avctx->rc_qmod_freq==0 && pict_type==P_TYPE)
+        q*= s->avctx->rc_qmod_amp;
+
+    bits= qp2bits(rce, q);
+//printf("q:%f\n", q);
+    /* buffer overflow/underflow protection */
+    if(buffer_size){
+        double expected_size= rcc->buffer_index;
+        double q_limit;
+
         if(min_rate){
             double d= 2*(buffer_size - expected_size)/buffer_size;
             if(d>1.0) d=1.0;
@@ -432,32 +446,6 @@ double bitrate_constraint(MpegEncContext *s, RateControlEntry *rce, double q, in
                 q= q_limit;
             }
         }
-	return q;
-
-}
-// /MEANX
-
-static double modify_qscale(MpegEncContext *s, RateControlEntry *rce, double q, int frame_num){
-    RateControlContext *rcc= &s->rc_context;
-    int qmin, qmax;
-    double bits;
-    const int pict_type= rce->new_pict_type;
-    const double buffer_size= s->avctx->rc_buffer_size;
-    const double fps= (double)s->avctx->frame_rate / (double)s->avctx->frame_rate_base;
-    const double min_rate= s->avctx->rc_min_rate / fps;
-    const double max_rate= s->avctx->rc_max_rate / fps;
-    
-    get_qminmax(&qmin, &qmax, s, pict_type);
-
-    /* modulation */
-    if(s->avctx->rc_qmod_freq && frame_num%s->avctx->rc_qmod_freq==0 && pict_type==P_TYPE)
-        q*= s->avctx->rc_qmod_amp;
-
-    bits= qp2bits(rce, q);
-//printf("q:%f\n", q);
-    /* buffer overflow/underflow protection */
-    if(buffer_size && !( s->flags&CODEC_FLAG_PASS1)){ //MEANX: Dont do min/max in pass1
-      q=bitrate_constraint(s, rce, q, frame_num);
     }
 //printf("q:%f max:%f min:%f size:%f index:%d bits:%f agr:%f\n", q,max_rate, min_rate, buffer_size, rcc->buffer_index, bits, s->avctx->rc_buffer_aggressivity);
     if(s->avctx->rc_qsquish==0.0 || qmin==qmax){
@@ -466,16 +454,16 @@ static double modify_qscale(MpegEncContext *s, RateControlEntry *rce, double q,
     }else{
         double min2= log(qmin);
         double max2= log(qmax);
-        
+
         q= log(q);
         q= (q - min2)/(max2-min2) - 0.5;
         q*= -4.0;
         q= 1.0/(1.0 + exp(q));
         q= q*(max2-min2) + min2;
-        
+
         q= exp(q);
     }
-    
+
     return q;
 }
 
@@ -513,28 +501,35 @@ static void adaptive_quantization(MpegEncContext *s, double q){
     const float temp_cplx_masking= s->avctx->temporal_cplx_masking;
     const float spatial_cplx_masking = s->avctx->spatial_cplx_masking;
     const float p_masking = s->avctx->p_masking;
+    const float border_masking = s->avctx->border_masking;
     float bits_sum= 0.0;
     float cplx_sum= 0.0;
     float cplx_tab[s->mb_num];
     float bits_tab[s->mb_num];
-    const int qmin= s->avctx->lmin;
-    const int qmax= s->avctx->lmax;
+    const int qmin= s->avctx->mb_lmin;
+    const int qmax= s->avctx->mb_lmax;
     Picture * const pic= &s->current_picture;
-    
+    const int mb_width = s->mb_width;
+    const int mb_height = s->mb_height;
+
     for(i=0; i<s->mb_num; i++){
         const int mb_xy= s->mb_index2xy[i];
         float temp_cplx= sqrt(pic->mc_mb_var[mb_xy]); //FIXME merge in pow()
         float spat_cplx= sqrt(pic->mb_var[mb_xy]);
         const int lumi= pic->mb_mean[mb_xy];
         float bits, cplx, factor;
-#if 0        
+        int mb_x = mb_xy % s->mb_stride;
+        int mb_y = mb_xy / s->mb_stride;
+        int mb_distance;
+        float mb_factor = 0.0;
+#if 0
         if(spat_cplx < q/3) spat_cplx= q/3; //FIXME finetune
         if(temp_cplx < q/3) temp_cplx= q/3; //FIXME finetune
-#endif   
+#endif
         if(spat_cplx < 4) spat_cplx= 4; //FIXME finetune
         if(temp_cplx < 4) temp_cplx= 4; //FIXME finetune
 
-        if((s->mb_type[mb_xy]&CANDIDATE_MB_TYPE_INTRA)){//FIXME hq mode 
+        if((s->mb_type[mb_xy]&CANDIDATE_MB_TYPE_INTRA)){//FIXME hq mode
             cplx= spat_cplx;
             factor= 1.0 + p_masking;
         }else{
@@ -547,9 +542,26 @@ static void adaptive_quantization(MpegEncContext *s, double q){
             factor*= (1.0 - (lumi-128)*(lumi-128)*lumi_masking);
         else
             factor*= (1.0 - (lumi-128)*(lumi-128)*dark_masking);
-        
+
+        if(mb_x < mb_width/5){
+            mb_distance = mb_width/5 - mb_x;
+            mb_factor = (float)mb_distance / (float)(mb_width/5);
+        }else if(mb_x > 4*mb_width/5){
+            mb_distance = mb_x - 4*mb_width/5;
+            mb_factor = (float)mb_distance / (float)(mb_width/5);
+        }
+        if(mb_y < mb_height/5){
+            mb_distance = mb_height/5 - mb_y;
+            mb_factor = FFMAX(mb_factor, (float)mb_distance / (float)(mb_height/5));
+        }else if(mb_y > 4*mb_height/5){
+            mb_distance = mb_y - 4*mb_height/5;
+            mb_factor = FFMAX(mb_factor, (float)mb_distance / (float)(mb_height/5));
+        }
+
+        factor*= 1.0 - border_masking*mb_factor;
+
         if(factor<0.00001) factor= 0.00001;
-        
+
         bits= cplx*factor;
         cplx_sum+= cplx;
         bits_sum+= bits;
@@ -576,7 +588,7 @@ static void adaptive_quantization(MpegEncContext *s, double q){
         if(bits_sum < 0.001) bits_sum= 0.001;
         if(cplx_sum < 0.001) cplx_sum= 0.001;
     }
-   
+
     for(i=0; i<s->mb_num; i++){
         const int mb_xy= s->mb_index2xy[i];
         float newq= q*cplx_tab[i]/bits_tab[i];
@@ -595,9 +607,20 @@ static void adaptive_quantization(MpegEncContext *s, double q){
         s->lambda_table[mb_xy]= intq;
     }
 }
+
+void ff_get_2pass_fcode(MpegEncContext *s){
+    RateControlContext *rcc= &s->rc_context;
+    int picture_number= s->picture_number;
+    RateControlEntry *rce;
+
+    rce= &rcc->entry[picture_number];
+    s->f_code= rce->f_code;
+    s->b_code= rce->b_code;
+}
+
 //FIXME rd or at least approx for dquant
 
-float ff_rate_estimate_qscale(MpegEncContext *s)
+float ff_rate_estimate_qscale(MpegEncContext *s, int dry_run)
 {
     float q;
     int qmin, qmax;
@@ -619,10 +642,10 @@ float ff_rate_estimate_qscale(MpegEncContext *s)
 
     get_qminmax(&qmin, &qmax, s, pict_type);
 
-    fps= (double)s->avctx->frame_rate / (double)s->avctx->frame_rate_base;
+    fps= 1/av_q2d(s->avctx->time_base);
 //printf("input_pic_num:%d pic_num:%d frame_rate:%d\n", s->input_picture_number, s->picture_number, s->frame_rate);
         /* update predictors */
-    if(picture_number>2){
+    if(picture_number>2 && !dry_run){
         const int last_var= s->last_pict_type == I_TYPE ? rcc->last_mb_var_sum : rcc->last_mc_mb_var_sum;
         update_predictor(&rcc->pred[s->last_pict_type], rcc->last_qscale, sqrt(last_var), s->frame_bits);
     }
@@ -642,23 +665,16 @@ float ff_rate_estimate_qscale(MpegEncContext *s)
     if(br_compensation<=0.0) br_compensation=0.001;
 
     var= pict_type == I_TYPE ? pic->mb_var_sum : pic->mc_mb_var_sum;
-    
+
     short_term_q = 0; /* avoid warning */
     if(s->flags&CODEC_FLAG_PASS2){
         if(pict_type!=I_TYPE)
             assert(pict_type == rce->new_pict_type);
 
         q= rce->new_qscale / br_compensation;
-//MEANX, take also constraint in pass 2
-	if(s->avctx->rc_buffer_size)
-	{
-	  q=bitrate_constraint(s, rce, q, picture_number);
-	}
-// /MEANX
-
 //printf("%f %f %f last:%d var:%d type:%d//\n", q, rce->new_qscale, br_compensation, s->frame_bits, var, pict_type);
     }else{
-        rce->pict_type= 
+        rce->pict_type=
         rce->new_pict_type= pict_type;
         rce->mc_mb_var_sum= pic->mc_mb_var_sum;
         rce->mb_var_sum   = pic->   mb_var_sum;
@@ -677,7 +693,7 @@ float ff_rate_estimate_qscale(MpegEncContext *s)
             rce->i_count   = 0; //FIXME we do know this approx
             rce->i_tex_bits= 0;
             rce->p_tex_bits= bits*0.9;
-            
+
             rce->mv_bits= bits*0.1;
         }
         rcc->i_cplx_sum [pict_type] += rce->i_tex_bits*rce->qscale;
@@ -687,7 +703,7 @@ float ff_rate_estimate_qscale(MpegEncContext *s)
 
         bits= rce->i_tex_bits + rce->p_tex_bits;
         rate_factor= rcc->pass1_wanted_bits/rcc->pass1_rc_eq_output_sum * br_compensation;
-    
+
         q= get_qscale(s, rce, rate_factor, picture_number);
 
         assert(q>0.0);
@@ -707,7 +723,7 @@ float ff_rate_estimate_qscale(MpegEncContext *s)
 //printf("%f ", q);
         }
         assert(q>0.0);
-        
+
         q= modify_qscale(s, rce, q, picture_number);
 
         rcc->pass1_wanted_bits+= s->bit_rate/fps;
@@ -722,17 +738,19 @@ float ff_rate_estimate_qscale(MpegEncContext *s)
         );
     }
 
-    if     (q<qmin) q=qmin; 
+    if     (q<qmin) q=qmin;
     else if(q>qmax) q=qmax;
 
     if(s->adaptive_quant)
         adaptive_quantization(s, q);
     else
         q= (int)(q + 0.5);
-    
-    rcc->last_qscale= q;
-    rcc->last_mc_mb_var_sum= pic->mc_mb_var_sum;
-    rcc->last_mb_var_sum= pic->mb_var_sum;
+
+    if(!dry_run){
+        rcc->last_qscale= q;
+        rcc->last_mc_mb_var_sum= pic->mc_mb_var_sum;
+        rcc->last_mb_var_sum= pic->mb_var_sum;
+    }
 #if 0
 {
     static int mvsum=0, texsum=0;
@@ -752,7 +770,7 @@ static int init_pass2(MpegEncContext *s)
     RateControlContext *rcc= &s->rc_context;
     AVCodecContext *a= s->avctx;
     int i;
-    double fps= (double)s->avctx->frame_rate / (double)s->avctx->frame_rate_base;
+    double fps= 1/av_q2d(s->avctx->time_base);
     double complexity[5]={0,0,0,0,0};   // aproximate bits at quant=1
     double avg_quantizer[5];
     uint64_t const_bits[5]={0,0,0,0,0}; // quantizer idependant bits
@@ -762,14 +780,14 @@ static int init_pass2(MpegEncContext *s)
     double rate_factor=0;
     double step;
     //int last_i_frame=-10000000;
-    const int filter_size= (int)(a->qblur*4) | 1;  
+    const int filter_size= (int)(a->qblur*4) | 1;
     double expected_bits;
     double *qscale, *blured_qscale;
 
     /* find complexity & const_bits & decide the pict_types */
     for(i=0; i<rcc->num_entries; i++){
         RateControlEntry *rce= &rcc->entry[i];
-        
+
         rce->new_pict_type= rce->pict_type;
         rcc->i_cplx_sum [rce->pict_type] += rce->i_tex_bits*rce->qscale;
         rcc->p_cplx_sum [rce->pict_type] += rce->p_tex_bits*rce->qscale;
@@ -780,27 +798,27 @@ static int init_pass2(MpegEncContext *s)
         const_bits[rce->new_pict_type]+= rce->mv_bits + rce->misc_bits;
     }
     all_const_bits= const_bits[I_TYPE] + const_bits[P_TYPE] + const_bits[B_TYPE];
-    
+
     if(all_available_bits < all_const_bits){
         av_log(s->avctx, AV_LOG_ERROR, "requested bitrate is to low\n");
         return -1;
     }
-    
+
     /* find average quantizers */
     avg_quantizer[P_TYPE]=0;
     for(step=256*256; step>0.0000001; step*=0.5){
         double expected_bits=0;
         avg_quantizer[P_TYPE]+= step;
-        
+
         avg_quantizer[I_TYPE]= avg_quantizer[P_TYPE]*ABS(s->avctx->i_quant_factor) + s->avctx->i_quant_offset;
         avg_quantizer[B_TYPE]= avg_quantizer[P_TYPE]*ABS(s->avctx->b_quant_factor) + s->avctx->b_quant_offset;
-        
-        expected_bits= 
-            + all_const_bits 
+
+        expected_bits=
+            + all_const_bits
             + complexity[I_TYPE]/avg_quantizer[I_TYPE]
             + complexity[P_TYPE]/avg_quantizer[P_TYPE]
             + complexity[B_TYPE]/avg_quantizer[B_TYPE];
-            
+
         if(expected_bits < all_available_bits) avg_quantizer[P_TYPE]-= step;
 //printf("%f %lld %f\n", expected_bits, all_available_bits, avg_quantizer[P_TYPE]);
     }
@@ -810,14 +828,14 @@ static int init_pass2(MpegEncContext *s)
         available_bits[i]= const_bits[i] + complexity[i]/avg_quantizer[i];
     }
 //printf("%lld %lld %lld %lld\n", available_bits[I_TYPE], available_bits[P_TYPE], available_bits[B_TYPE], all_available_bits);
-        
+
     qscale= av_malloc(sizeof(double)*rcc->num_entries);
     blured_qscale= av_malloc(sizeof(double)*rcc->num_entries);
 
     for(step=256*256; step>0.0000001; step*=0.5){
         expected_bits=0;
         rate_factor+= step;
-        
+
         rcc->buffer_index= s->avctx->rc_buffer_size/2;
 
         /* find qscale */
@@ -829,7 +847,7 @@ static int init_pass2(MpegEncContext *s)
         /* fixed I/B QP relative to P mode */
         for(i=rcc->num_entries-1; i>=0; i--){
             RateControlEntry *rce= &rcc->entry[i];
-            
+
             qscale[i]= get_diff_limited_q(s, rce, qscale[i]);
         }
 
@@ -839,12 +857,12 @@ static int init_pass2(MpegEncContext *s)
             const int pict_type= rce->new_pict_type;
             int j;
             double q=0.0, sum=0.0;
-        
+
             for(j=0; j<filter_size; j++){
                 int index= i+j-filter_size/2;
                 double d= index-i;
                 double coeff= a->qblur==0 ? 1.0 : exp(-d*d/(a->qblur * a->qblur));
-            
+
                 if(index < 0 || index >= rcc->num_entries) continue;
                 if(pict_type != rcc->entry[index].new_pict_type) continue;
                 q+= qscale[index] * coeff;
@@ -852,7 +870,7 @@ static int init_pass2(MpegEncContext *s)
             }
             blured_qscale[i]= q/sum;
         }
-    
+
         /* find expected bits */
         for(i=0; i<rcc->num_entries; i++){
             RateControlEntry *rce= &rcc->entry[i];
