@@ -22,7 +22,7 @@
  * @file rv10.c
  * RV10 codec.
  */
- 
+
 #include "avcodec.h"
 #include "dsputil.h"
 #include "mpegvideo.h"
@@ -67,7 +67,7 @@ static const uint16_t rv_lum_code[256] =
  0x0f78, 0x0f79, 0x0f7a, 0x0f7b, 0x0f7c, 0x0f7d, 0x0f7e, 0x0f7f,
 };
 
-static const uint8_t rv_lum_bits[256] = 
+static const uint8_t rv_lum_bits[256] =
 {
  14, 12, 12, 12, 12, 12, 12, 12,
  12, 12, 12, 12, 12, 12, 12, 12,
@@ -235,29 +235,59 @@ void rv10_encode_picture_header(MpegEncContext *s, int picture_number)
     int full_frame= 0;
 
     align_put_bits(&s->pb);
-    
-    put_bits(&s->pb, 1, 1);	/* marker */
+
+    put_bits(&s->pb, 1, 1);     /* marker */
 
     put_bits(&s->pb, 1, (s->pict_type == P_TYPE));
 
-    put_bits(&s->pb, 1, 0);	/* not PB frame */
+    put_bits(&s->pb, 1, 0);     /* not PB frame */
 
     put_bits(&s->pb, 5, s->qscale);
 
     if (s->pict_type == I_TYPE) {
-	/* specific MPEG like DC coding not used */
+        /* specific MPEG like DC coding not used */
     }
     /* if multiple packets per frame are sent, the position at which
        to display the macro blocks is coded here */
     if(!full_frame){
-        put_bits(&s->pb, 6, 0);	/* mb_x */
-        put_bits(&s->pb, 6, 0);	/* mb_y */
+        put_bits(&s->pb, 6, 0); /* mb_x */
+        put_bits(&s->pb, 6, 0); /* mb_y */
         put_bits(&s->pb, 12, s->mb_width * s->mb_height);
     }
 
-    put_bits(&s->pb, 3, 0);	/* ignored */
+    put_bits(&s->pb, 3, 0);     /* ignored */
 }
 
+void rv20_encode_picture_header(MpegEncContext *s, int picture_number){
+    put_bits(&s->pb, 2, s->pict_type); //I 0 vs. 1 ?
+    put_bits(&s->pb, 1, 0);     /* unknown bit */
+    put_bits(&s->pb, 5, s->qscale);
+
+    put_bits(&s->pb, 8, picture_number&0xFF); //FIXME wrong, but correct is not known
+    s->mb_x= s->mb_y= 0;
+    ff_h263_encode_mba(s);
+
+    put_bits(&s->pb, 1, s->no_rounding);
+
+    assert(s->f_code == 1);
+    assert(s->unrestricted_mv == 1);
+//    assert(s->h263_aic== (s->pict_type == I_TYPE));
+    assert(s->alt_inter_vlc == 0);
+    assert(s->umvplus == 0);
+    assert(s->modified_quant==1);
+    assert(s->loop_filter==1);
+
+    s->h263_aic= s->pict_type == I_TYPE;
+    if(s->h263_aic){
+        s->y_dc_scale_table=
+        s->c_dc_scale_table= ff_aic_dc_scale_table;
+    }else{
+        s->y_dc_scale_table=
+        s->c_dc_scale_table= ff_mpeg1_dc_scale_table;
+    }
+}
+
+#if 0 /* unused, remove? */
 static int get_num(GetBitContext *gb)
 {
     int n, n1;
@@ -270,15 +300,15 @@ static int get_num(GetBitContext *gb)
         return (n << 16) | n1;
     }
 }
+#endif
 
 #endif //CONFIG_ENCODERS
 
 /* read RV 1.0 compatible frame header */
 static int rv10_decode_picture_header(MpegEncContext *s)
 {
-    int mb_count, pb_frame, marker, full_frame, unk;
-    
-    full_frame= s->avctx->slice_count==1;
+    int mb_count, pb_frame, marker, unk, mb_xy;
+
 //printf("ff:%d\n", full_frame);
     marker = get_bits(&s->gb, 1);
 
@@ -293,7 +323,7 @@ static int rv10_decode_picture_header(MpegEncContext *s)
 #ifdef DEBUG
     printf("pict_type=%d pb_frame=%d\n", s->pict_type, pb_frame);
 #endif
-    
+
     if (pb_frame){
         av_log(s->avctx, AV_LOG_ERROR, "pb frame not supported\n");
         return -1;
@@ -321,16 +351,18 @@ static int rv10_decode_picture_header(MpegEncContext *s)
     }
     /* if multiple packets per frame are sent, the position at which
        to display the macro blocks is coded here */
-    if ((!full_frame) || show_bits(&s->gb, 12)==0) {
-        s->mb_x = get_bits(&s->gb, 6);	/* mb_x */
-        s->mb_y = get_bits(&s->gb, 6);	/* mb_y */
+
+    mb_xy= s->mb_x + s->mb_y*s->mb_width;
+    if(show_bits(&s->gb, 12)==0 || (mb_xy && mb_xy < s->mb_num)){
+        s->mb_x = get_bits(&s->gb, 6); /* mb_x */
+        s->mb_y = get_bits(&s->gb, 6); /* mb_y */
         mb_count = get_bits(&s->gb, 12);
     } else {
         s->mb_x = 0;
         s->mb_y = 0;
         mb_count = s->mb_width * s->mb_height;
     }
-    unk= get_bits(&s->gb, 3);	/* ignored */
+    unk= get_bits(&s->gb, 3);   /* ignored */
 //printf("%d\n", unk);
     s->f_code = 1;
     s->unrestricted_mv = 1;
@@ -341,13 +373,29 @@ static int rv10_decode_picture_header(MpegEncContext *s)
 static int rv20_decode_picture_header(MpegEncContext *s)
 {
     int seq, mb_pos, i;
-    
+
+#if 0
+    GetBitContext gb= s->gb;
+    for(i=0; i<64; i++){
+        av_log(s->avctx, AV_LOG_DEBUG, "%d", get_bits1(&gb));
+        if(i%4==3) av_log(s->avctx, AV_LOG_DEBUG, " ");
+    }
+    av_log(s->avctx, AV_LOG_DEBUG, "\n");
+#endif
+#if 0
+    for(i=0; i<s->avctx->extradata_size; i++){
+        av_log(s->avctx, AV_LOG_DEBUG, "%2X ", ((uint8_t*)s->avctx->extradata)[i]);
+        if(i%4==3) av_log(s->avctx, AV_LOG_DEBUG, " ");
+    }
+    av_log(s->avctx, AV_LOG_DEBUG, "\n");
+#endif
+
     if(s->avctx->sub_id == 0x30202002 || s->avctx->sub_id == 0x30203002){
         if (get_bits(&s->gb, 3)){
             av_log(s->avctx, AV_LOG_ERROR, "unknown triplet set\n");
             return -1;
-        } 
-    }   
+        }
+    }
 
     i= get_bits(&s->gb, 2);
     switch(i){
@@ -355,16 +403,16 @@ static int rv20_decode_picture_header(MpegEncContext *s)
     case 1: s->pict_type= I_TYPE; break; //hmm ...
     case 2: s->pict_type= P_TYPE; break;
     case 3: s->pict_type= B_TYPE; break;
-    default: 
+    default:
         av_log(s->avctx, AV_LOG_ERROR, "unknown frame type\n");
         return -1;
     }
-    
+
     if(s->last_picture_ptr==NULL && s->pict_type==B_TYPE){
         av_log(s->avctx, AV_LOG_ERROR, "early B pix\n");
         return -1;
     }
-    
+
     if (get_bits(&s->gb, 1)){
         av_log(s->avctx, AV_LOG_ERROR, "unknown bit set\n");
         return -1;
@@ -381,29 +429,39 @@ static int rv20_decode_picture_header(MpegEncContext *s)
             return -1;
         }
     }
-        
+
     if(s->avctx->has_b_frames){
+        int f=9;
+        int v= s->avctx->extradata_size >= 4 ? ((uint8_t*)s->avctx->extradata)[1] : 0;
+
         if (get_bits(&s->gb, 1)){
-//            av_log(s->avctx, AV_LOG_ERROR, "unknown bit3 set\n");
+            av_log(s->avctx, AV_LOG_ERROR, "unknown bit3 set\n");
 //            return -1;
         }
-        seq= get_bits(&s->gb, 15);
-        if (s->avctx->sub_id == 0x20201002 && get_bits(&s->gb, 1)){
-            av_log(s->avctx, AV_LOG_ERROR, "unknown bit4 set\n");
-//            return -1;
+        seq= get_bits(&s->gb, 14)<<1;
+
+        if(v)
+            f= get_bits(&s->gb, av_log2(v));
+
+        if(s->avctx->debug & FF_DEBUG_PICT_INFO){
+            av_log(s->avctx, AV_LOG_DEBUG, "F %d/%d\n", f, v);
         }
+    }else{
+        seq= get_bits(&s->gb, 8)*128;
+    }
+
+//     if(s->avctx->sub_id <= 0x20201002){ //0x20201002 definitely needs this
+    mb_pos= ff_h263_decode_mba(s);
+/*    }else{
         mb_pos= get_bits(&s->gb, av_log2(s->mb_num-1)+1);
         s->mb_x= mb_pos % s->mb_width;
         s->mb_y= mb_pos / s->mb_width;
-    }else{
-        seq= get_bits(&s->gb, 8)*128;
-        mb_pos= ff_h263_decode_mba(s);
-    }
+    }*/
 //av_log(s->avctx, AV_LOG_DEBUG, "%d\n", seq);
     seq |= s->time &~0x7FFF;
     if(seq - s->time >  0x4000) seq -= 0x8000;
     if(seq - s->time < -0x4000) seq += 0x8000;
-    if(seq != s->time){  
+    if(seq != s->time){
         if(s->pict_type!=B_TYPE){
             s->time= seq;
             s->pp_time= s->time - s->last_non_b_time;
@@ -412,8 +470,8 @@ static int rv20_decode_picture_header(MpegEncContext *s)
             s->time= seq;
             s->pb_time= s->pp_time - (s->last_non_b_time - s->time);
             if(s->pp_time <=s->pb_time || s->pp_time <= s->pp_time - s->pb_time || s->pp_time<=0){
-                av_log(s->avctx, AV_LOG_DEBUG, "messed up order, seeking?, skiping current b frame\n");
-                return FRAME_SKIPED;
+                av_log(s->avctx, AV_LOG_DEBUG, "messed up order, possible from seeking? skipping current b frame\n");
+                return FRAME_SKIPPED;
             }
         }
     }
@@ -423,7 +481,7 @@ static int rv20_decode_picture_header(MpegEncContext *s)
 }
 av_log(s->avctx, AV_LOG_DEBUG, "\n");*/
     s->no_rounding= get_bits1(&s->gb);
-    
+
     s->f_code = 1;
     s->unrestricted_mv = 1;
     s->h263_aic= s->pict_type == I_TYPE;
@@ -432,9 +490,9 @@ av_log(s->avctx, AV_LOG_DEBUG, "\n");*/
 //    s->umvplus=1;
     s->modified_quant=1;
     s->loop_filter=1;
-    
+
     if(s->avctx->debug & FF_DEBUG_PICT_INFO){
-            av_log(s->avctx, AV_LOG_INFO, "num:%5d x:%2d y:%2d type:%d qscale:%2d rnd:%d\n", 
+            av_log(s->avctx, AV_LOG_INFO, "num:%5d x:%2d y:%2d type:%d qscale:%2d rnd:%d\n",
                    seq, s->mb_x, s->mb_y, s->pict_type, s->qscale, s->no_rounding);
     }
 
@@ -449,7 +507,7 @@ static int rv10_decode_init(AVCodecContext *avctx)
     static int done=0;
 
     MPV_decode_defaults(s);
-    
+
     s->avctx= avctx;
     s->out_format = FMT_H263;
     s->codec_id= avctx->codec_id;
@@ -479,13 +537,17 @@ static int rv10_decode_init(AVCodecContext *avctx)
         s->h263_long_vectors=0;
         s->low_delay=1;
         break;
-    case 0x20001000:
-    case 0x20100001:
+    case 0x20001000: /* real rv20 decoder fail on this id */
+    /*case 0x20100001:
     case 0x20101001:
+    case 0x20103001:*/
+    case 0x20100000 ... 0x2019ffff:
         s->low_delay=1;
         break;
-    case 0x20200002:
+    /*case 0x20200002:
     case 0x20201002:
+    case 0x20203002:*/
+    case 0x20200002 ... 0x202fffff:
     case 0x30202002:
     case 0x30203002:
         s->low_delay=0;
@@ -494,7 +556,13 @@ static int rv10_decode_init(AVCodecContext *avctx)
     default:
         av_log(s->avctx, AV_LOG_ERROR, "unknown header %X\n", avctx->sub_id);
     }
-//printf("ver:%X\n", avctx->sub_id);
+
+    if(avctx->debug & FF_DEBUG_PICT_INFO){
+        av_log(avctx, AV_LOG_DEBUG, "ver:%X ver0:%X\n", avctx->sub_id, avctx->extradata_size >= 4 ? ((uint32_t*)avctx->extradata)[0] : -1);
+    }
+
+    avctx->pix_fmt = PIX_FMT_YUV420P;
+
     if (MPV_common_init(s) < 0)
         return -1;
 
@@ -502,16 +570,14 @@ static int rv10_decode_init(AVCodecContext *avctx)
 
     /* init rv vlc */
     if (!done) {
-        init_vlc(&rv_dc_lum, DC_VLC_BITS, 256, 
+        init_vlc(&rv_dc_lum, DC_VLC_BITS, 256,
                  rv_lum_bits, 1, 1,
-                 rv_lum_code, 2, 2);
-        init_vlc(&rv_dc_chrom, DC_VLC_BITS, 256, 
+                 rv_lum_code, 2, 2, 1);
+        init_vlc(&rv_dc_chrom, DC_VLC_BITS, 256,
                  rv_chrom_bits, 1, 1,
-                 rv_chrom_code, 2, 2);
+                 rv_chrom_code, 2, 2, 1);
         done = 1;
     }
-    
-    avctx->pix_fmt = PIX_FMT_YUV420P;
 
     return 0;
 }
@@ -524,19 +590,13 @@ static int rv10_decode_end(AVCodecContext *avctx)
     return 0;
 }
 
-static int rv10_decode_packet(AVCodecContext *avctx, 
+static int rv10_decode_packet(AVCodecContext *avctx,
                              uint8_t *buf, int buf_size)
 {
     MpegEncContext *s = avctx->priv_data;
-    int i, mb_count, mb_pos, left;
+    int mb_count, mb_pos, left;
 
     init_get_bits(&s->gb, buf, buf_size*8);
-#if 0
-    for(i=0; i<buf_size*8 && i<200; i++)
-        printf("%d", get_bits1(&s->gb));
-    printf("\n");
-    return 0;
-#endif
     if(s->codec_id ==CODEC_ID_RV10)
         mb_count = rv10_decode_picture_header(s);
     else
@@ -545,7 +605,7 @@ static int rv10_decode_packet(AVCodecContext *avctx,
         av_log(s->avctx, AV_LOG_ERROR, "HEADER ERROR\n");
         return -1;
     }
-    
+
     if (s->mb_x >= s->mb_width ||
         s->mb_y >= s->mb_height) {
         av_log(s->avctx, AV_LOG_ERROR, "POS ERROR %d %d\n", s->mb_x, s->mb_y);
@@ -560,12 +620,14 @@ static int rv10_decode_packet(AVCodecContext *avctx,
 //if(s->pict_type == P_TYPE) return 0;
 
     if ((s->mb_x == 0 && s->mb_y == 0) || s->current_picture_ptr==NULL) {
+        if(s->current_picture_ptr){ //FIXME write parser so we always have complete frames?
+            ff_er_frame_end(s);
+            MPV_frame_end(s);
+            s->mb_x= s->mb_y = s->resync_mb_x = s->resync_mb_y= 0;
+        }
         if(MPV_frame_start(s, avctx) < 0)
             return -1;
-    }
-
-    if(s->pict_type == B_TYPE){ //FIXME remove after cleaning mottion_val indexing
-        memset(s->current_picture.motion_val[0], 0, sizeof(int16_t)*2*(s->mb_width*2+2)*(s->mb_height*2+2));
+        ff_er_frame_start(s);
     }
 
 #ifdef DEBUG
@@ -576,12 +638,12 @@ static int rv10_decode_packet(AVCodecContext *avctx,
     if(s->codec_id== CODEC_ID_RV10){
         if(s->mb_y==0) s->first_slice_line=1;
     }else{
-        s->first_slice_line=1;    
+        s->first_slice_line=1;
         s->resync_mb_x= s->mb_x;
         s->resync_mb_y= s->mb_y;
     }
     if(s->h263_aic){
-        s->y_dc_scale_table= 
+        s->y_dc_scale_table=
         s->c_dc_scale_table= ff_aic_dc_scale_table;
     }else{
         s->y_dc_scale_table=
@@ -590,7 +652,7 @@ static int rv10_decode_packet(AVCodecContext *avctx,
 
     if(s->modified_quant)
         s->chroma_qscale_table= ff_h263_chroma_qscale_table;
-        
+
     ff_set_qscale(s, s->qscale);
 
     s->rv10_first_dc_coded[0] = 0;
@@ -600,9 +662,9 @@ static int rv10_decode_packet(AVCodecContext *avctx,
     s->block_wrap[0]=
     s->block_wrap[1]=
     s->block_wrap[2]=
-    s->block_wrap[3]= s->mb_width*2 + 2;
+    s->block_wrap[3]= s->b8_stride;
     s->block_wrap[4]=
-    s->block_wrap[5]= s->mb_width + 2;
+    s->block_wrap[5]= s->mb_stride;
     ff_init_block_index(s);
     /* decode each macroblock */
 
@@ -613,12 +675,11 @@ static int rv10_decode_packet(AVCodecContext *avctx,
         printf("**mb x=%d y=%d\n", s->mb_x, s->mb_y);
 #endif
 
-	s->dsp.clear_blocks(s->block[0]);
         s->mv_dir = MV_DIR_FORWARD;
-        s->mv_type = MV_TYPE_16X16; 
+        s->mv_type = MV_TYPE_16X16;
         ret=ff_h263_decode_mb(s, s->block);
 
-        if (ret == SLICE_ERROR) {
+        if (ret == SLICE_ERROR || s->gb.size_in_bits < get_bits_count(&s->gb)) {
             av_log(s->avctx, AV_LOG_ERROR, "ERROR at MB %d %d\n", s->mb_x, s->mb_y);
             return -1;
         }
@@ -638,16 +699,18 @@ static int rv10_decode_packet(AVCodecContext *avctx,
         if(ret == SLICE_END) break;
     }
 
+    ff_er_add_slice(s, s->resync_mb_x, s->resync_mb_y, s->mb_x-1, s->mb_y, AC_END|DC_END|MV_END);
+
     return buf_size;
 }
 
-static int rv10_decode_frame(AVCodecContext *avctx, 
+static int rv10_decode_frame(AVCodecContext *avctx,
                              void *data, int *data_size,
                              uint8_t *buf, int buf_size)
 {
     MpegEncContext *s = avctx->priv_data;
     int i;
-    AVFrame *pict = data; 
+    AVFrame *pict = data;
 
 #ifdef DEBUG
     printf("*****frame %d size=%d\n", avctx->frame_number, buf_size);
@@ -655,7 +718,6 @@ static int rv10_decode_frame(AVCodecContext *avctx,
 
     /* no supplementary picture */
     if (buf_size == 0) {
-        *data_size = 0;
         return 0;
     }
 
@@ -663,27 +725,22 @@ static int rv10_decode_frame(AVCodecContext *avctx,
         for(i=0; i<avctx->slice_count; i++){
             int offset= avctx->slice_offset[i];
             int size;
-            
+
             if(i+1 == avctx->slice_count)
                 size= buf_size - offset;
             else
                 size= avctx->slice_offset[i+1] - offset;
 
-            if( rv10_decode_packet(avctx, buf+offset, size) < 0 )
-                return -1;
+            rv10_decode_packet(avctx, buf+offset, size);
         }
     }else{
-        if( rv10_decode_packet(avctx, buf, buf_size) < 0 )
-            return -1;
-    }
-    
-    if(s->pict_type == B_TYPE){ //FIXME remove after cleaning mottion_val indexing
-        memset(s->current_picture.motion_val[0], 0, sizeof(int16_t)*2*(s->mb_width*2+2)*(s->mb_height*2+2));
+        rv10_decode_packet(avctx, buf, buf_size);
     }
 
     if(s->mb_y>=s->mb_height){
+        ff_er_frame_end(s);
         MPV_frame_end(s);
-    
+
         if(s->pict_type==B_TYPE || s->low_delay){
             *pict= *(AVFrame*)&s->current_picture;
             ff_print_debug_info(s, pict);
@@ -691,10 +748,9 @@ static int rv10_decode_frame(AVCodecContext *avctx,
             *pict= *(AVFrame*)&s->last_picture;
             ff_print_debug_info(s, pict);
         }
-        
-        *data_size = sizeof(AVFrame);
-    }else{
-        *data_size = 0;
+        if(s->last_picture_ptr || s->low_delay)
+            *data_size = sizeof(AVFrame);
+        s->current_picture_ptr= NULL; //so we can detect if frame_end wasnt called (find some nicer solution...)
     }
 
     return buf_size;
@@ -721,6 +777,7 @@ AVCodec rv20_decoder = {
     NULL,
     rv10_decode_end,
     rv10_decode_frame,
-    CODEC_CAP_DR1
+    CODEC_CAP_DR1 | CODEC_CAP_DELAY,
+    .flush= ff_mpeg_flush,
 };
 
