@@ -32,7 +32,7 @@
 
 #include "ADM_library/fourcc.h"
 #include "ADM_3gp/ADM_atom.h"
-
+//#define _3G_LOGO
 #define aprintf printf
 //#define ATOM_DEBUG
 adm_atom::adm_atom(adm_atom *atom)
@@ -69,6 +69,11 @@ adm_atom::adm_atom(FILE *fd )
 #ifdef ATOM_DEBUG
 	dumpAtom();
 #endif
+#ifdef _3G_LOGO
+        printf("Starting at %x  atom ",_atomStart);
+        fourCC::printBE(_atomFCC);
+        printf("\n");
+#endif
 
 }
 uint8_t adm_atom::skipBytes( uint32_t nb )
@@ -120,6 +125,13 @@ uint32_t adm_atom::getSize( void )
 {
 	return _atomSize-8;
 }
+uint32_t adm_atom::getRemainingSize( void )
+{
+        int64_t pos=ftello(_fd);
+        
+        return _atomStart+_atomSize-pos;
+}
+
 uint8_t adm_atom::readPayload( uint8_t *whereto, uint32_t rd)
 {
 	uint32_t pos;
@@ -154,6 +166,11 @@ uint8_t adm_atom::dumpAtom( void )
 uint8_t adm_atom::skipAtom( void )
 {
 	fseek(_fd,_atomStart+_atomSize,SEEK_SET);
+#ifdef _3G_LOGO
+        printf("Branching to %x ending atom ",_atomStart+_atomSize);
+        fourCC::printBE(_atomFCC);
+        printf("\n");
+#endif
 	return 1;
 
 
