@@ -143,6 +143,10 @@ uint8_t		AVDMGenericAudioStream::getPacketWMA(uint8_t *dest, uint32_t *len,
 	return 0;
 
 }
+//*************
+// The packet is 1024 bytes long BUT the 4/8 bytes (mono/stereo) are used for predictor initialization
+//
+// See Mike Melanson nice doc http://www.multimedia.cx/simpleaudio.html
 //___________________________
 uint8_t		AVDMGenericAudioStream::getPacketPCM(uint8_t *dest, uint32_t *len, 
 								uint32_t *samples)
@@ -172,7 +176,8 @@ uint8_t		AVDMGenericAudioStream::getPacketPCM(uint8_t *dest, uint32_t *len,
 				printf("Wav Packetizer: running empty, last packet sent\n");
 				return 0;
 			}
-                        if(_wavheader->encoding!=WAV_ULAW && _wavheader->encoding!=WAV_8BITS_UNSIGNED)
+                        if(_wavheader->encoding!=WAV_ULAW && _wavheader->encoding!=WAV_8BITS_UNSIGNED&&
+                                        _wavheader->encoding!=WAV_IMAADPCM)
 			{
 				*samples=sample/2;
 			}
