@@ -33,7 +33,11 @@ static uint32_t xin,xout;
 ADM_faad::ADM_faad( uint32_t fourcc ,WAVHeader *info,uint32_t l,uint8_t *d) :   ADM_Audiocodec(fourcc)
 {
 faacDecConfigurationPtr conf;
+#ifdef OLD_FAAD_PROTO
 unsigned long int srate;
+#else
+uint32_t srate;
+#endif
 unsigned char chan;
 		_inited=0;
 		_instance=NULL;
@@ -50,7 +54,17 @@ unsigned char chan;
 		{
 			_inited = 1;
 			faacDecInit2(_instance, d,l, &srate,&chan);
-			printf("Found :%d rate %d channels\n",srate,chan);		
+			printf("Found :%d rate %d channels\n",srate,chan);
+                        if(srate!=info->frequency)
+                        {
+                            printf("Frequency mismatch!!! %d to %d (SBR ?)\n",info->frequency,srate);
+                            info->frequency=srate;
+                        }	
+                        if(chan!=info->channels) // Ask for stereo !
+                        {
+                             printf("channel mismatch!!! %d to %d \n",info->channels,chan);
+                            info->channels=chan;
+                        }
 		}
 		else // we will init it later on...
 		{
@@ -89,7 +103,11 @@ long int res;
 void *outbuf;
 faacDecFrameInfo info;
 int max=0;
-unsigned long int srate=0;
+#ifdef OLD_FAAD_PROTO
+unsigned long int srate;
+#else
+uint32_t srate;
+#endif
 unsigned char chan=0;
 uint8_t first=0;
 
