@@ -47,6 +47,9 @@
 #include "ADM_audiodevice/ADM_deviceWin32.h"
 #endif
 
+#ifdef USE_ESD
+#include "ADM_deviceEsd.h"
+#endif
 
 #include "gui_action.hxx"
 #include "audio_out.h"
@@ -125,6 +128,7 @@ AUDIO_DEVICE id;
 			case DEVICE_COREAUDIO:
 			case DEVICE_SDL:
 			case DEVICE_WIN32:
+			case DEVICE_ESD:
 			
 						printf("Using real audio device\n");
 						AVDM_switch(id);
@@ -149,8 +153,12 @@ AUDIO_DEVICE id;
 			#ifdef CYG_MANGLING
 			AVDM_switch(DEVICE_WIN32);
 			#else
-			AVDM_switch(DEVICE_DUMMY);
-			printf("\n Using dummy\n");
+                #ifdef USE_ESD
+			        AVDM_switch(DEVICE_ESD);
+                #else
+			        AVDM_switch(DEVICE_DUMMY);
+			        printf("\n Using dummy\n");
+                #endif
 			#endif
 		#endif
 		}
@@ -181,6 +189,12 @@ void AVDM_switch(AUDIO_DEVICE action)
 								currentDevice=DEVICE_OSS;;
 								break;
 #endif
+#if defined(USE_ESD) && !defined(CYG_MANGLING)
+		  case  DEVICE_ESD :
+								device=new 	 esdAudioDevice;
+								currentDevice=DEVICE_ESD;;
+								break;
+#endif
 #ifdef USE_ARTS
 		case DEVICE_ARTS:
 								device=new 	 artsAudioDevice;
@@ -238,7 +252,13 @@ uint32_t AVDM_AudioSetup(uint32_t fq, uint32_t channel)
 	if(channel>2) channel=2;
 	return device->init(channel,fq);
 }
+uint8_t         AVDM_setVolume(int volume)
+{
+        printf("New volume :%d\n",volume);
+        device->setVolume(volume);
+        return 1;
 
+}
 //_______________________________________________
 //
 //
