@@ -18,7 +18,8 @@ typedef enum
 	DEVICE_ALSA,
 	DEVICE_COREAUDIO,
 	DEVICE_SDL,
-	DEVICE_WIN32
+	DEVICE_WIN32,
+    DEVICE_ESD
 }AUDIO_DEVICE;
 
 typedef struct DEVICELIST
@@ -48,6 +49,9 @@ static const DEVICELIST audioDeviceList[]=
 #ifdef CYG_MANGLING	
 	MKADID(WIN32),
 #endif	
+#ifdef USE_ESD	
+	MKADID(ESD),
+#endif	
 
 	MKADID(DUMMY)
 };
