@@ -33,6 +33,7 @@
 #else
 	#include <sys/soundcard.h>
 	const char *dsp = "/dev/dsp";
+        const char *device_mixer = "/dev/mixer";
 
 #endif
  
@@ -43,11 +44,45 @@
 #include <ADM_assert.h>
 #include  "ADM_audiodevice/ADM_deviceoss.h"
 #include "ADM_toolkit/toolkit.hxx"
+#include "prefs.h"
 
+//_______________________________________________
+//
+//
+//_______________________________________________
+uint8_t  ossAudioDevice::setVolume(int volume) 
+{
+        int fd;
+	int ret;
+	uint8_t which_vol = 0;
 
+	prefs->get(FEATURE_AUDIOBAR_USES_MASTER,&which_vol);
+        fd=open(device_mixer,O_RDONLY);
+        if(!fd)
+        {
+                printf("OSS: cannot open mixer\n");
+                return 0;
+        }
+        printf("Oss: New %s volume %d\n",(which_vol?"master":"pcm"),volume);
+        // Assuming stereo
+        volume=volume+(volume<<8);
+	if( which_vol ){
+        	ret = ioctl(fd, MIXER_WRITE(SOUND_MIXER_VOLUME), &volume);
+	}else{
+        	ret = ioctl(fd, MIXER_WRITE(SOUND_MIXER_PCM   ), &volume);
+	}
+        close(fd);
 
+	if( ret ){
+		if( errno == EBADF ){
+			printf("set mixer failed: %u (possible access issue)\n",errno);
+		}else{
+			printf("set mixer failed: %u\n",errno);
+		}
+	}
+        return 1;
 
-
+}
 
 //_______________________________________________
 //
@@ -74,7 +109,7 @@ uint8_t ossAudioDevice::init(uint32_t channel, uint32_t fq)
     if (oss_fd == -1) {
 	if( errno == EACCES )
 	{
-           GUI_Alert("There is permission problem on /dev/dsp");
+           GUI_Error_HIG("Could not open OSS audio device", "Check the permissions for /dev/dsp.");
 	  }
 	else
            printf("\n Error initializing OSS: Error : %d", errno);
