@@ -49,6 +49,8 @@
 */
 #include "avi_vars.h"
 #include "audioeng_toolame.h"
+#include "ADM_audiocodec/ADM_audiocodeclist.h"
+#include "audioeng_lpcm.h"
 #include "ADM_toolkit/ADM_debugID.h"
 #define MODULE_NAME MODULE_AUDIO_FILTER
 #include "ADM_toolkit/ADM_debug.h"
@@ -59,54 +61,127 @@ extern void UI_setAudioCodec( int i);
 uint32_t audioFilterGetNbEncoder(void);
 const char* audioFilterGetIndexedName(uint32_t i);
 
-typedef struct {
-	const char *name;
-	const char *menuName;
-	AUDIOENCODER codec;
-}CODECLIST;
 
-static CODECLIST myCodecList[]=
+typedef struct externalSource
 {
-#ifdef HAVE_LIBMP3LAME
-		{"lame","Lame", AUDIOENC_MP3},
-#endif
-#ifdef USE_FAAC
-		{"aac","FAAC", AUDIOENC_FAAC},
-#endif
-#ifdef USE_VORBIS
-		{"vorbis","Vorbis", AUDIOENC_VORBIS},
-#endif
+ AudioSource type;
+ char *name;       
+}externalSource;
 
-		{"mp2", "FFm MP2", AUDIOENC_MP2},
-		{"ac3", "FFm AC3",AUDIOENC_AC3},
-		{"toolame","Toolame", AUDIOENC_2LAME},
-		{"none", "Wav PCM",AUDIOENC_NONE}
+static const externalSource Sources[]=
+{
+        {AudioAvi,"VIDEO"},
+        {AudioMP3,"MP3"},
+        {AudioWav,"WAV"},
+        {AudioAC3,"AC3"},
+        {AudioNone,"NONE"}
 };
+
+static DRCparam drcSetup=
+{
+    1,
+    0.001,//double   mFloor;
+    0.2, //double   mAttackTime;
+    1.0, //double   mDecayTime;
+    2.0, //double   mRatio;
+    -12.0 ,//double   mThresholdDB;
+};
+
 extern int DIA_getLameSettings(int *pmode, int *pbitrate,ADM_LAME_PRESET *preset);
 extern void UI_PrintCurrentACodec( const char *s);
 
 #define MAX_AUDIO_FILTER 10
 static AVDMProcessAudioStream *filters[MAX_AUDIO_FILTER];
 static uint32_t filtercount = 0;
-
- int  audioNormalizeMode = 0;
- int  audioFreq=48000;
- RESAMPLING  audioResampleMode = RESAMPLING_NONE;
+static AUDIOENCODER  activeAudioEncoder=  AUDIOENC_NONE;
+/*----------------------------------*/
+static int  audioNormalizeMode = 0;
+static int  audioFreq=48000;
+static RESAMPLING  audioResampleMode = RESAMPLING_NONE;
 static int  audioDRC = 0;
-
-
+static FILMCONV audioFilmConv=FILMCONV_NONE;
+static CHANNELCONV audioChannelConv=CHANNELCONV_NONE;
+static int audioMP3mode = 0;
+static int audioMP3bitrate = 128;
+static ADM_LAME_PRESET audioMP3preset=ADM_LAME_PRESET_CBR;
 // These are globals for the moment
 int 	   audioShift = 0;
 int	   audioDelay=0;
+//**********
+const char              *audioSourceFromEnum(AudioSource src)
+{
+        uint32_t nb=sizeof(Sources)/sizeof(externalSource);
+        for(uint32_t i=0;i<nb;i++)
+                if(src==Sources[i].type) return Sources[i].name;
+        ADM_assert(0);
 
-FILMCONV audioFilmConv=FILMCONV_NONE;
-CHANNELCONV audioChannelConv=CHANNELCONV_NONE;
+}
+AudioSource             audioSourceFromString(const char *name)
+{
+        uint32_t nb=sizeof(Sources)/sizeof(externalSource);
+        for(uint32_t i=0;i<nb;i++)
+                if(!strcasecmp(name,Sources[i].name)) return Sources[i].type;
+        return (AudioSource)0;
 
-// MP3 parameters
- int audioMP3mode = 0, audioMP3bitrate = 128;
- ADM_LAME_PRESET audioMP3preset=ADM_LAME_PRESET_CBR;
+}
+
+//**********
+uint8_t audioReset(void )
+{
+        audioNormalizeMode=0;
+        audioResampleMode = RESAMPLING_NONE;
+        audioFilmConv=FILMCONV_NONE;
+        audioChannelConv=CHANNELCONV_NONE;
+        return 1;
+}
+//************
+uint8_t audioGetNormalize(void)
+{
+        return audioNormalizeMode;
+
+}
+uint8_t audioGetDownsample(void)
+{
+        switch(audioResampleMode)
+        {
+        case RESAMPLING_CUSTOM:
+        case RESAMPLING_NONE: return 0;
+        case RESAMPLING_DOWNSAMPLING: return 1;
+        default: ADM_assert(0);
+        }
+        return 0;
+        
+}
+uint32_t audioGetResample(void)
+{
+      return audioFreq;
+        
+}
+uint32_t audioGetDelay(void)
+{
+        if(audioShift && audioDelay)
+        {
+                return audioDelay;
+                
+        }
+        return 0;
+}
+FILMCONV audioGetFpsConv(void)
+{
+        return audioFilmConv;
+}
+CHANNELCONV audioGetChannelConv(void)
+{
+        return audioChannelConv;
+}
+
+uint32_t audioGetBitrate(void)
+{
+        return audioMP3bitrate;
+} 
+/*----------------------------------*/
 //
-static AUDIOENCODER  activeAudioEncoder=  AUDIOENC_NONE;
+
 
 void audioCodecChanged(int newcodec)
 {
@@ -160,13 +235,23 @@ uint8_t audioFilterStereo2Mono(uint8_t onoff)
 		audioChannelConv=CHANNELCONV_NONE;
 	return 1;
 }
-
+RESAMPLING  audioGetResampling(void)
+{
+        return audioResampleMode;
+}
 uint8_t audioFilterFilm2Pal(uint8_t onoff)
 {
 	if(onoff) audioFilmConv=FILMCONV_FILM2PAL;
 	else audioFilmConv=FILMCONV_NONE;
 	return 1;
 }
+uint8_t audioFilterPal2Film(uint8_t onoff)
+{
+        if(onoff) audioFilmConv=FILMCONV_PAL2FILM;
+        else audioFilmConv=FILMCONV_NONE;
+        return 1;
+}
+
 void audioFilterDownsample(uint8_t onoff)
 {
 	if(onoff)
@@ -209,7 +294,7 @@ uint8_t audioCodecSetByName( const char *name)
 {
 		for(uint32_t i=0;i<sizeof(myCodecList)/sizeof(CODECLIST);i++)
 		{
-			if(!strcmp(name,myCodecList[i].name))
+			if(!strcasecmp(name,myCodecList[i].name))
 			{
 
 				audioCodecSetcodec(myCodecList[i].codec);
@@ -219,6 +304,20 @@ uint8_t audioCodecSetByName( const char *name)
 		}
 		printf("\n Mmmm Select audio codec by name failed...(%s).\n",name);
 		return 0;
+}
+AudioSource audioCodecGetFromName( const char *name)
+{
+                for(uint32_t i=0;i<sizeof(myCodecList)/sizeof(CODECLIST);i++)
+                {
+                        if(!strcasecmp(name,Sources[i].name))
+                        {
+
+                                return Sources[i].type;
+                        }
+
+                }
+                printf("\n Mmmm Select audio codec by name failed...(%s).\n",name);
+                return AudioNone;
 }
 	#define Read(x) { \
 		tmp=name; \
@@ -233,37 +332,7 @@ uint8_t audioCodecSetByName( const char *name)
 		}
 #define Add(x) {sprintf(tmp,"%s=%d ",#x,x);strcat(conf,tmp);}
 
-uint8_t audioCodecSetConf(char *name )
-{
- const char *tmp;
- uint8_t newmode,oldmode;
-	aprintf("-Audio filter by name : %s\n",name);
 
-	oldmode=audioProcessMode;
-	Read(audioProcessMode);
-	newmode=audioProcessMode;
-	audioProcessMode=oldmode;
-
-	Read(audioMP3mode);
-	Read(audioMP3bitrate);
-	Read(audioMP3preset);
-	UI_setAProcessToggleStatus( newmode );
-	return 1;
-}
-
-const char *audioCodecGetConf( void )
-{
- static char conf[400];
-	static char tmp[200];
-	conf[0]=0;
-	Add(audioProcessMode);
-	Add(audioMP3mode);
-	Add(audioMP3bitrate);
-	Add(audioMP3preset);
-
-	return conf;
-
-}
 const char *audioCodecGetName( void )
 {
 	for(uint32_t i=0;i<sizeof(myCodecList)/sizeof(CODECLIST);i++)
@@ -337,6 +406,11 @@ void audioCodecSelect( void )
 	audioPrintCurrentCodec();
 
 
+}
+uint32_t audioProcessMode(void)
+{
+        if(activeAudioEncoder==AUDIOENC_COPY) return 0;
+        return 1;
 }
 /*
 	Refresh   activeAudioEncoder value
@@ -361,8 +435,10 @@ void audioCodecConfigure( void )
 	
 	switch(activeAudioEncoder)
 	{
+                case AUDIOENC_LPCM:
 		case AUDIOENC_NONE:
 								return;
+
 #ifdef USE_FAAC
 		case AUDIOENC_FAAC:
 						
@@ -419,7 +495,7 @@ void audioCodecConfigure( void )
 
 
 AVDMProcessAudioStream *buildInternalAudioFilter(AVDMGenericAudioStream *currentaudiostream,
-				uint32_t starttime, uint32_t size)
+				uint32_t starttime, uint32_t duration)
 {
 
     AVDMProcessAudioStream *firstFilter = NULL;
@@ -444,32 +520,53 @@ AVDMProcessAudioStream *buildInternalAudioFilter(AVDMGenericAudioStream *current
 	if(audioFilmConv==FILMCONV_FILM2PAL)	
 	{
 		double d;
-		d=size;
+		d=duration;
 		d*=25000;
 		d/=23976;
-		size=(uint32_t)floor(d);
-		size=(size+1)&0xfffffffe;
+		duration=(uint32_t)floor(d);
+		duration=(duration+1)&0xfffffffe;
 	}
-    firstFilter = new AVDMProcessAudio_Null(currentaudiostream,
-					    starttime, size);
-    filtercount = 0;
-    lastFilter = firstFilter;
-    filters[filtercount++] = firstFilter;
-
 //_______________________________________________________
-    if (audioDelay)
+    if (audioDelay && audioShift)
       {
-	  if (audioShift)
-	    {
-		AVDMProcessAudio_TimeShift *ts;
-		ts = new AVDMProcessAudio_TimeShift(lastFilter,
-						    audioDelay);
-		tshift = (AVDMProcessAudioStream *) ts;
-		lastFilter = tshift;
-		printf("\n Time shift activated with %d %d ms", audioShift,audioDelay);
-		filters[filtercount++] = lastFilter;
-	    }
+                printf("\n Time shift activated with %d %d ms", audioShift,audioDelay);
+                // Depending on starttime & delay
+                // we may have or not to add silence
+                int32_t sstart=(int32_t)starttime;
+                
+                if (sstart>=audioDelay) // just seek in the file
+                {
+                        firstFilter = new AVDMProcessAudio_Null(currentaudiostream,
+                                            sstart-audioDelay, duration);
+                        filtercount = 0;
+                        lastFilter = firstFilter;
+                        filters[filtercount++] = firstFilter;
+                }
+                else    // We have to add a silence of -sstart seconds
+                {
+                
+                        firstFilter = new AVDMProcessAudio_Null(currentaudiostream,
+                                            sstart, duration);
+                        filtercount = 0;
+                        lastFilter = firstFilter;
+                        filters[filtercount++] = firstFilter;
+                        // Then the silence
+                        AVDMProcessAudio_TimeShift *ts;
+                        ts = new AVDMProcessAudio_TimeShift(lastFilter, audioDelay);
+                        tshift = (AVDMProcessAudioStream *) ts;
+                        lastFilter = tshift;
+                        
+                        filters[filtercount++] = lastFilter;
+                }
       }
+      else // no delay
+    {
+        firstFilter = new AVDMProcessAudio_Null(currentaudiostream,
+                                            starttime, duration);
+        filtercount = 0;
+        lastFilter = firstFilter;
+        filters[filtercount++] = firstFilter;
+    }
 
 
 //_______________________________________________________
@@ -491,7 +588,7 @@ AVDMProcessAudioStream *buildInternalAudioFilter(AVDMGenericAudioStream *current
       {
 	  AVDMProcessAudio_Compress *pdrc = NULL;
 	  printf("\n  DRC activated...\n");
-	  pdrc = new AVDMProcessAudio_Compress(lastFilter);
+	  pdrc = new AVDMProcessAudio_Compress(lastFilter,&drcSetup);
 	  drc = (AVDMProcessAudioStream *) pdrc;
 	  lastFilter = drc;
 	  filters[filtercount++] = lastFilter;
@@ -507,7 +604,7 @@ AVDMProcessAudioStream *buildInternalAudioFilter(AVDMGenericAudioStream *current
 	  		||  (lastFilter->getInfo()->channels != 2)
 			)
 	    	{
-			GUI_Alert(" input is not stereo@48 khz\n Downsample disabled\n");
+			GUI_Info_HIG(ADM_LOG_IMPORTANT,"Downsample disabled", "Input is not stereo, 48 kHz.");
 	  	} 
 		else
 	    	{
@@ -585,26 +682,38 @@ AVDMProcessAudioStream *buildInternalAudioFilter(AVDMGenericAudioStream *current
 }
 
 AVDMProcessAudioStream *buildPlaybackFilter(AVDMGenericAudioStream *currentaudiostream,
-				uint32_t starttime, uint32_t size)
+				uint32_t starttime, uint32_t duration)
 {
-AVDMProcessAudioStream *lastFilter;
+AVDMProcessAudioStream *lastFilter=NULL;
+int32_t sstart;
 
- 	lastFilter = new AVDMProcessAudio_Null(currentaudiostream,starttime, size);
- 	filtercount = 0;
- 	filters[filtercount++] = lastFilter;
-	if (audioDelay)
-      			{
-				  if (audioShift)
-				    {
-						AVDMProcessAudio_TimeShift *ts;
-						ts = new AVDMProcessAudio_TimeShift(lastFilter,    audioDelay);
+        // Do we need to go back
+        sstart=(int32_t)starttime;
 
-						lastFilter = ts;
-						printf("\n Time shift activated with %d %d ms", audioShift,audioDelay);
-						filters[filtercount++] = lastFilter;
+        if(audioShift && audioDelay)
+        {
+                if(sstart>audioDelay) sstart-=audioDelay;
+                else
+                {
+                        sstart=audioDelay-sstart;
+                        lastFilter = new AVDMProcessAudio_Null(currentaudiostream,0, duration);
+                        filtercount = 0;
+                        filters[filtercount++] = lastFilter;
 
-	    				}
-			}
+                        AVDMProcessAudio_TimeShift *ts;
+                                ts = new AVDMProcessAudio_TimeShift(lastFilter,    sstart);
+
+                                lastFilter = ts;
+                                printf("\n Time shift activated with %d %d ms", audioShift,audioDelay);
+                                filters[filtercount++] = lastFilter;
+                                return lastFilter;
+                }
+        }
+
+        lastFilter = new AVDMProcessAudio_Null(currentaudiostream,sstart, duration);
+        filtercount = 0;
+        filters[filtercount++] = lastFilter;
+       
 	return lastFilter;
 }
 void audioForceDownSample( void)
@@ -617,20 +726,37 @@ void audioSetResample(uint32_t fq)
 	audioResampleMode=RESAMPLING_CUSTOM;
 	audioFreq=fq;
 }
+uint8_t audioLamePreset(const char *name)
+{
+#ifdef HAVE_LIBMP3LAME
+int nb=sizeof(presetDefinition)/sizeof(ADM_PRESET_DEFINITION);
+        for(int i=0;i<nb;i++)   
+        {
+                if(!strcasecmp(presetDefinition[i].name,name))
+                        {
+                           audioMP3preset=    presetDefinition[i].preset;
+                           return 1; 
+                        }
+        }
+//
+        printf("AudioLame : Unknown preset  :%s\n",name);
+#endif
+        return 0;
+}
 /*
 	Build a fake filter chain without normalizer
 		to avoid to have to scan the file to get the max amplitude value
 
 */
 AVDMProcessAudioStream *buildFakeAudioFilter(AVDMGenericAudioStream *currentaudiostream,
-				uint32_t starttime, uint32_t size)
+				uint32_t starttime, uint32_t duration)
 {
 	uint8_t stored_norm;
 	AVDMProcessAudioStream *out;
 		stored_norm=audioNormalizeMode;	// Temporarily disable normalizing
 		
 		audioNormalizeMode=0;
-		out=buildAudioFilter(currentaudiostream,starttime,size);
+		out=buildAudioFilter(currentaudiostream,starttime,duration);
 		audioNormalizeMode=stored_norm;
 		return out;
 }
@@ -639,15 +765,15 @@ AVDMProcessAudioStream *buildFakeAudioFilter(AVDMGenericAudioStream *currentaudi
 */
 
 AVDMProcessAudioStream *buildAudioFilter(AVDMGenericAudioStream *currentaudiostream,
-				uint32_t starttime, uint32_t size)
+				uint32_t starttime, uint32_t duration)
 {
 AVDMProcessAudioStream *lastFilter=NULL;
 
 	// if audio is set to copy, we just return the first filter
-	if(!audioProcessMode)
+	if(!audioProcessMode())
 	{
  			lastFilter = new AVDMProcessAudio_Null(currentaudiostream,
-					    starttime, size);
+					    starttime, duration);
     			filtercount = 0;
     			lastFilter = lastFilter;
     			filters[filtercount++] = lastFilter;
@@ -657,7 +783,7 @@ AVDMProcessAudioStream *lastFilter=NULL;
 
 
 // else we build the full chain
-			buildInternalAudioFilter(currentaudiostream,starttime, size);
+			buildInternalAudioFilter(currentaudiostream,starttime, duration);
 			lastFilter=filters[filtercount-1];
 // and add encoder...
 
@@ -675,6 +801,14 @@ uint8_t init;
  				filters[filtercount++] = lastFilter;
 			#endif
 			break;
+                case AUDIOENC_LPCM:
+                {
+                                AVDMProcessAudio_Lpcm *lpcm;
+                                lpcm = new AVDMProcessAudio_Lpcm(lastFilter);
+                                lastFilter = lpcm;
+                                filters[filtercount++] = lastFilter;
+                }
+                break;
 #ifdef USE_VORBIS
 		case AUDIOENC_VORBIS:
 		{
@@ -688,8 +822,7 @@ uint8_t init;
  				else
 				{
 					delete vorbis;
-					GUI_Alert("VORBIS initialization failed\n"
-							" NOT ACTIVATED");
+					GUI_Error_HIG("Vorbis initialization failed", "Not activated.");
 				}
 		}
 		break;
@@ -707,8 +840,7 @@ uint8_t init;
  				else
 				{
 					delete faac;
-					GUI_Alert("FAAC initialization failed\n"
-							" NOT ACTIVATED");
+					GUI_Error_HIG("FAAC initialization failed", "Not activated.");
 				}
 		}
 		break;
@@ -732,8 +864,7 @@ uint8_t init;
 				  } else
 			    	{
 						delete plame;
-						GUI_Alert("Lame initialization failed\n"
-							" NOT ACTIVATED");
+						GUI_Error_HIG("LAME initialization failed", "Not activated.");
 			    	}
 			   }
 		    break;
@@ -757,7 +888,7 @@ uint8_t init;
 				  } else
 			    {
 			    		delete mp2enc;
-					GUI_Alert("FF MP2 initialization failed\n NOT ACTIVATED");
+					GUI_Error_HIG("FFmpeg MP2 initialization failed", "Not activated.");
 			    }
 			    }
     	  break;
@@ -777,8 +908,7 @@ uint8_t init;
 			} else
 			{
 				delete toolame_enc;
-				GUI_Alert("LibToolame initialization failed\n"
-					" NOT ACTIVATED");
+				GUI_Error_HIG("tooLAME initialization failed", "Not activated.");
 			}
 		}
     	  break;
@@ -799,7 +929,7 @@ uint8_t init;
 				  } else
 			    {
 			    		delete ac3enc;
-					GUI_Alert("FF AC3enc initialization failed\n NOT ACTIVATED");
+					GUI_Error_HIG("FFmpeg AC3 initialization failed", "Not activated.");
 			    }
 		  }
     	  break;
