@@ -20,12 +20,12 @@ AVDMProcessAudioStream *buildFakeAudioFilter(AVDMGenericAudioStream *currentaudi
 				uint32_t starttime, uint32_t size);
 
  AVDMProcessAudioStream *buildAudioFilter(AVDMGenericAudioStream *currentaudiostream,
-				uint32_t starttime, uint32_t size);
+				uint32_t starttime, uint32_t duration);
 AVDMProcessAudioStream *buildPlaybackFilter(AVDMGenericAudioStream *currentaudiostream,
-				uint32_t starttime, uint32_t size);
+				uint32_t starttime, uint32_t duration);
 
 AVDMProcessAudioStream *buildInternalAudioFilter(AVDMGenericAudioStream *currentaudiostream,
-				uint32_t starttime, uint32_t size);				
+				uint32_t starttime, uint32_t duration);				
 
 void deleteAudioFilter(void);								
 void audioFilter_configureFilters( void );
@@ -48,6 +48,8 @@ typedef enum AUDIOENCODER
 	AUDIOENC_2LAME,
 	AUDIOENC_FAAC,
 	AUDIOENC_VORBIS,
+        AUDIOENC_COPY,
+        AUDIOENC_LPCM,
 	AUDIOENC_DUMMY
 }AUDIOENCODER;
 
@@ -74,11 +76,22 @@ typedef enum CHANNELCONV
 	CHANNELCONV_1to2=2,
 	CHANNELCONV_last
 }CHANNELCONV;
+typedef enum
+{
+        AudioInvalid,
+        AudioAvi=1,
+        AudioMP3,
+        AudioWav,
+        AudioAC3,
+        AudioNone
+
+}AudioSource;
 
 void audioCodecSetcodec(AUDIOENCODER codec);
-
+uint8_t audioReset(void);
 /*  for job/workspace stuff  */
 uint8_t audioCodecSetByName( const char *name);
+AudioSource audioCodecGetFromName( const char *name);
 const char *audioCodecGetName( void );
 
 const char *audioFilterGetName( void );
@@ -89,14 +102,33 @@ uint8_t audioCodecSetConf(char *conf );
 
 AVDMGenericAudioStream *mpt_getAudioStream(void);
 
+/* -- Set filter --*/
 void audioFilterNormalize(uint8_t onoff);
 void audioFilterDownsample(uint8_t onoff);
 void audioFilterResample(uint32_t onoff);
 uint8_t audioFilterDelay(int32_t delay);
 uint8_t audioFilterFilm2Pal(uint8_t onoff);
+uint8_t audioFilterPal2Film(uint8_t onoff);
 
 uint8_t audioFilterMono2Stereo(uint8_t onoff);
 uint8_t audioFilterStereo2Mono(uint8_t onoff);
 
 void audioFilter_SetBitrate( int i);
+/* -- Get filter -- */
+uint32_t audioGetBitrate(void);
+uint8_t audioGetNormalize(void);
+uint8_t audioGetDownsample(void);
+uint32_t audioGetResample(void);
+uint32_t audioGetDelay(void);
+FILMCONV audioGetFpsConv(void);
+CHANNELCONV audioGetChannelConv(void);
+RESAMPLING  audioGetResampling(void);
+/*-----*/
+uint8_t                 A_changeAudioStream(AVDMGenericAudioStream *newaudio,AudioSource so,char *name);
+AudioSource             getCurrentAudioSource(char **name);
+const char              *audioSourceFromEnum(AudioSource *src);
+AudioSource             audioSourceFromString(const char *name);
+uint8_t     audioLamePreset(const char *name);
+//
+
 
