@@ -163,7 +163,7 @@ int i;
 	/* Nwing: # of filter coeffs in right wing */
 	r->Nwing = r->Nq * (r->Nmult/2+1) + 1;
 
-	r->Imp = (Float *)malloc(sizeof(Float) * (r->Nwing+2)) + 1;
+	r->Imp = (Float *)ADM_alloc(sizeof(Float) * (r->Nwing+2)) + 1;
 	/* need Imp[-1] and Imp[Nwing] for quadratic interpolation */
 	/* returns error # <=0, or adjusted wing-len > 0 */
 	
@@ -210,7 +210,7 @@ int i;
 	r->Ysize = BUFFSIZE - r->Xsize;
 	/* st_report("Xsize %d, Ysize %d, Xoff %d",r->Xsize,r->Ysize,r->Xoff); */
 
-	r->X = (Float *) malloc(sizeof(Float) * (BUFFSIZE));
+	r->X = (Float *) ADM_alloc(sizeof(Float) * (BUFFSIZE));
 	r->Y = r->X + r->Xsize;
 
 	/* Need Xoff zeros at beginning of sample */
@@ -395,8 +395,8 @@ int sox_stop(ResampleStruct *r)
 {
 	
 	
-	free(r->Imp - 1);
-	free(r->X);
+	ADM_dealloc((r->Imp - 1));
+	ADM_dealloc(r->X);
 	/* free(r->Y); Y is in same block starting at X */ 
 	return (1);
 }
@@ -896,7 +896,7 @@ int makeFilter(Float Imp[], long Nwing, double Froll, double Beta,
    if (Mwing==0)
       return(-4);
 
-   ImpR = (double *) malloc(sizeof(double) * Mwing);
+   ImpR = (double *) ADM_alloc(sizeof(double) * Mwing);
 
    /* Design a Nuttall or Kaiser windowed Sinc low-pass filter */
    LpFilter(ImpR, Mwing, Froll, Beta, Num);
@@ -919,7 +919,7 @@ int makeFilter(Float Imp[], long Nwing, double Froll, double Beta,
       for (i=0; i<Mwing; i++)
          Imp[i] = ImpR[i];
    }
-   free(ImpR);
+   ADM_dealloc(ImpR);
    for (i=Mwing; i<=Nwing; i++) Imp[i] = 0;
    /* Imp[Mwing] and Imp[-1] needed for quadratic interpolation */
    Imp[-1] = Imp[1];
