@@ -66,6 +66,7 @@ extern "C" {
 #endif
 #include "ADM_codecs/ADM_mpeg.h"
 #include "ADM_codecs/ADM_vp3.h"
+#include "ADM_codecs/ADM_png.h"
 #include "ADM_toolkit/toolkit.hxx"
 #include <ADM_assert.h>
 #include "prefs.h"
@@ -88,6 +89,7 @@ uint8_t isMpeg4Compatible( uint32_t fourcc)
 	       	CHECK("xvid");
 	       	CHECK("XVID");
           	CHECK("BLZ0");
+		CHECK("M4S2");
 
           return divx4;
 
@@ -187,6 +189,14 @@ decoders *getDecoderVopPacked(uint32_t fcc,uint32_t w, uint32_t h,uint32_t extra
 
 			  	     	return(decoders *)( new decoderFFhuff(w,h,extraLen,extraData));
 	   }
+#ifdef USE_PNG
+	   if(fourCC::check(fcc,(uint8_t *)"PNG "))
+          {
+
+                                        return(decoders *)( new decoderPng(w,h));
+           } 
+#endif
+	   
   if(fourCC::check(fcc,(uint8_t *)"FFVH"))
           {
 
@@ -197,6 +207,12 @@ decoders *getDecoderVopPacked(uint32_t fcc,uint32_t w, uint32_t h,uint32_t extra
 
 			  	     	return(decoders *)( new decoderFFSVQ3(w,h,extraLen,extraData));
 	   }
+ if(fourCC::check(fcc,(uint8_t *)"tscc"))
+          {
+
+                                        return(decoders *)( new decoderCamtasia(w,h,16));
+//stream->biBitCount)); // Fixme should be bit per pixel
+           }
 
     if(fourCC::check(fcc,(uint8_t *)"WMV2"))
           {
@@ -213,10 +229,15 @@ decoders *getDecoderVopPacked(uint32_t fcc,uint32_t w, uint32_t h,uint32_t extra
 
 			  	     	return(decoders *)( new decoderSnow(w,h));
 	   }
-           if(fourCC::check(fcc,(uint8_t *)"H264"))
+           if(  
+                fourCC::check(fcc,(uint8_t *)"H264")||fourCC::check(fcc,(uint8_t *)"avc1") ||
+                fourCC::check(fcc,(uint8_t *)"h264")||fourCC::check(fcc,(uint8_t *)"x264") ||
+                fourCC::check(fcc,(uint8_t *)"X264")
+
+                )
            {
 
-             return(decoders *)( new decoderFFH264(w,h));
+             return(decoders *)( new decoderFFH264(w,h,extraLen,extraData));
            }           
 #endif
 
@@ -228,7 +249,7 @@ decoders *getDecoderVopPacked(uint32_t fcc,uint32_t w, uint32_t h,uint32_t extra
 
  	if(isMpeg4Compatible(fcc)==1)
     	{
-				       	return(decoders *)( new decoderFFMpeg4(w,h));
+				       	return(decoders *)( new decoderFFMpeg4(w,h,extraLen,extraData));
 				  //	return(decoders *)( new decoderXvid(w,h));
 				  //	return(decoders *)( new decoderDIVX(w,h));
 	}
@@ -245,7 +266,7 @@ decoders *getDecoderVopPacked(uint32_t fcc,uint32_t w, uint32_t h,uint32_t extra
 #endif
 
            }
-          if(fourCC::check(fcc,(uint8_t *)"YV12"))
+          if(fourCC::check(fcc,(uint8_t *)"YV12")||fourCC::check(fcc,(uint8_t *)"I420"))
           {
             			printf("\n using null codec\n");
 			       	return(decoders *)( new decoderNull(w,h));
