@@ -42,7 +42,24 @@
 #include "ADM_toolkit/ADM_debugID.h"
 #define MODULE_NAME  MODULE_CODEC
 #include "ADM_toolkit/ADM_debug.h"
-
+//****************************
+#define WRAP_Open(x) \
+{\
+AVCodec *codec=avcodec_find_decoder(x);\
+if(!codec) {GUI_Alert("Internal error finding codec"#x);ADM_assert(0);} \
+  codecId=x; \
+  if (avcodec_open(_context, codec) < 0)  \
+                      { \
+                                        printf(" Decoder init: Lavcodec :"#x" video decoder failed!\n"); \
+                                        GUI_Alert("Internal error opening "#x); \
+                                        ADM_assert(0); \
+                                } \
+                                else \
+                                { \
+                                        printf(" Decoder init: lavcodec "#x" video decoder initialized!\n"); \
+                                } \
+} 
+//****************************
 extern uint8_t DIA_lavDecoder(uint32_t *swapUv, uint32_t *showU);
 extern "C"
 {
@@ -120,7 +137,7 @@ void decoderFF::setParam( void )
 //-------------------------------
 decoderFF::decoderFF(uint32_t w,uint32_t h) :decoders(w,h)
 {
-
+                                codecId=0;
 //				memset(&_context,0,sizeof(_context));
 				_allowNull=0;
                                 _gmc=0;
@@ -234,12 +251,11 @@ uint8_t     decoderFF::uncompress(uint8_t *in,ADMImage *out,uint32_t len,uint32_
 			
 		if(len==0 && !_allowNull) // Null frame, silently skipped
 				{
-            				if(flagz) *flagz=AVI_KEY_FRAME;
-              				printf("\n ff4: null frame\n");
-                                        if(dontcopy())
+                                        if(flagz) *flagz=AVI_KEY_FRAME;
+                                        printf("\n ff4: null frame\n");
                                         {
                                                 // search the last image
-                                                if(_context->coded_frame->data)
+                                                if(_context->coded_frame && _context->coded_frame->data)
                                                 {
                                                         clonePic(_context->coded_frame,out);
                                                         if(flagz)
@@ -248,7 +264,7 @@ uint8_t     decoderFF::uncompress(uint8_t *in,ADMImage *out,uint32_t len,uint32_
                                                 else                                                
                                                         out->_noPicture=1;                                                
                                         }
-					return 1;
+                                        return 1;
 				}
 
 		ret= avcodec_decode_video(_context,&_frame,&got_picture, in, len);
@@ -264,13 +280,13 @@ uint8_t     decoderFF::uncompress(uint8_t *in,ADMImage *out,uint32_t len,uint32_
 				// Some encoder code a vop header with the 
 				// vop flag set to 0
 				// it is meant to mean frame skipped but very dubious
-				if(len<=8)
+				if(len<=8 && codecId==CODEC_ID_MPEG4)
 					{
 						printf("Probably pseudo black frame...\n");
 						out->_Qp=2;
 						out->flags=0; // assume P ?
-                                                if(dontcopy())
-                                                        clonePic(_context->coded_frame,out);
+
+                                                clonePic(_context->coded_frame,out);
 						if(flagz)
 							*flagz=out->flags;
 						return 1;
@@ -308,214 +324,40 @@ uint8_t     decoderFF::uncompress(uint8_t *in,ADMImage *out,uint32_t len,uint32_
 			}
  			return 1;
 		}
-		// convert ffmpeg to our format : yv12
-		uint8_t **src;
-		uint32_t stridex[3];
-		uint8_t  *inx[3];
-		//printf("cspace %d\n", _context->pix_fmt);
 
-		switch(_context->pix_fmt)
-		{
-		case PIX_FMT_YUV411P:
-			stridex[0]=	_frame.linesize[0 ];
-			stridex[1]=	_frame.linesize[1 ];
-			stridex[2]=	_frame.linesize[2 ];
+                switch(_context->pix_fmt)
+                {
+                case PIX_FMT_YUV411P:
+                        out->_colorspace=ADM_COLOR_YUV411;
+                        break;
 
-			inx[0]=_frame.data[0];
-			inx[1]=_frame.data[1];
-			inx[2]=_frame.data[2];
+                case PIX_FMT_YUV422P:
+                case PIX_FMT_YUVJ422P:
+                        out->_colorspace=ADM_COLOR_YUV422;
+                        break;
 
-
-			COL_411_YV12(inx,stridex,_internalBuffer,_w,_h);
-
-			oBuff[0]=_internalBuffer;
-		 	oBuff[1]=_internalBuffer+_w*_h;
- 		 	oBuff[2]=oBuff[1]+((_w*_h)>>2);
-			src= (uint8_t **)oBuff;
-			_frame.linesize[0 ]=_w;
-			_frame.linesize[1 ]=_w>>1;
-			_frame.linesize[2 ]=_w>>1;
-			
-			
-			break;
-
-		case PIX_FMT_YUV422P:
-			//printf("422p\n");
-			stridex[0]=	_frame.linesize[0 ];
-			stridex[1]=	_frame.linesize[1 ];
-			stridex[2]=	_frame.linesize[2 ];
-
-			inx[0]=_frame.data[0];
-			inx[1]=_frame.data[1];
-			inx[2]=_frame.data[2];
-
-			
-			COL_422_YV12(inx,stridex,_internalBuffer,_w,_h);
-
-			oBuff[0]=_internalBuffer;
-		 	oBuff[1]=_internalBuffer+_w*_h;
- 		 	oBuff[2]=oBuff[1]+((_w*_h)>>2);
-			src= (uint8_t **)oBuff;
-			_frame.linesize[0 ]=_w;
-			_frame.linesize[1 ]=_w>>1;
-			_frame.linesize[2 ]=_w>>1;
-		
-			
-			break;
-		
-		case PIX_FMT_YUV420P:
-		case PIX_FMT_YUVJ420P:
-		// Default is YV12 or I420
-		// In that case depending on swap u/v
-		// we do it or not
-	                        if(dontcopy())
-                                {
-                                        clonePic(&_frame,out);
-                                        if(flagz)
-                                                               *flagz=out->flags;
-                                        return 1;
-                                }
-				//printf("420p\n");
-				src= (uint8_t **) _frame.data;
-				
-				if(_frame.qstride && _frame.qscale_table)	
-				{
-				if(out->quant)
-				{
-					{
-						uint8_t *src,*dst;
-						src=(uint8_t *)_frame.qscale_table;
-						dst=out->quant;
-						// Pack them
-						// /16 width = >>4
-						// /16 height= >>4
-						out->_qStride=(_w+15)>>4;
-						for(uint32_t y=0;y<((_h+15)>>4);y++)
-						{				
-							memcpy(dst,src,out->_qStride);
-							src+=_frame.qstride;
-							dst+=out->_qStride;
-							
-						}
-					}
-				}
-				}
-				else out->_qStride=0;
-
-			break;
-/*
-uint8_t COL_RawRGB32toYV12(uint8_t *data1,uint8_t *data2, uint8_t *oy,uint8_t *oy2, 
-				uint8_t *u, uint8_t *v,uint32_t lineSize)
-*/			
-		case PIX_FMT_RGBA32:
-				{
-				uint32_t stride;
-				uint8_t *data1,*data2;
-				uint8_t *oy,*oy2,*u,*v;
-				
-						
-						stride=	_frame.linesize[0 ];
-						data1=(uint8_t *)_frame.data[0];
-						data2=(uint8_t *)_frame.data[0]+stride;
-						oy=out->data;
-						oy2=out->data+_w;
-						if(!_swapUV)
-						{
-							u=out->data+(_w*_h);
-							v=out->data+((_w*_h*5)>>2);
-						
-						}
-						else
-						{
-							v=out->data+(_w*_h);
-							u=out->data+((_w*_h*5)>>2);	
-						}
-						
-						 COL_RawRGB32toYV12(data1,data2, oy,oy2, 
-							u, v,_w,_h,stride)	;
-						_lastQ=0; //_context->quality;	
-						if(flagz)
-						{
-							*flagz=frameType();
-						}
-						
- 						return 1;
-				}
-		default:
-				printf("\n Unhandled colorspace:%d\n",_context->pix_fmt);
-				return 0;
-				
-		}
-		// Pack the output so that stride=width
-		
-		uint8_t *tmp;
-		tmp=src[0];
-		uint8_t *otmp= out->data;
-		uint32_t stride;
-
-                ADM_assert(!dontcopy());
-
-		stride=  _frame.linesize[0 ];
-
-		for(uint32_t y=_h;y>0;y--)
-			{
-				 	memcpy(otmp,tmp,_w);
-				  	tmp+=stride;
-   				  	otmp+=_w;
-				}
-		
-
-		if(!_swapUV)
-		{
-			tmp= src[1];
-			stride=  _frame.linesize[1];
-		}
-		else
-		{
-			tmp= src[2];			
-			stride=  _frame.linesize[2];
-		}
-			
-
-		otmp= out->data+((5*_w*_h)>>2);
-
-		for(uint32_t y=_h>>1;y>0;y--)
-			{
-				 	memcpy(otmp,tmp,_w>>1);
-				  	tmp+=stride;
-   				  	otmp+=_w>>1;
-				}
-		if(!_swapUV)
-		{
-			tmp= src[2];			
-			stride=  _frame.linesize[2];
-		}
-		else
-		{
-			tmp= src[1];
-			stride=  _frame.linesize[1];
-		}
-		otmp= out->data+_w*_h;
-
-		for(uint32_t y=_h>>1;y>0;y--)
-			{
-				 	memcpy(otmp,tmp,_w>>1);
-				  	tmp+=stride;
-   				  	otmp+=_w>>1;
-				}
-
-		_lastQ=0; //_context->quality;
-	//	printf("FF %d :: \n",_frame.pict_type);
-		out->_Qp=(_frame.quality*32)/FF_LAMBDA_MAX;
-		//printf("%d %d\n",_frame.quality,FF_LAMBDA_MAX);
-		out->flags=frameType();
-		if(flagz)
-		{
-
-			*flagz=out->flags;
-		}
-		
- 		return 1;
+                case PIX_FMT_YUV420P:
+                case PIX_FMT_YUVJ420P:
+                // Default is YV12 or I420
+                // In that case depending on swap u/v
+                // we do it or not
+                        out->_colorspace=ADM_COLOR_YV12;
+                        break;
+                break;
+                case PIX_FMT_RGBA32:
+                        out->_colorspace=ADM_COLOR_RGB32A;
+                        break;
+                case PIX_FMT_RGB555:
+                        out->_colorspace=ADM_COLOR_BGR555;
+                        break;
+                default:
+                                printf("\n Unhandled colorspace:%d\n",_context->pix_fmt);
+                                return 0;
+                }
+                clonePic(&_frame,out);
+                if(flagz)
+                        *flagz=out->flags;
+                return 1;
 }
 
 
@@ -523,71 +365,38 @@ uint8_t COL_RawRGB32toYV12(uint8_t *data1,uint8_t *data2, uint8_t *oy,uint8_t *o
 decoderFFDiv3::decoderFFDiv3(uint32_t w,uint32_t h)    :decoderFF(w,h) 
 {
                       _refCopy=1; // YUV420 only
-		      if (avcodec_open(_context, &msmpeg4v3_decoder) < 0) 
-		      {
-					printf(" Decoder init: FFMpeg MS MPEG43 video decoder failed!\n");
-				}
-				else
-				{
-					printf(" Decoder init: FFMpeg MS MPEG43 video decoder initialized!\n");
-				}
+                        WRAP_Open(CODEC_ID_MSMPEG4V3);
 }              
 decoderFFMpeg4VopPacked::decoderFFMpeg4VopPacked(uint32_t w,uint32_t h)       :decoderFF(w,h)
 {
 // force low delay as avidemux don't handle B-frames
 
       _refCopy=1; // YUV420 only
-      if (avcodec_open(_context,& mpeg4_decoder) < 0)
-	      {
-				printf(" Decoder init: FFMpeg MPEG4 video decoder failed!\n");
-		}
-	else
-		{
-				printf(" Decoder init: FFMpeg MPEG4 video vop packed  decoder initialized!\n");
-		}
 	_allowNull=1;
+        WRAP_Open(CODEC_ID_MPEG4);
 }
-decoderFFMpeg4::decoderFFMpeg4(uint32_t w,uint32_t h)       :decoderFF(w,h)
+decoderFFMpeg4::decoderFFMpeg4(uint32_t w,uint32_t h,uint32_t l, uint8_t *d)       :decoderFF(w,h)
 {
 // force low delay as avidemux don't handle B-frames
-
-		  _context->flags|=CODEC_FLAG_LOW_DELAY;
+        printf("Using %d bytes of extradata for MPEG4 decoder\n",l);
+                  _context->flags|=CODEC_FLAG_LOW_DELAY;
                   _refCopy=1; // YUV420 only
+                  _context->extradata=(void *)d;
+                  _context->extradata_size=(int)l;
  		//  _context->flags|=FF_DEBUG_VIS_MV;
-      if (avcodec_open(_context,& mpeg4_decoder) < 0)
-	      {
-					printf(" Decoder init: FFMpeg MPEG4 video decoder failed!\n");
-				}
-				else
-				{
-					printf(" Decoder init: FFMpeg MPEG4 video decoder initialized!\n");
-				}
+       WRAP_Open(CODEC_ID_MPEG4);
 }
 decoderFFDV:: decoderFFDV(uint32_t w,uint32_t h,uint32_t l,uint8_t *d)        :decoderFF(w,h)
 {
       _context->extradata=(void *)d;
       _context->extradata_size=(int)l;
-      if (avcodec_open(_context,& dvvideo_decoder) < 0) 
-	      {
-					printf(" Decoder init: FFMpeg DV video decoder failed!\n");
-				}
-				else
-				{
-					printf(" Decoder init: FFMpeg DV video decoder initialized!\n");
-				}
+      WRAP_Open(CODEC_ID_DVVIDEO);
 	
 }
 decoderFFMP42::decoderFFMP42(uint32_t w,uint32_t h)       :decoderFF(w,h)
 {
       _refCopy=1; // YUV420 only
-      if (avcodec_open(_context,& msmpeg4v2_decoder) < 0)
-	      {
-					printf(" Decoder init: FFMpeg MP42 video decoder failed!\n");
-				}
-				else
-				{
-					printf(" Decoder init: FFMpeg MP42 video decoder initialized!\n");
-				}
+        WRAP_Open(CODEC_ID_MSMPEG4V2);
 
 }
 decoderFFMpeg12::decoderFFMpeg12(uint32_t w,uint32_t h,uint32_t extraLen,uint8_t *extraData)
@@ -596,15 +405,7 @@ decoderFFMpeg12::decoderFFMpeg12(uint32_t w,uint32_t h,uint32_t extraLen,uint8_t
 int got_picture=0;
   	_context->flags|=CODEC_FLAG_LOW_DELAY;
         _refCopy=1; // YUV420 only
-      if (avcodec_open(_context,& mpeg1video_decoder) < 0)
-	      {
-					printf(" Decoder init: FFMpeg Mpeg1/2 video decoder failed!\n");
-				}
-				else
-				{
-					printf(" Decoder init: FFMpeg Mpeg1/2 video decoder initialized!\n");
-				}
-
+      WRAP_Open(CODEC_ID_MPEG2VIDEO);
 }
 decoderFFSVQ3::decoderFFSVQ3(uint32_t w,uint32_t h,uint32_t extraLen,uint8_t *extraData)
 	    :decoderFF(w,h)
@@ -614,71 +415,36 @@ int got_picture=0;
   	_context->flags|=CODEC_FLAG_LOW_DELAY;
 	 _context->extradata=(void *)extraData;
       _context->extradata_size=(int)extraLen;
-      if (avcodec_open(_context,& svq3_decoder) < 0)
-	      {
-					printf(" Decoder init: FFMpeg SVQ3 video decoder failed!\n");
-				}
-				else
-				{
-					printf(" Decoder init: FFMpeg SVQ3 video decoder initialized"
-						" (%lu bytes of extra)!\n",extraLen);
-				}
-
+     WRAP_Open(CODEC_ID_SVQ3);
 }
 
 decoderFFH263::decoderFFH263(uint32_t w,uint32_t h)       :decoderFF(w,h)
 {
       _refCopy=1; // YUV420 only
-      if (avcodec_open(_context,& h263_decoder) < 0)
-	      {
-					printf(" Decoder init: FFMpeg h263 video decoder failed!\n");
-				}
-				else
-				{
-					printf(" Decoder init: FFMpeg h263 video decoder initialized!\n");
-				}
+      WRAP_Open(CODEC_ID_H263);
 
 }
 decoderFFV1::decoderFFV1(uint32_t w,uint32_t h)       :decoderFF(w,h)
 {
       _refCopy=1; // YUV420 only
-      if (avcodec_open(_context,& ffv1_decoder) < 0)
-	      {
-					printf(" Decoder init: FFMpeg ffV1 video decoder failed!\n");
-				}
-				else
-				{
-					printf(" Decoder init: FFMpeg ffv1 video decoder initialized!\n");
-				}
-
+      WRAP_Open(CODEC_ID_FFV1);
 }
 decoderFF_ffhuff::decoderFF_ffhuff(uint32_t w,uint32_t h,uint32_t l,uint8_t *d)       :decoderFF(w,h) 
 {
       _context->extradata=(void *)d;
       _context->extradata_size=(int)l;
       printf("FFhuff: We have :%d bytes of extra data\n",l);
-      if (avcodec_open(_context,& ffvhuff_decoder) < 0)
-              {
-                                        printf(" Decoder init: FFMpeg ffhuff video decoder failed!\n");
-                                }
-                                else
-                                {
-                                        printf(" Decoder init: FFMpeg ffhuff video decoder initialized!\n");
-                                }
+     WRAP_Open(CODEC_ID_FFVHUFF);
         
 }
-decoderFFH264::decoderFFH264(uint32_t w,uint32_t h)  :decoderFF(w,h) 
+decoderFFH264::decoderFFH264(uint32_t w,uint32_t h,uint32_t l,uint8_t *d)  :decoderFF(w,h) 
 {
   _refCopy=1; // YUV420 only
-  printf("Initializing lavcodec H264 decoder\n");
-  if (avcodec_open(_context,& h264_decoder) < 0)
-  {
-    printf(" Decoder init: FFMpeg H264 video decoder failed!\n");
-  }
-  else
-  {
-    printf(" Decoder init: FFMpeg H264 video decoder initialized!\n");
-  }
+  _context->extradata=(void *)d;
+  _context->extradata_size=(int)l;
+
+  printf("Initializing lavcodec H264 decoder with %d extradata\n",l);
+ WRAP_Open(CODEC_ID_H264);
   
 }
 decoderFFhuff::decoderFFhuff(uint32_t w,uint32_t h,uint32_t l,uint8_t *d)       :decoderFF(w,h) 
@@ -686,29 +452,14 @@ decoderFFhuff::decoderFFhuff(uint32_t w,uint32_t h,uint32_t l,uint8_t *d)
       _context->extradata=(void *)d;
       _context->extradata_size=(int)l;
       
-      if (avcodec_open(_context,& huffyuv_decoder) < 0)
-	      {
-					printf(" Decoder init: FFMpeg huffy_uv video decoder failed!\n");
-				}
-				else
-				{
-					printf(" Decoder init: FFMpeg huffy_uv video decoder initialized!\n");
-				}
-	
+     WRAP_Open(CODEC_ID_HUFFYUV);
 }
 decoderFFWMV2::decoderFFWMV2(uint32_t w,uint32_t h,uint32_t l,uint8_t *d)       :decoderFF(w,h)
 {
       _context->extradata=(void *)d;
       _context->extradata_size=(int)l;
       
-      if (avcodec_open(_context,& wmv2_decoder) < 0) 
-	      			{
-					printf(" Decoder init: FFMpeg WMV2 video decoder failed!\n");
-				}
-				else
-				{
-					printf(" Decoder init: FFMpeg WMV2 video decoder initialized!\n");		
-				}
+     WRAP_Open(CODEC_ID_WMV2);
 	
 }
 decoderFFcyuv::decoderFFcyuv(uint32_t w,uint32_t h,uint32_t l,uint8_t *d)       :decoderFF(w,h)
@@ -716,43 +467,20 @@ decoderFFcyuv::decoderFFcyuv(uint32_t w,uint32_t h,uint32_t l,uint8_t *d)
       _context->extradata=(void *)d;
       _context->extradata_size=(int)l;
 
-      if (avcodec_open(_context,& cyuv_decoder) < 0)
-	      			{
-					printf(" Decoder init: FFMpeg cyuv video decoder failed!\n");
-				}
-				else
-				{
-					printf(" Decoder init: FFMpeg cyuv video decoder initialized!\n");
-				}
-
+      WRAP_Open(CODEC_ID_CYUV);
 }
 decoderFFMJPEG::decoderFFMJPEG(uint32_t w,uint32_t h)       :decoderFF(w,h)
 {
-
-
-      if (avcodec_open(_context,& mjpeg_decoder) < 0)
-	      			{
-					printf(" Decoder init: FFMpeg mjpeg video decoder failed!\n");
-				}
-				else
-				{
-					printf(" Decoder init: FFMpeg mjpeg video decoder initialized!\n");
-				}
-
+            WRAP_Open(CODEC_ID_MJPEG);
 }
 decoderSnow::decoderSnow(uint32_t w,uint32_t h)       :decoderFF(w,h)
 {
-
-
-      if (avcodec_open(_context,& snow_decoder) < 0)
-	      			{
-					printf(" Decoder init: FFMpeg snow video decoder failed!\n");
-				}
-				else
-				{
-					printf(" Decoder init: FFMpeg snow video decoder initialized!\n");
-				}
-
+           WRAP_Open(CODEC_ID_SNOW);
+}
+decoderCamtasia::decoderCamtasia(uint32_t w,uint32_t h,uint32_t bpp)       :decoderFF(w,h)
+{
+           _context->bits_per_sample=bpp;
+           WRAP_Open(CODEC_ID_TSCC);
 }
 
 #endif
