@@ -44,6 +44,13 @@
 
 static char LogName[500];
 
+#define WRAP_Open(x) \
+{\
+AVCodec *codec=avcodec_find_encoder(x);\
+if(!codec) {GUI_Alert("Internal error opening codec"#x);ADM_assert(0);} \
+  res=avcodec_open(_context, codec); \
+  if(res<0) {GUI_Alert("Internal error with context for  codec"#x);ADM_assert(0);} \
+} 
 
 static myENC_RESULT res;
 ffmpegEncoder::ffmpegEncoder (uint32_t width, uint32_t height, FF_CODEC_ID id):encoder (width,
@@ -130,12 +137,17 @@ ffmpegEncoder::gopMpeg1 (void)
 {
   // small gop, 2 b frames allowed
   // min bitrate 500 max bitrate 2200
+int rate;
 
+        rate=_context->time_base.den;
+        rate=rate*1000;
+        rate/=_context->time_base.num;
 
+        _context->me_range=255; // Fix motion vector for picky players (pioneer)
 
   if (_id == FF_MPEG2)
     {
-      if (FRAME_FILM == identMovieType (_context->frame_rate))
+      if (FRAME_FILM == identMovieType (rate))
 	{
 	  printf ("\nPulldown activated...\n");
 	  _context->flags2 |= CODEC_FLAG2_32_PULLDOWN;
@@ -237,37 +249,37 @@ ffmpegEncoder::initContext (void)
   switch (_id)
     {
     case FF_MPEG4:
-      res = avcodec_open (_context, &mpeg4_encoder);
+      WRAP_Open(CODEC_ID_MPEG4);
       break;
     case FF_MSMP4V3:
-      res = avcodec_open (_context, &msmpeg4v3_encoder);
+      WRAP_Open(CODEC_ID_MSMPEG4V3);
       break;
     case FF_MPEG1:
-      res = avcodec_open (_context, &mpeg1video_encoder);
+      WRAP_Open(CODEC_ID_MPEG1VIDEO);
       break;
     case FF_MPEG2:
-      res = avcodec_open (_context, &mpeg2video_encoder);
+      WRAP_Open(CODEC_ID_MPEG2VIDEO);
       break;
     case FF_H263:
-      res = avcodec_open (_context, &h263_encoder);
+      WRAP_Open(CODEC_ID_H263);
       break;
     case FF_H263P:
-      res = avcodec_open (_context, &h263p_encoder);
+      WRAP_Open(CODEC_ID_H263P);
       break;
     case FF_HUFF:
-      res = avcodec_open (_context, &huffyuv_encoder);
+      WRAP_Open(CODEC_ID_HUFFYUV);
       break;
     case FF_FFV1:
-      res = avcodec_open (_context, &ffv1_encoder);
+      WRAP_Open(CODEC_ID_FFV1);
       break;
     case FF_MJPEG:
-      res = avcodec_open (_context, &mjpeg_encoder);
+      WRAP_Open(CODEC_ID_MJPEG);
       break;
     case FF_FFHUFF:
-        res=avcodec_open (_context, &ffvhuff_encoder);
+        WRAP_Open(CODEC_ID_FFVHUFF);
         break;
     case FF_SNOW:
-      res = avcodec_open (_context, &snow_encoder);
+      WRAP_Open(CODEC_ID_SNOW);
       break;
     default:
       ADM_assert (0);
@@ -336,10 +348,11 @@ ffmpegEncoderCQ::init (uint32_t val, uint32_t fps1000, uint8_t vbr)
       _statfile = NULL;
 
     }
-
+ _context->time_base= (AVRational){1000,fps1000};
+/*
   _context->frame_rate_base = 1000;
   _context->frame_rate = fps1000;
-
+*/
   _context->bit_rate = 0;
   _context->bit_rate_tolerance = 1024 * 8 * 1000;
 
@@ -424,10 +437,11 @@ ffmpegEncoderCBR::init (uint32_t val, uint32_t fps1000)
 //
   _br = val;
   mplayer_init ();
-  _context->frame_rate_base = 1000;
-  _context->frame_rate = fps1000;
-
-  _context->bit_rate = _br;
+/*  _context->frame_rate_base = 1000;
+  _context->frame_rate = fps1000;*/
+_context->time_base= (AVRational){1000,fps1000};
+ 
+ _context->bit_rate = _br;
 
   printf ("--> br: %lu", _br);
 
@@ -442,18 +456,19 @@ uint8_t
   int32_t sz = 0;
 
   encodePreamble (in->data);
-  _context->bit_rate = _br;
+  _context->bit_rate = _br; // ???
 
 
   if ((sz = avcodec_encode_video (_context, out, _w * _h * 3, &_frame)) < 0)
     return 0;
   _last_coded_frame=_context->real_pict_num;
   *len = (uint32_t) sz;
-  res.out_quantizer =
-    (int) floor (_context->coded_frame->quality / (float) FF_QP2LAMBDA);
   if (flags)
-//               if(_context->key_frame)
     *flags = frameType ();
+
+  res.total_bits = sz * 8;      // bytes -> bits
+  res.out_quantizer = (int) floor (_context->coded_frame->quality / (float) FF_QP2LAMBDA);
+
   return 1;
 
 }
@@ -519,10 +534,10 @@ ffmpegEncoderVBR::init (uint32_t val, uint32_t fps1000)
   _qual = val;
   mplayer_init ();
 
-  _context->frame_rate_base = 1000;
-  _context->frame_rate = fps1000;
-
+//   _context->frame_rate_base = 1000;
+//   _context->frame_rate = fps1000;
 
+_context->time_base= (AVRational){1000,fps1000};
 
   /* If internal 2 passes mode is selected ... */
   _context->flags |= CODEC_FLAG_PASS2;
@@ -618,8 +633,9 @@ ffmpegEncoderVBRExternal::init (uint32_t val, uint32_t fps1000)
   _qual = val;
   mplayer_init ();
 
-  _context->frame_rate_base = 1000;
-  _context->frame_rate = fps1000;
+/*  _context->frame_rate_base = 1000;
+  _context->frame_rate = fps1000;*/
+  _context->time_base= (AVRational){1000,fps1000};
   _context->flags |= CODEC_FLAG_QSCALE;;
   _context->bit_rate = 0;
   _context->bit_rate_tolerance = 1024 * 8 * 1000;
@@ -808,8 +824,9 @@ ffmpegEncoderHuff::init (uint32_t val, uint32_t fps1000, uint8_t vbr)
   UNUSED_ARG (vbr);
   mplayer_init ();
 
-  _context->frame_rate_base = 1000;
-  _context->frame_rate = fps1000;
+_context->time_base= (AVRational){1000,fps1000};
+//   _context->frame_rate_base = 1000;
+//   _context->frame_rate = fps1000;
 
 
   _context->bit_rate = 0;
@@ -852,9 +869,9 @@ ffmpegEncoderFFHuff::init (uint32_t val, uint32_t fps1000, uint8_t vbr)
   UNUSED_ARG (vbr);
   mplayer_init ();
 
-  _context->frame_rate_base = 1000;
-  _context->frame_rate = fps1000;
-
+/*  _context->frame_rate_base = 1000;
+  _context->frame_rate = fps1000;*/
+_context->time_base= (AVRational){1000,fps1000};
 
   _context->bit_rate = 0;
   _context->bit_rate_tolerance = 1024 * 8 * 1000;
@@ -910,9 +927,9 @@ ffmpegEncoderFFV1::init (uint32_t val, uint32_t fps1000, uint8_t vbr)
   UNUSED_ARG (val);
   UNUSED_ARG (vbr);
   mplayer_init ();
-
-  _context->frame_rate_base = 1000;
-  _context->frame_rate = fps1000;
+_context->time_base= (AVRational){1000,fps1000};
+//   _context->frame_rate_base = 1000;
+//   _context->frame_rate = fps1000;
 
 
   _context->bit_rate = 0;
@@ -963,8 +980,9 @@ uint8_t
 
   _qual = (uint32_t) floor (f);
 
-  _context->frame_rate_base = 1000;
-  _context->frame_rate = fps1000;
+//   _context->frame_rate_base = 1000;
+//   _context->frame_rate = fps1000;
+_context->time_base= (AVRational){1000,fps1000};
   _context->flags = CODEC_FLAG_QSCALE;
   _context->bit_rate = 0;
   _context->bit_rate_tolerance = 1024 * 8 * 1000;
