@@ -14,15 +14,22 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
+#ifndef ADM_RGB16_H
+#define ADM_RGB16_H
 
+#include "ADM_colorspace/ADM_rgb.h"
  class decoderRGB16 : decoders
 {
      protected:
-      			                 uint8_t *planar;
+                                                uint8_t         *planar;
+                                                ColRgbToYV12    *color;
 
      public:
-						decoderRGB16(uint32_t w,uint32_t h);
-			virtual			~decoderRGB16();
-			virtual uint8_t 	uncompress(uint8_t *in,ADMImage *out,uint32_t len,uint32_t *flag=NULL);	
-		       uint8_t 			uncompressRGB24(uint8_t *in,ADMImage *out,uint32_t len);
+                                uint8_t         dontcopy(void) { return 1;} 
+                                                decoderRGB16(uint32_t w,uint32_t h);
+                        virtual	                ~decoderRGB16();
+                        virtual uint8_t         uncompress(uint8_t *in,ADMImage *out,uint32_t len,uint32_t *flag=NULL);	
+                        
 }   ;
+
+#endif
