@@ -47,13 +47,11 @@
 #include <gtk/gtk.h>
 # include <math.h>
 
-#include "callbacks.h"
-#include "avi_vars.h"
+#include "ADM_library/default.h"
 #include "ADM_gui2/support.h"
 #include "ADM_toolkit/toolkit_gtk.h"
 #include "ADM_toolkit/toolkit_gtk_include.h"
 #include "ADM_toolkit/toolkit.hxx"
-#include "ADM_library/default.h"
 
 #include "ADM_video/ADM_vidMSmooth_param.h"
 static GtkWidget	*create_dialog1 (void);
