@@ -27,7 +27,7 @@
 #include "avio.hxx"
 
 
-#include "avi_vars.h"
+#include "ADM_library/default.h"
 #include "ADM_toolkit/toolkit_gtk.h"
 #include "ADM_toolkit/toolkit_gtk_include.h"
 #include "ADM_toolkit/toolkit.hxx"
@@ -62,6 +62,7 @@ uint32_t numberOfVideoFrames;
 static uint32_t videoSize,videoBitrate;
 
 static uint32_t getPicSize(void);
+extern uint8_t         videoCodecSetFinalSize(uint32_t size);;
 //************************************
 void DIA_Calculator(uint32_t *sizeInMeg, uint32_t *avgBitrate )
 {
@@ -80,6 +81,8 @@ void DIA_Calculator(uint32_t *sizeInMeg, uint32_t *avgBitrate )
 		if(GTK_RESPONSE_APPLY==gtk_dialog_run(GTK_DIALOG(dialog)))
 		{
 			update();
+                        videoCodecSetFinalSize(videoSize);
+                        
 		}
 	else
 		{
@@ -127,7 +130,7 @@ void prepare( void )
 
 	// Now get audio info
 	track1=0;
-	if(audioProcessMode && currentaudiostream)
+	if(audioProcessMode() && currentaudiostream)
 	{
 		stream=buildFakeAudioFilter(currentaudiostream,
 				0, 0xffffffff);
@@ -158,7 +161,7 @@ uint32_t getPicSize(void)
 uint32_t size;
          AVDMGenericVideoStream *last;
                 last=getLastVideoFilter();
-                size=last->getInfo()->width*last->getInfo()->width;
+                size=last->getInfo()->width*last->getInfo()->height;
         
                 return size;
 }
@@ -200,8 +203,8 @@ aviInfo info;
 	}
 	else
 	{//AVI or OGM
-		s74=690;
-		s80=730;
+		s74=650;
+		s80=700;
 		dvd=4300;
 	}
 	
@@ -262,7 +265,7 @@ aviInfo info;
 	
 	// and compute
 	//
-	uint32_t videoSize;
+	//uint32_t videoSize;
 	
 	if(audioSize>=totalSize) sprintf(string,"** NO ROOM LEFT**");
 	else
@@ -292,7 +295,7 @@ aviInfo info;
                         // Fetch info from filter
                 
                         
-                        if(videoProcessMode)
+                        if(videoProcessMode())
                                 picSize=getPicSize();
                         else
                                 picSize=info.width*info.height;
