@@ -19,8 +19,6 @@
 #include "ADM_toolkit/toolkit_gtk_include.h"
 
 
-#include "callbacks.h"
-
 
 
 //#include "avi_vars.h"
@@ -31,7 +29,7 @@
 
 
 
-#include "ADM_gui/GUI_mux.h"
+#include "oplug_avi/GUI_mux.h"
 
 static GtkWidget	*create_dialog1 (void);
 
@@ -49,7 +47,8 @@ uint8_t  DIA_setUserMuxParam( int *mode, int *param, int *muxsize)
 	int ret=0;
 
                 dialog=create_dialog1();
-		gtk_transient(dialog);
+//		gtk_transient(dialog);
+                gtk_register_dialog(dialog);
                 switch(*mode)
                 	{
                    	case MUX_REGULAR:
@@ -95,6 +94,7 @@ uint8_t  DIA_setUserMuxParam( int *mode, int *param, int *muxsize)
 
 	        	        	*muxsize=ADJ_GET(spinbutton3);
             }
+        gtk_unregister_dialog(dialog);
 	gtk_widget_destroy(dialog);
 	 return ret;
 }
