@@ -11,8 +11,7 @@
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 # include <config.h>
-#include "callbacks.h"
-#include "avi_vars.h"
+#include "ADM_library/default.h"
 #include "ADM_gui2/support.h"
 #include "ADM_toolkit/toolkit_gtk.h"
 #include "ADM_toolkit/toolkit_gtk_include.h"
