@@ -15,17 +15,15 @@
 # include <math.h>
 # include <config.h>
 
-#include "callbacks.h"
-#include "avi_vars.h"
+#include "ADM_library/default.h"
 #include "ADM_gui2/support.h"
 #include "ADM_toolkit/toolkit_gtk.h"
 #include "ADM_toolkit/toolkit_gtk_include.h"
 #include "ADM_toolkit/toolkit.hxx"
 
-#include "ADM_library/default.h"
 #include "ADM_assert.h"
 #include "ADM_encoder/ADM_vidEncode.hxx"
-#include "ADM_gui/GUI_xvidparam.h"
+//#include "ADM_gui/GUI_xvidparam.h"
 #include "prefs.h"
 
 #ifdef USE_XX_XVID 
@@ -62,7 +60,8 @@ int  DIA_getXvidCompressParams(COMPRESSION_MODE * mode, uint32_t * qz,
 	gint r,b;
 
 	dialog=create_dialog1();
-	gtk_transient(dialog);
+//	gtk_transient(dialog);
+        gtk_register_dialog(dialog);
 
 	// set the right select button
  	switch (*mode)
@@ -133,6 +132,7 @@ int  DIA_getXvidCompressParams(COMPRESSION_MODE * mode, uint32_t * qz,
 		      				ADM_assert(0);
 				}
 	}
+        gtk_unregister_dialog(dialog);
 	gtk_widget_destroy(dialog);
 	return ret;
 
