@@ -415,15 +415,45 @@ uint32_t left,ww;
                 ww=_imageBuffer->_width;
                 left=0;
        }
-	
+	tmpImage->_colorspace=ADM_COLOR_YV12;
 	// Do pp, and use imageBuffer as intermediate buffer
 	if (!_videos[seg].decoder->uncompress (compBuffer, tmpImage, len, &flags))
 	    {
 	      printf ("\nEditor: Last Decoding2 failed for frame %lu\n",frame);
-	      return 0;
-	    }
-	// Quant ?
-	if(!tmpImage->quant || !tmpImage->_qStride)
+	       // Try to dupe previous frame
+                if(frame)
+                {             
+                        ADMImage *prev; 
+                        prev=cache->getImage(frame-1);
+                        if(prev)
+                        {
+                                image->duplicate(prev);
+                                cache->updateFrameNum(image,frame);
+                                if(refOnly)
+                                        delete tmpImage;
+                                return 1;
+                        }
+                }
+                goto _next; 
+           }
+
+        // 
+        if(tmpImage->_noPicture && refOnly && frame)
+        {
+                // Try to grab previous image from buffer
+
+                ADMImage *prev; 
+                        prev=cache->getImage(frame-1);
+                        if(prev)
+                        {
+                                image->duplicate(prev);
+                                cache->updateFrameNum(image,frame);
+                                delete tmpImage;
+                                return 1;
+                        }
+        }
+	// If not quant and it is already YV12, we can stop here
+	if((!tmpImage->quant || !tmpImage->_qStride) && tmpImage->_colorspace==ADM_COLOR_YV12)
 	{      
 		image->_Qp=2;
 		image->duplicate(tmpImage);
@@ -457,10 +487,9 @@ uint32_t left,ww;
 	tmpImage->_Qp=image->_Qp=(uint32_t)floor(sum);
 	
 	// Pp deactivated ?
-	if(!_pp.postProcType || !_pp.postProcStrength)
-	{
-                // nothing to do
-		image->duplicate(tmpImage);
+	if(!_pp.postProcType || !_pp.postProcStrength || tmpImage->_colorspace!=ADM_COLOR_YV12)
+         {
+                dupe(tmpImage,image,&(_videos[seg]));
 		cache->updateFrameNum(image,frame);
                 if(refOnly) delete tmpImage;
 		aprintf("EdCache: Postproc disabled\n");
@@ -472,7 +501,9 @@ uint32_t left,ww;
 	if(tmpImage->flags & AVI_KEY_FRAME) type=1;
 		else if(tmpImage->flags & AVI_B_FRAME) type=3;
 			else type=2;
-	
+
+        ADM_assert(tmpImage->_colorspace==ADM_COLOR_YV12);
+
 	// we do postproc !
 	// keep
 	uint8_t *oBuff[3],*iBuff[3];
@@ -508,10 +539,18 @@ uint32_t left,ww;
                         strideTab[1]=strideTab2[1]=_info.width>>1;
                         strideTab[2]=strideTab2[2]=_info.width>>1;
                 }
+                if(_pp.swapuv)
+                {
         	        oBuff[0]= YPLANE(image);
-                        oBuff[1]= UPLANE(image);
-                        oBuff[2]= VPLANE(image);		
+                        oBuff[1]= VPLANE(image);
+                        oBuff[2]= UPLANE(image);		
+                }else
+                {
 
+                        oBuff[0]= YPLANE(image);
+                        oBuff[1]= UPLANE(image);
+                        oBuff[2]= VPLANE(image);                
+                }
 		 pp_postprocess(
 		 		iBuff,
 		 		strideTab,
@@ -574,7 +613,7 @@ uint32_t left,ww;
                         
 
                 }
-
+_next:
                 // update some infos
                 if(refOnly) delete tmpImage;
 		cache->updateFrameNum(image,frame);
@@ -582,20 +621,44 @@ uint32_t left,ww;
 		return 1;	
 
 }
-uint8_t ADM_Composer::setPostProc( int type, int strength, int swapuv)
+uint8_t ADM_Composer::dupe(ADMImage *src,ADMImage *dst,_VIDEOS *vid)
+{
+                if(src->_colorspace!=ADM_COLOR_YV12)
+                {
+                        // We need to do some colorspace conversion
+                        // Is there already one ?
+                        if(!vid->color)
+                        {
+                                vid->color=new COL_Generic2YV12(src->_width,src->_height,src->_colorspace);
+                        }
+                        // Since it is not YV12 it MUST be a ref
+                        ADM_assert(src->_isRef);
+                        vid->color->transform(src->_planes,src->_planeStride,dst->data);
+                        return 1;
+                }
+                // nothing to do
+                if(_pp.swapuv)
+                      dst->duplicateSwapUV(src);
+                else
+                        dst->duplicate(src);
+                return 1;
+}
+
+uint8_t ADM_Composer::setPostProc( uint32_t type, uint32_t strength, uint32_t swapuv)
 {
 	if(!_nb_video) return 0;
 	_pp.postProcType=type;
 	_pp.postProcStrength=strength;
+        _pp.swapuv=swapuv;
 	updatePostProc(&_pp); // DeletePostproc/ini missing ?
 	return 1;
 }
-uint8_t ADM_Composer::getPostProc( int *type, int *strength, int *swapuv)
+uint8_t ADM_Composer::getPostProc( uint32_t *type, uint32_t *strength, uint32_t *swapuv)
 {
 	if(!_nb_video) return 0;
 	*type=_pp.postProcType;
 	*strength=_pp.postProcStrength;
-	*swapuv=0;
+	*swapuv=_pp.swapuv;
 	return 1;
 }
 //______________________________________________
