@@ -24,18 +24,21 @@
 #include "fourcc.h"
 #include "avio.hxx"
 #include "ADM_editor/ADM_edit.hxx"
+#include "ADM_script/ADM_JSGlobal.h"
 #include "ADM_inpics/ADM_pics.h"
 #include "ADM_nuv/ADM_nuv.h"
 #include "ADM_h263/ADM_h263.h"
 #include "ADM_3gp/ADM_3gp.h"
 #include "ADM_openDML/ADM_openDML.h"
-#include "ADM_mpeg2dec/ADM_mpegscan.h"
 #include "ADM_toolkit/toolkit.hxx"
 #include "ADM_editor/ADM_edit.hxx"
 #include "ADM_video/ADM_genvideo.hxx"
 #include "ADM_filter/video_filters.h"
 #include "ADM_dialog/DIA_working.h"
 #include "ADM_ogm/ADM_ogm.h"
+#include "ADM_mpegdemuxer/dmx_video.h"
+#include "ADM_mpegdemuxer/dmx_identify.h"
+#include "ADM_mpegdemuxer/dmx_probe.h"
 #include "ADM_assert.h"
 #include "prefs.h"
 
@@ -46,20 +49,26 @@
 #ifdef USE_DIVX
 	#include "ADM_codecs/ADM_divx4.h"
 #endif
+#include "ADM_mpegdemuxer/dmx_indexer.h"
+#include "ADM_outputfmt.h"
+#include "ADM_gui2/GUI_ui.h"
 int DIA_mpegIndexer (char **mpegFile, char **indexFile, int *aid,
 		     int already = 0);
 void DIA_indexerPrefill(char *name);
 extern uint8_t indexMpeg (char *mpeg, char *file, uint8_t aid);
+
 extern uint8_t loadVideoCodecConf( char *name);
+extern uint8_t parseScript(char *name);
+const char *VBR_MSG="Avidemux detected VBR MP3 audio in this file. For keeping audio/video in sync, time map is needed. Build it now?\n\nYou can do it later with \"Audio -> Build VBR Time Map\".";
 //
 //
-int filterDefaultPPType=3;
-int filterDefaultPPStrength=3;
 
 #define TEST_MPEG2DEC
 
 ADM_Composer::ADM_Composer (void)
 {
+uint32_t type,value;
+
   _nb_segment = 0;
   _nb_video = 0;
   _total_frames = 0;
@@ -73,12 +82,20 @@ ADM_Composer::ADM_Composer (void)
   _haveMarkers=0; // only edl have markers
   // Initialize a default postprocessing (dummy)
   initPostProc(&_pp,16,16);
-  _pp.postProcType=filterDefaultPPType;
-  _pp.postProcStrength=filterDefaultPPStrength;
+  if(!prefs->get(DEFAULT_POSTPROC_TYPE,&type)) type=3;
+  if(!prefs->get(DEFAULT_POSTPROC_VALUE,&value)) value=3;
+
+  _pp.postProcType=type;
+  _pp.postProcStrength=value;
+  _pp.swapuv=0;
   _pp.forcedQuant=0;
   updatePostProc(&_pp);
   _imageBuffer=NULL;    
   _internalFlags=0;
+  // Start with a clean base
+  memset (_videos, 0, sizeof (_videos));
+  memset (_segments, 0, sizeof (_segments));
+  
 }
 /**
 	Remap 1:1 video to segments
@@ -100,6 +117,7 @@ uint8_t ADM_Composer::resetSeg( void )
 	}
 
   	_nb_segment=_nb_video;
+  	computeTotalFrames();
 	dumpSeg();
 	return 1;
 }
@@ -137,13 +155,14 @@ uint8_t ADM_Composer::getAudioExtra (uint32_t * l, uint8_t ** d)
 /**
 	Purge all segments
 */
-void
-ADM_Composer::deleteAllSegments (void)
+uint8_t ADM_Composer::deleteAllSegments (void)
 {
 
 
   memset (_segments, 0, sizeof (_segments));
   _nb_segment = 0;
+  _total_frames=computeTotalFrames();
+  return 1;
 
 }
 
@@ -166,6 +185,8 @@ ADM_Composer::deleteAllVideos (void)
       // if there is a video decoder...
       if (_videos[vid].decoder)
 	delete _videos[vid].decoder;
+      if(_videos[vid].color)
+        delete _videos[vid].color;
       // prevent from crashing
       _videos[vid]._aviheader->close ();
       delete _videos[vid]._aviheader;
@@ -176,6 +197,7 @@ ADM_Composer::deleteAllVideos (void)
 
   memset (_videos, 0, sizeof (_videos));
   
+  
   if(_imageBuffer)
   	delete _imageBuffer;
   _imageBuffer=NULL;
@@ -233,6 +255,7 @@ UNUSED_ARG(mode);
       		break;
       OPEN_AS (Mp4_FileType, mp4Header);
       OPEN_AS (H263_FileType, h263Header);
+      OPEN_AS (NewMpeg_FileType,dmxHeader);
       // For AVI we first try top open it as openDML
       case AVI_FileType:
       			_videos[_nb_video]._aviheader=new OpenDMLHeader; 
@@ -257,7 +280,6 @@ UNUSED_ARG(mode);
 		break;
 	}
       OPEN_AS (BMP_FileType, picHeader);
-      OPEN_AS (MpegIdx_FileType, mpeg2decHeader);
       OPEN_AS (_3GPP_FileType, _3GPHeader);
        OPEN_AS (Ogg_FileType, oggHeader);
 
@@ -267,86 +289,38 @@ UNUSED_ARG(mode);
 	ADM_assert(strlen(name)+5<256);;
 	strcpy(tmpname,name);
 	strcat(tmpname,".idx");
-	if(addFile(tmpname)) return 1;
-      // then propose to index it
-	{ unsigned int autoidx = 0;
-		prefs->get(FEATURE_TRYAUTOIDX,&autoidx);
-		if( autoidx ){
-		   mpegAudioTrack track[24];
-		   int tracknum = -1;
-		   int trackcount = 0;
-			if(MpegaudoDetectAudio(name,track)){
-				for(int i=0;i<8;i++){
-					if(track[i+8].presence){
-						tracknum = i;
-						trackcount++;
-					}
-					if(track[i].presence){
-						tracknum = 0xC0 | i;
-						trackcount++;
-					}
-					if(track[i+16].presence){
-						tracknum = 0xA0 | i;
-						trackcount++;
-					}
-				}
-				if( trackcount == 0 ){
-					printf("\nNo audio tracks found. Autoindex aborted ...\n");
-				}else if( trackcount > 1 ){
-					printf("\nMore than one audio track found. Autoindex aborted ...\n");
-				}else{
-					if(indexMpeg (name,tmpname,(uint8_t)tracknum)){
-						printf("\n re-opening %s\n",tmpname);
-						return addFile (tmpname, 0);
-					} // else goto GUI_Question
-				} // else goto GUI_Question
-			}else{ // no audio stream
-				if(indexMpeg (name,tmpname,0)){
-					printf("\n re-opening %s\n",tmpname);
-					return addFile (tmpname, 0); // memleak ?
-				} // else goto GUI_Question
-			}
-		}
-	}
-      if (GUI_Question ("This looks like mpeg\n Do you want to index it?"))
-	{
-	  char *	  idx, *	    mname;
-	  int	    track;
-
-	  DIA_indexerPrefill(name);
-	  if (DIA_mpegIndexer (&mname, &idx, &track, 1))
-	    {
-	      if ((mname == NULL) || (idx == NULL))
-		{
-		  GUI_Alert ("Select files!");
-
-		  return 0;
-		}
-	      printf ("\n indexing :%s to \n%s\n", mname, idx);
-
-
-	      if (indexMpeg (mname, idx, (uint8_t) track))
-	      {
-	      		printf("\n re-opening %s\n", idx);
-			return addFile (idx, 0);
-	      }
-	      return 0;
-
-	    }
-	}
-      return 0;
+        if(ADM_fileExist(tmpname))
+        {
+	       return addFile(tmpname);
+        }
+        if(tryIndexing(name))
+        {
+                return addFile (name);
+        }
+        return 0;
       break;
 	case WorkBench_FileType:
 
   		return loadWorbench(name);
+#if 0
+        case Script_FileType:
+                return parseScript(name);
+#endif
+	case ECMAScript_FileType:
+                printf("****** This is an ecmascript, run it with avidemux2 --run yourscript *******\n");
+                printf("****** This is an ecmascript, run it with avidemux2 --run yourscript *******\n");
+                printf("****** This is an ecmascript, run it with avidemux2 --run yourscript *******\n");
+                return 0;
+		
+                
     default:
       if (type == Unknown_FileType)
 	{
 	  printf ("\n not identified ...\n");
 	}
       else
-	printf
-	  ("\n successfully identified but no loader support detected...\n");
+	GUI_Error_HIG("File type identified but no loader support detected...",
+		"May be related to an old index file.");
       return 0;
     }
   // check opening was successful
@@ -365,11 +339,15 @@ UNUSED_ARG(mode);
   // 1st if it is our first video we update postproc
  if(!_nb_video)
  {
- 	
+        uint32_t type,value;
+
+        if(!prefs->get(DEFAULT_POSTPROC_TYPE,&type)) type=3;
+        if(!prefs->get(DEFAULT_POSTPROC_VALUE,&value)) value=3; 	
+
 	deletePostProc(&_pp );
  	initPostProc(&_pp,info.width,info.height);
-	_pp.postProcType=filterDefaultPPType;
-	_pp.postProcStrength=filterDefaultPPStrength;
+	_pp.postProcType=type;
+	_pp.postProcStrength=value;
 	_pp.forcedQuant=0;
 	updatePostProc(&_pp);
 
@@ -402,47 +380,13 @@ float duration;
       _videos[_nb_video]._audio_size =_videos[_nb_video]._audiostream->getLength ();
      
       
-	// For mpeg2, try to guess if it is pulldowned material
-	double duration_a, duration_v;
-	double rdirect, rpulldown;
 	
-	duration_a=_videos[_nb_video]._audio_size;
-	duration_a/=_wavinfo->byterate;   // now we got duration in seconds
-	
-	// ditto for video
-	duration_v= _videos[_nb_video]._nb_video_frames;
-	duration_v/=info.fps1000;
-	duration_v*=1000;
-	
-	printf("Audio : %f video : %f\n",duration_a,duration_v);
-	if(MpegIdx_FileType==type && info.fps1000>29000 && info.fps1000<30000
-		 && duration_a>1 && duration_v>1)
-	{
-		rdirect=(duration_a-duration_v)/duration_v;
-		if(rdirect<0) rdirect=-rdirect;
-		
-		rpulldown=((duration_a*0.8)-duration_v)/duration_v;
-		if(rpulldown<0) rpulldown=-rpulldown;
-		
-		
-		printf("Direct : %f pd : %f\n",rdirect,rpulldown);
-		if( rdirect*2> rpulldown)
-		{
-			printf("Probably pulldowned, switching to 23.976 \n");
-			 AVIStreamHeader *ily =	_videos[_nb_video]._aviheader->	getVideoStreamHeader ();
-      				ily->dwRate = 23976;
-      				ily->dwScale = 1000;
-				info.fps1000=23976;	
-		
-		}
-		
-	
-	}
 	duration=_videos[_nb_video]._nb_video_frames;
 	duration/=info.fps1000;
 	duration*=1000;			// duration in seconds
 	duration*=_wavinfo->frequency;  	// In sample
 	_videos[_nb_video]._audio_duration=(uint64_t)floor(duration);
+       
 
     }
 
@@ -473,7 +417,19 @@ float duration;
   _segments[_nb_segment]._nb_frames   =   _videos[_nb_video]._nb_video_frames ;
 
   _videos[_nb_video]._isAudioVbr=0;
+//****************************
+   
+
   // next one please
+        if(_wavinfo)
+        if(_wavinfo->encoding==WAV_MP3 && _wavinfo->blockalign==1152)
+        {
+                if(GUI_Confirmation_HIG("Build Time Map", "Build VBR time map?", VBR_MSG))
+                {
+                _videos[_nb_video]._isAudioVbr=_videos[_nb_video]._audiostream->buildAudioTimeLine ();
+                }
+        }
+
 	_nb_video++;
 	_nb_segment++;
 
@@ -536,19 +492,20 @@ TryAgain:
 					//printf(" %lu : %lu \n",i,flag2);
 					if(flag2 & AVI_B_FRAME)
 					{
-						printf(" %lu is a b frame\n",i);
+						printf(" * ");
 					 	bframe=1;
 						vid->_aviheader->getFlags(i,&flags);
 						if(!(flags & AVI_B_FRAME))
                                                 {
+                                                        printf("Frame %lu is A B frame, flag not ok\n",i);
 							bconsistency=0;
                                                 }
 						else
-							printf("\n and flags is ok\n");
+							printf("# ");
 					}
-					
+					if((i%16)==15) printf("\n");
 				}
-
+                                printf("\n");
 				delete  buffer;
 				delete [] bufferin;
 				if(getEnv(ENV_EDITOR_BFRAME))
@@ -602,8 +559,8 @@ TryAgain:
 								// can only unpack avi
 								if(!count && type==AVI_FileType)
 								{
-									if( forced || GUI_Question(
-									"It looks like Vop packed divx.\n"
+									if( forced || GUI_YesNo(
+									"Packed Bitstream detected",
 									"Do you want me to unpack it ?"))
 									{
 									OpenDMLHeader *dml=NULL;
@@ -612,22 +569,30 @@ TryAgain:
 									// Can we repack it ?
 									if(dml->unpackPacked())
 									{
+                                                                                // Set ouput to avi vop
+                                                                                UI_SetCurrentFormat(ADM_AVI_UNP);
+                                                                                // Create a new decoder
+                                                                                // As the current one have already decoded
+                                                                                // some pics
+                                                                                delete  _videos[_nb_video-1].decoder;
+                                                                                _videos[_nb_video-1].decoder=NULL;
+                                                                                printf("Creating fresh decoder\n");
+                                                                                 _videos[_nb_video-1].decoder = getDecoder (info.fcc,
+                                           info.width, info.height, l, d);
 										goto TryAgain;
 									}
-									GUI_Alert("Could not unpack it\n"
-									", using backup decoder= not frame accurate.");
+									GUI_Error_HIG("Could not unpack the video", "Using backup decoder - not frame accurate.");
 									}
 								}
 #if  1 //def USE_DIVX
-
+                                                                if(count)
+                                                                        GUI_Info_HIG(ADM_LOG_IMPORTANT,"Weird", "The unpacking succeedeed but the index is still not up to date.");
 								printf("\n Switching codec...\n");
 								delete vid->decoder;
-								vid->decoder=getDecoderVopPacked(info.fcc,
-																   info.width,
-																   info.height,0,NULL);
+								vid->decoder=getDecoderVopPacked(info.fcc, info.width,info.height,0,NULL);
 								ispacked=1;
 #else
-								GUI_Alert("Troubles ahead : This a vop packed avi..");
+								GUI_Info_HIG(ADM_LOG_IMPORTANT,"Troubles ahead", "This a VOP packed AVI.");
 #endif
 
 							}
@@ -635,7 +600,12 @@ TryAgain:
 						}
 						// else warn user
 						if(!ispacked)
-							GUI_Alert("\n Please used Misc->Rebuild frame for BFrames!");
+                                                {
+                                                        if(GUI_YesNo("Index is not up to date","You should use Tool->Rebuild frame. Do it now ?"))
+                                                        {
+                                                                rebuildFrameType();
+							}
+                                                }
 					}
 				}
 				else
@@ -644,7 +614,6 @@ TryAgain:
 				}
 		printf(" End of B-frame check\n");
 		}
-
   return 1;
 }
 /**
@@ -674,6 +643,17 @@ _VIDEOS *vid;
 	}
 	return 1;
 }
+/*
+        If one of the videos has VBR audio we handle the whole editor audio has VBR
+        If it is CBR, it is not harmful 
+        and it avoid loosing the VBR info in case we do VBR time map upon loading
+*/
+uint8_t ADM_Composer::hasVBRVideos(void)
+{
+        for(int i=0;i<_nb_video;i++)
+                if(_videos[i]._isAudioVbr) return 1;
+        return 0;
+}
 /**
 	Set decoder settings (post process/swap u&v...)
 	for the segment referred by frame
@@ -711,7 +691,46 @@ uint8_t ADM_Composer::cleanup (void)
   _total_frames = 0;
   return 1;
 }
+/*
+        param:
+                source : source #
+                start : start frame in source #
+                nb    : nb frame to copy into segment
+*/
+uint8_t ADM_Composer::addSegment(uint32_t source,uint32_t start, uint32_t nb)
+{
+        // do some sanity check
+        if(_nb_segment==MAX_SEG-1)
+        {
+                printf("[editor] Too many segments %d\n",_nb_segment);
+                return 0;
+        }
+        if(_nb_video<=source)
+        {
+                printf("[editor]: No such source %d/%d\n",source,_nb_video);
+                 return 0;
+        }
+        if(_videos[source]._nb_video_frames<=start)
+        {
+                printf("[editor]:start out of bound %d/%d\n",start,_videos[source]._nb_video_frames);
+                 return 0;
+        }
+        if(_videos[source]._nb_video_frames<start+nb)
+        {
+                printf("[editor]:end out of bound %d/%d\n",start+nb,_videos[source]._nb_video_frames);
+                 return 0;
+        }
+        // ok, let's go
+        _SEGMENT *seg=&(_segments[_nb_segment]);
+        seg->_reference=source;
+        seg->_start_frame=start;
+        seg->_nb_frames=nb;
+        _nb_segment++;
+        updateAudioTrack (_nb_segment-1);
+        _total_frames=computeTotalFrames();
 
+        return 1;
+}
 /**
 ______________________________________________________
 //  Remove frames , the frame are given as seen by GUI
@@ -787,6 +806,75 @@ uint8_t ADM_Composer::removeFrames (uint32_t start, uint32_t end)
   return 1;
 
 }
+//******************************
+// Select audio track
+//
+//******************************
+uint8_t ADM_Composer::getAudioStreamsInfo(uint32_t frame,uint32_t *nbStreams, uint32_t **infos)
+{
+uint32_t seg,rel,reference;
+
+        if (!convFrame2Seg (frame, &seg, &rel))
+        {
+                printf("Editor : frame2seg failed (%u)\n",frame);
+                return 0;
+        }
+        reference=_segments[seg]._reference;
+        return _videos[reference]._aviheader->getAudioStreamsInfo(nbStreams,infos);
+}
+/*
+        Change the audio track for the source video attached to the "frame" frame
+
+*/
+uint32_t ADM_Composer::getCurrentAudioStreamNumber(uint32_t frame)
+{
+uint32_t   seg,rel,reference;
+
+        if (!convFrame2Seg (frame, &seg, &rel))
+        {
+                printf("Editor : frame2seg failed (%u)\n",frame);
+                return 0;
+        }
+        reference=_segments[seg]._reference;
+        return _videos[reference]._aviheader->getCurrentAudioStreamNumber();
+}
+uint8_t ADM_Composer::changeAudioStream(uint32_t frame,uint32_t newstream)
+{
+uint32_t   seg,rel,reference;
+double     duration;
+WAVHeader *wav;
+aviInfo    info;
+
+        if (!convFrame2Seg (frame, &seg, &rel))
+        {
+                printf("Editor : frame2seg failed (%u)\n",frame);
+                return 0;
+        }
+        reference=_segments[seg]._reference;
+        if(!_videos[reference]._aviheader->changeAudioStream(newstream))
+        {
+                printf("Editor : stream change failed for frame %u seg %u stream %u\n",frame,seg,newstream);
+                return 0;
+        }
+        // Now update audio tracks infos
+        wav = _videos[reference]._aviheader->getAudioInfo ();
+        if(!wav)
+        {
+                ADM_assert(0); // Cannot change to a non existing track!
+        }
+        _videos[reference]._aviheader->getVideoInfo (&info);
+        _videos[reference]._aviheader->getAudioStream (&_videos[reference]._audiostream);
+        _videos[reference]._audio_size =_videos[reference]._audiostream->getLength ();
+        duration=_videos[reference]._nb_video_frames;
+        duration/=info.fps1000;
+        duration*=1000;                 // duration in seconds
+        duration*=wav->frequency;          // In sample
+        _videos[reference]._audio_duration=(uint64_t)floor(duration);
+        for(uint32_t i=0;i<_nb_segment;i++)
+                updateAudioTrack(i);
+        return 1;
+}
+
 /**
 ______________________________________________________
 //
@@ -1219,5 +1307,63 @@ uint8_t r=0;
 		return r;
 
 }
+//_________________________________________
+//    Try indexing the file, return 1 if file successfully indexed 
+//              0 else
+//_________________________________________
+extern uint8_t DIA_dmx(char *file,DMX_TYPE format,uint32_t nbTracks, MPEG_TRACK *tracks, uint32_t *selectedTracks);
+//
+uint8_t         ADM_Composer::tryIndexing(char *name)
+{
+ unsigned int autoidx = 0;
+      prefs->get(FEATURE_TRYAUTOIDX,&autoidx);
+      if (!autoidx)
+        {
+          if (!GUI_Question ("This looks like mpeg\n Do you want to index it?"))
+            {
+                return 0;
+            }
+		}  
+          char      *idx;
+          DMX_TYPE  type;
+          uint32_t  nbTrack=0,audioTrack=0;
+          MPEG_TRACK *tracks=NULL;
+          uint8_t r=1;
+
+                if(!dmx_probe(name,&type,&nbTrack,&tracks))
+                {
+                        printf("This is not mpeg\n");
+                        return 0;
+                }
+
+          
+                if(type==DMX_MPG_PS || type==DMX_MPG_TS)
+                {
+                       if(nbTrack>2)
+		       if(autoidx)
+			{
+				printf("Using autoindex\n");
+			}else
+		       {
+                        if(!DIA_dmx(name,type,nbTrack,tracks,&audioTrack))
+                        {
+                                delete [] tracks;
+                                return 0;
+                        }
+		       }
+                }
+                idx=new char[strlen(name)+5];
+                strcpy(idx,name);
+                strcat(idx,".idx");
+
+                r=dmx_indexer(name,idx,audioTrack,0,nbTrack,tracks);
+
+                if(tracks)
+                        delete [] tracks;
+                delete [] idx;
+
+                if(!r) GUI_Error_HIG("Indexing failed", NULL); 
+                return r;
+}
 //
 //
