@@ -34,7 +34,7 @@
 #include "ADM_toolkit/ADM_debugID.h"
 #define MODULE_NAME MODULE_PREVIEW
 #include "ADM_toolkit/ADM_debug.h"
-
+#include "ADM_toolkit/ADM_quota.h"
 //
 void updateVideoFilters( void );
 // exported vars
@@ -132,7 +132,7 @@ void registerFilter(const char *name,VF_FILTERS tag,uint8_t viewable
 }
 void registerFilterEx(const char *name,VF_FILTERS tag,uint8_t viewable
 		,AVDMGenericVideoStream *(*create) (AVDMGenericVideoStream *in, CONFcouple *)
-		,char *filtername,AVDMGenericVideoStream *(*create_from_script) (AVDMGenericVideoStream *in, int n,Arg *args))
+		,char *filtername,AVDMGenericVideoStream *(*create_from_script) (AVDMGenericVideoStream *in, int n,Arg *args),char *desc)
 {
         ADM_assert(nb_video_filter<(MAX_FILTER-1));
         allfilters[ nb_video_filter].name=name;
@@ -141,6 +141,7 @@ void registerFilterEx(const char *name,VF_FILTERS tag,uint8_t viewable
         allfilters[ nb_video_filter].viewable=viewable;
 	allfilters[ nb_video_filter].filtername=filtername;
 	allfilters[ nb_video_filter].create_from_script=create_from_script;
+        allfilters[ nb_video_filter].description=desc;
         nb_video_filter ++;
 
         if(viewable==1)
@@ -283,6 +284,25 @@ AVDMGenericVideoStream *filterCreateFromTag(VF_FILTERS tag,CONFcouple *couple, A
 			ADM_assert(0);
 			return NULL;                      
 }
+/*
+
+
+*/
+const char  *filterGetNameFromTag(VF_FILTERS tag)
+{
+
+                        ADM_assert(tag!=VF_INVALID);
+                        for(unsigned int i=0;i<nb_video_filter;i++)
+                                {
+                                        if(tag==allfilters[i].tag)
+                                                {
+                                                        return allfilters[i].name;
+                                                        
+                                                }
+                                }
+                        ADM_assert(0);
+                        return NULL;                      
+}
 /*____________________________________
 	Save and load current set of filters
 	
@@ -311,7 +331,7 @@ void 	editorReignitPreview( void )
 		unpackd=NULL;		
 	    }
 	    unpackd=new ADMImage(preview->getInfo()->width,preview->getInfo()->height);
-            GUI_PreviewInit(preview->getInfo()->width,preview->getInfo()->height);
+            GUI_PreviewInit(preview->getInfo()->width,preview->getInfo()->height,0);
 }
 
 
@@ -427,7 +447,7 @@ uint8_t 	filterAddScript(VF_FILTERS tag,uint32_t n,Arg *args)
 				printf("That filter cannot be created from script\n");
 				return 0;
 			}
-			filter=allfilters[i].create_from_script(videofilters[0].filter,n-1,&(args[1]));
+			filter=allfilters[i].create_from_script(videofilters[nb_active_filter-1].filter,n-1,&(args[1]));
 			if(!filter) return 0;
 			videofilters[nb_active_filter].filter=filter;
 			videofilters[nb_active_filter].tag=tag;						
@@ -448,9 +468,14 @@ FILE *f;
 
 		f=fopen(name,"wt");
 		if(!f)
-		{ 	GUI_Alert("Cannot write file!");
+		{ 	GUI_Error_HIG("File error", "Cannot open \"%s\" for writing.", GetFileName(name));
 			return;
 		}
+                filterSaveScriptFD(f);
+                fclose(f);
+}
+void filterSaveScriptFD(FILE *f)
+{
 		for(int i=1;i<nb_active_filter;i++)
 		{
 			VF_FILTERS tag=videofilters[i].tag;
@@ -478,6 +503,37 @@ FILE *f;
 			fprintf(f,");\n");			
 		
 		}
-		fclose(f);
-}		
+		
+}	
+void filterSaveScriptJS(FILE *f)
+{
+                for(int i=1;i<nb_active_filter;i++)
+                {
+                        VF_FILTERS tag=videofilters[i].tag;
+                        qfprintf(f,"app.video.addFilter(");
+                        for(unsigned int j=0;j<nb_video_filter;j++)
+                                {
+                                        if(tag==allfilters[j].tag)
+                                        {       
+                                                qfprintf(f,"\"%s\"",allfilters[j].filtername);
+                                                break;  
+                                        }
+                                }
+                        // get args
+                        CONFcouple *couple;
+                        char *arg,*value;
+                        if(videofilters[i].filter->getCoupledConf( &couple))
+                        {
+                                for(int j=0;j<couple->getNumber();j++)
+                                {
+                                         couple->getEntry(j, &arg,&value);
+                                         qfprintf(f,",\"%s=%s\"",arg,value);
+                                }
+                                delete couple;
+                        }
+                        qfprintf(f,");\n");                      
+                
+                }
+                
+}               	
 // EOF
