@@ -31,6 +31,7 @@
 #endif
 
 #include "ADM_toolkit/toolkit.hxx"
+#include "ADM_toolkit/ADM_quota.h"
 #include <ADM_assert.h>
 
 #include "ADM_editor/ADM_edit.hxx"
@@ -47,6 +48,8 @@ extern FILTER  videofilters[MAX_FILTER];
 
 extern AVDMGenericVideoStream *filterCreateFromTag(VF_FILTERS tag,CONFcouple *couple, AVDMGenericVideoStream *in);
 extern void filterCleanUp( void );
+extern int qxmlSaveFormatFile(const char *filename, xmlDocPtr cur, int format);
+
 /*
 
   	Try to rebuild filter from text file
@@ -130,11 +133,7 @@ int max;
 		}
 
 		xmlSetDocCompressMode(xdoc,0);  // we want pure text
-		if( xmlSaveFormatFile(docname,xdoc,1) == -1 )
-		{
-			GUI_Alert("Error writing XML file");
-			return ;
-		}
+		qxmlSaveFormatFile(docname,xdoc,1);
 		xmlFreeDoc(xdoc);
 	return ;
 }
@@ -154,7 +153,7 @@ CONFcouple *couple;
 			xdoc=xmlParseFile(docname);
 			if(!xdoc)
 				{
-					GUI_Alert("Problem reading xml filters!");
+					GUI_Error_HIG("Problem reading XML filters", NULL);
 					return 0;
 				}
 			node=xdoc->children;
@@ -162,7 +161,7 @@ CONFcouple *couple;
 			if(nb_filters==-1)
 					{
 							xmlFreeDoc(xdoc);
-							GUI_Alert("No filter found!");
+							GUI_Error_HIG("No filter found", NULL);
 							return 0;
 					}
 
@@ -198,7 +197,7 @@ CONFcouple *couple;
 				subnode=nextByName(subnode ,(char *)"Filter");
 				if(!node)
 					{
-						GUI_Alert("Error searching Filter");
+						GUI_Error_HIG("Could not find a filter", NULL);
 						return 0;
 					}
 
@@ -206,7 +205,7 @@ CONFcouple *couple;
 				if(itag==-1)
 					{
 							xmlFreeDoc(xdoc);
-							GUI_Alert("No tag found!");
+							GUI_Error_HIG("No tag found", NULL);
 							return 0;
 					}
 				// now we got the tag
@@ -286,7 +285,7 @@ xmlNodePtr nextByName(xmlNodePtr node,char *name)
 					node=node->next;
 					if(!node)
 					{
-						GUI_Alert("Node not found");
+						GUI_Error_HIG("Node not found", NULL);
 						return NULL;
 					}
 				};
