@@ -45,6 +45,9 @@
 
 #include "ADM_toolkit/filesel.h"
 #include "ADM_editor/ADM_Video.h"
+#include "prefs.h"
+
+#define WOD(x) lookup_widget (guiRootWindow,#x)
 
 void frame2time(uint32_t frame, uint32_t fps, uint16_t * hh, uint16_t * mm,
 	   uint16_t * ss, uint16_t * ms);
@@ -68,7 +71,7 @@ static GtkWidget *guiVideoToggle=NULL;
 static GdkCursor *guiCursorBusy=NULL;
 static GdkCursor *guiCursorNormal=NULL;
 static gint	  guiCursorEvtMask=0;
-
+static void     volumeChange( void );
 // heek !
 static  GtkAdjustment *sliderAdjustment;
 // Needed for DND
@@ -76,7 +79,13 @@ extern void A_openAvi (char *name);
 extern void A_appendAvi (char *name);
 
 
-
+static void on_audio_change(void);
+static void on_video_change(void);
+static int update_ui=0;
+extern uint8_t AVDM_setVolume(int volume);
+#define AUDIO_WIDGET "comboboxAudio"
+#define VIDEO_WIDGET "comboboxVideo"
+#define FORMAT_WIDGET "comboboxFormat"
 //
 enum 
 {
@@ -153,34 +162,32 @@ buttonCallBack_S buttonCallback[]=
 	{"buttonMarkB"			,"clicked"		,ACT_MarkB},
 	{"buttonBegin"			,"clicked"		,ACT_Begin},
 	{"buttonEnd"			,"clicked"		,ACT_End},
-	{"buttonOpen"			,"clicked"		,ACT_OpenAvi},
-	{"buttonInfo"			,"clicked"		,ACT_AviInfo},
-	{"buttonSaveAvi"		,"clicked"		,ACT_SaveAvi},
+	{"menutoolbuttonOpen"		,"clicked"		,ACT_OpenAvi},
+	{"toolbuttonInfo"			,"clicked"		,ACT_AviInfo},
+	{"toolbuttonSave"		,"clicked"		,ACT_SaveAvi},
+
 	{"buttonFilters"		,"clicked"		,ACT_VideoParameter},
 	{"buttonAudioFilter"		,"clicked"		,ACT_AudioFilters},
 	{"buttonConfV"			,"clicked"		,ACT_VideoCodec},
 	{"buttonConfA"			,"clicked"		,ACT_AudioCodec},
-	{"buttonRecent"			,"clicked"		,ACT_RecentFiles},
+
 	{"buttonPrevBlack"		,"clicked"		,ACT_PrevBlackFrame},
 	{"buttonNextBlack"		,"clicked"		,ACT_NextBlackFrame},
 	{"buttonGotoA"			,"clicked"		,ACT_GotoMarkA},
 	{"buttonGotoB"			,"clicked"		,ACT_GotoMarkB},	
-	{"buttonBitrate"		,"clicked"		,ACT_Bitrate},	
+	{"toolbuttonCalc"		,"clicked"		,ACT_Bitrate},	
+
+	{"toggletoolbuttonPreview"	,"toggled"		,ACT_PreviewToggle},
+	{"toggletoolbuttonOutput"      ,"toggled"		,ACT_OuputToggle},
 
-	{"togglebuttonPreview"		,"toggled"		,ACT_PreviewToggle},
-	{"toggleOutput"			,"toggled"		,ACT_OuputToggle},
-	
-	
-		
-	{"togglebuttonVideo"		,"toggled"		,ACT_VideoModeToggle},
 	{"boxCurFrame"			,"editing_done"		,ACT_JumpToFrame},
 	{"boxCurFrame"			,"activate"		,ACT_JumpToFrame},
 	{"boxCurTime"			,"editing_done"		,ACT_TimeChanged},
-	{"togglebuttonAudio"		,"toggled"		,ACT_AudioModeToggle},
-	{"optionVCodec"			,"changed"		,ACT_VideoCodecChanged},
-	{"optionACodec"			,"changed"		,ACT_AudioCodecChanged}
-	
 
+        {"CheckButtonTimeshift"         ,"toggled"             ,ACT_TimeShift},
+        {"spinbuttonTimeShift"          ,"value_changed"       ,ACT_TimeShift}
+       // {"spinbuttonTimeShift"          ,"editing_done"       ,ACT_TimeShift}
+  
 };
 
 ///
@@ -198,6 +205,7 @@ uint8_t ret=0;
 		// and seek global sub entity
 		ret= bindGUI();		
 		if(ret) gtk_widget_show(guiRootWindow);
+                UI_purge();
 		// Set it as always low level
 		//gtk_window_set_keep_below(GTK_WINDOW(guiRootWindow), 1);
 		renderInit();
@@ -231,11 +239,13 @@ uint8_t  bindGUI( void )
 	
 	ADM_LOOKUP(guiCurTime,boxCurTime);
 	ADM_LOOKUP(guiTotalTime,labelTotalTime);
-	
-	ADM_LOOKUP(guiPreviewToggle,togglebuttonPreview);
-	ADM_LOOKUP(guiOutputToggle,toggleOutput);
+
+	ADM_LOOKUP(guiPreviewToggle,toggletoolbuttonPreview);
+	ADM_LOOKUP(guiOutputToggle,toggletoolbuttonOutput);
+#if 0
 	ADM_LOOKUP(guiAudioToggle,togglebuttonAudio);
 	ADM_LOOKUP(guiVideoToggle,togglebuttonVideo);
+#endif
 #undef ADM_LOOKUP
   // bind menu
  #define CALLBACK(x,y) gtk_signal_connect(GTK_OBJECT(lookup_widget(guiRootWindow,#x)), "activate", \
@@ -266,7 +276,10 @@ uint8_t  bindGUI( void )
 	gtk_signal_connect(GTK_OBJECT(lookup_widget(guiRootWindow,"boxCurFrame")), "focus_out_event", 	
                       GTK_SIGNAL_FUNC(UI_looseFocus),                   (void *) NULL);	 
 
-
+        
+        // navKey
+        gtk_signal_connect(GTK_OBJECT(lookup_widget(guiRootWindow,"hscaleSensitive")), "value_changed",   
+                      GTK_SIGNAL_FUNC(volumeChange),                   (void *) NULL);  
 
 
 		       
@@ -316,37 +329,48 @@ uint8_t  bindGUI( void )
 	// Finally add video codec...
 	uint32_t nbVid;
 	const char *name;
-	GtkWidget *menuv;
-		 menuv = gtk_menu_new ();
-		nbVid=encoderGetNbEncoder();
-		GtkWidget *vidWidget[nbVid];
-		printf("Found %d video encoder\n",nbVid);		       
-		for(uint32_t i=0;i<nbVid;i++)
-		{
-			name=encoderGetIndexedName(i);
-			vidWidget[i]=gtk_menu_item_new_with_mnemonic(name);
-  			gtk_widget_show (vidWidget[i]);
-  			gtk_container_add (GTK_CONTAINER (menuv), vidWidget[i]);
-		}
-	 gtk_option_menu_set_menu (GTK_OPTION_MENU (lookup_widget(guiRootWindow,"optionVCodec")), menuv);
-	// And A codec
-	// Finally add video codec...
-	uint32_t nbAud;
-	
-	GtkWidget *menua;
-		 menua = gtk_menu_new ();
-		nbAud=audioFilterGetNbEncoder();
-		GtkWidget *audWidget[nbAud];
-		printf("Found %d audio encoder\n",nbAud);		       
-		for(uint32_t i=0;i<nbAud;i++)
-		{
-			name=audioFilterGetIndexedName(i);
-			audWidget[i]=gtk_menu_item_new_with_mnemonic(name);
-  			gtk_widget_show (audWidget[i]);
-  			gtk_container_add (GTK_CONTAINER (menua), audWidget[i]);
-		}
-	 gtk_option_menu_set_menu (GTK_OPTION_MENU (lookup_widget(guiRootWindow,"optionACodec")), menua);
+        GtkComboBox     *combo_box;
+
+                nbVid=encoderGetNbEncoder();
+                combo_box=GTK_COMBO_BOX(lookup_widget(guiRootWindow,VIDEO_WIDGET));
+                gtk_combo_box_remove_text(combo_box,0);
+                printf("Found %d video encoder\n",nbVid);
+                for(uint32_t i=0;i<nbVid;i++)
+                {
+                        name=encoderGetIndexedName(i);
+                        gtk_combo_box_append_text      (combo_box,name);
+                }
+
+        gtk_combo_box_set_active(combo_box,0);
+        on_video_change();
+        // And A codec
+        // Finally add video codec...
+        uint32_t nbAud;
+
+                nbAud=audioFilterGetNbEncoder();
+                combo_box=GTK_COMBO_BOX(lookup_widget(guiRootWindow,AUDIO_WIDGET));
+                gtk_combo_box_remove_text(combo_box,0);
+                printf("Found %d audio encoder\n",nbAud);		       
+                for(uint32_t i=0;i<nbAud;i++)
+                {
+                        name=audioFilterGetIndexedName(i);
+                        gtk_combo_box_append_text      (combo_box,name);	
+                }
+        gtk_combo_box_set_active(combo_box,0);
+	on_audio_change();
+        // Format
+                 gtk_combo_box_set_active(GTK_COMBO_BOX(lookup_widget(guiRootWindow,FORMAT_WIDGET)),0);
+
     //
+        gtk_signal_connect(GTK_OBJECT(lookup_widget(guiRootWindow,VIDEO_WIDGET)), "changed",
+                       GTK_SIGNAL_FUNC(on_video_change),
+                       NULL);
+        gtk_signal_connect(GTK_OBJECT(lookup_widget(guiRootWindow,AUDIO_WIDGET)), "changed",
+                       GTK_SIGNAL_FUNC(on_audio_change),
+                       NULL);
+        
+        // Add initial recent files
+        UI_updateRecentMenu(  );
     //
     //CYB 2005.02.22: DND (START)
     // Set up avidemux as an available drag'n'drop target.
@@ -357,6 +381,10 @@ uint8_t  bindGUI( void )
     g_signal_connect(GTK_OBJECT(guiRootWindow), "drag_data_received",
         GTK_SIGNAL_FUNC(DNDDataReceived),NULL);
     //CYB 2005.02.22: DND (END)
+
+     // Allow shrink
+   //GTK_WINDOW ( guiRootWindow ) ->allow_shrink = FALSE;
+   //GTK_WINDOW ( guiDrawingArea ) ->allow_shrink = FALSE;
     return 1;
 
 }
@@ -393,6 +421,27 @@ if(_upd_in_progres) return;
  _upd_in_progres--;
    
 }
+
+void volumeChange( void )
+{
+GtkWidget *wid;
+GtkAdjustment *adj;
+int vol;
+
+
+if(_upd_in_progres) return;
+ _upd_in_progres++;
+
+        wid=lookup_widget(guiRootWindow,"hscaleSensitive");
+        adj=gtk_range_get_adjustment (GTK_RANGE(wid));
+        vol=(int)floor(adj->value+0.5);
+        AVDM_setVolume( vol);
+ _upd_in_progres--;
+   
+}
+
+
+
 void UI_setTitle(char *name)
 {
 	char title[1024];
@@ -550,7 +599,7 @@ char string[500];
 uint8_t UI_getPreviewToggleStatus( void )
 {                         //gtk_toggle_button_get_active
 
-	if(TRUE==gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(guiPreviewToggle))  )
+	if(TRUE==gtk_toggle_tool_button_get_active(GTK_TOGGLE_TOOL_BUTTON(guiPreviewToggle))  )
  		return 1;
    	else
     	return 0;
@@ -561,12 +610,44 @@ uint8_t UI_getPreviewToggleStatus( void )
 uint8_t UI_setPreviewToggleStatus( uint8_t status )
 {
 gint b;
+        update_ui=1;
 	 if(status) b=TRUE;
   	else			b=FALSE;
-     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(guiPreviewToggle),b);
-
+     gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON(guiPreviewToggle),b);
+        // Update checkbox
+     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(WOD(preview1)),status);
+        update_ui=0;
 
 }
+///
+///     Return status of preview button toggle
+///     1-> Activated
+///     0-> deActivated
+
+uint8_t UI_getOutputToggleStatus( void )
+{                         //gtk_toggle_button_get_active
+
+        if(TRUE==gtk_toggle_tool_button_get_active(GTK_TOGGLE_TOOL_BUTTON(guiOutputToggle))  )
+                return 1;
+        else
+        return 0;
+}
+///
+///     Update the preview button toggle
+///
+uint8_t UI_setOutputToggleStatus( uint8_t status )
+{
+gint b;
+        update_ui=1;
+         if(status) b=TRUE;
+        else                    b=FALSE;
+     gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON(guiOutputToggle),b);
+        // Update checkbox
+     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(WOD(display_output1)),status);
+        update_ui=0;
+
+}
+
 /**
 	Set/unset the toggle button audio process
 */
@@ -576,8 +657,8 @@ gint b;
 	 if(status) b=TRUE;
   	else			b=FALSE;
 
-	if(b!=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(guiAudioToggle)))
-     		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(guiAudioToggle),b);
+	if(b!=gtk_toggle_tool_button_get_active(GTK_TOGGLE_TOOL_BUTTON(guiAudioToggle)))
+     		gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON(guiAudioToggle),b);
 	aprintf("++ audio toggle : %d(%d)\n",b,status);
 
 }
@@ -589,9 +670,9 @@ void UI_setVProcessToggleStatus( uint8_t status )
 gint b;
 	 if(status) 		b=TRUE;
   	else			b=FALSE;
-	if(b!=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(guiVideoToggle)))
+	if(b!=gtk_toggle_tool_button_get_active(GTK_TOGGLE_TOOL_BUTTON(guiVideoToggle)))
 	{
-     		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(guiVideoToggle),b);
+     		gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON(guiVideoToggle),b);
 		aprintf("Changing it to %d\n",b);
 	}
 	aprintf("++ video toggle : %d\n",b);
@@ -606,6 +687,7 @@ void guiCallback(GtkMenuItem * menuitem, gpointer user_data)
     UNUSED_ARG(menuitem);
     Action act;
     uint32_t aint;
+    if(update_ui) return; // no event sent
 
     aint = (long int) user_data;
     act = (Action) aint;
@@ -664,26 +746,70 @@ void UI_BusyCursor( void )
 */	
 
 	
+}
+void on_video_change(void)
+{
+int enable;
+        if(update_ui)
+        {
+                printf("Updating\n");
+                 return;
+        }
+
+        if(!UI_getCurrentVCodec()) // copy ?
+        {
+                enable=0;
+        }
+        else enable=1;
+        gtk_widget_set_sensitive(lookup_widget(guiRootWindow,"buttonConfV"),enable);        
+        gtk_widget_set_sensitive(lookup_widget(guiRootWindow,"buttonFilters"),enable);        
+        HandleAction(ACT_VideoCodecChanged);
+}
+void on_audio_change(void)
+{
+int enable;
+       if(update_ui) return;
+        if(!UI_getCurrentACodec()) // copy ?
+        {
+                enable=0;
+        }
+        else enable=1;
+        gtk_widget_set_sensitive(lookup_widget(guiRootWindow,"buttonConfA"),enable);        
+        gtk_widget_set_sensitive(lookup_widget(guiRootWindow,"buttonAudioFilter"),enable);        
+        HandleAction(ACT_AudioCodecChanged);
+
 }
  int 	UI_getCurrentACodec(void)
  {
- 	return getRangeInMenu(lookup_widget(guiRootWindow,"optionACodec"));
+        //return getRangeInMenu(lookup_widget(guiRootWindow,AUDIO_WIDGET));
+        return gtk_combo_box_get_active(GTK_COMBO_BOX(lookup_widget(guiRootWindow,AUDIO_WIDGET)));
  
  }
  int 	UI_getCurrentVCodec(void)
  {
  
- 	return getRangeInMenu(lookup_widget(guiRootWindow,"optionVCodec"));
+ 	//return getRangeInMenu(lookup_widget(guiRootWindow,VIDEO_WIDGET));
+        return gtk_combo_box_get_active(GTK_COMBO_BOX(lookup_widget(guiRootWindow,VIDEO_WIDGET)));
  
  }
+
 void UI_setAudioCodec( int i)
 {
-	gtk_option_menu_set_history(GTK_OPTION_MENU(lookup_widget(guiRootWindow,"optionACodec")), i);
-
+        //gtk_option_menu_set_history(GTK_OPTION_MENU(lookup_widget(guiRootWindow,AUDIO_WIDGET)), i);
+        update_ui=1;
+        gtk_combo_box_set_active(GTK_COMBO_BOX(lookup_widget(guiRootWindow,AUDIO_WIDGET)),i);
+        gtk_widget_set_sensitive(lookup_widget(guiRootWindow,"buttonConfA"),i);        
+        gtk_widget_set_sensitive(lookup_widget(guiRootWindow,"buttonAudioFilter"),i);        
+        update_ui=0;
 }
 void UI_setVideoCodec( int i)
 {
-	gtk_option_menu_set_history(GTK_OPTION_MENU(lookup_widget(guiRootWindow,"optionVCodec")), i);
+        //gtk_option_menu_set_history(GTK_OPTION_MENU(lookup_widget(guiRootWindow,VIDEO_WIDGET)), i);
+        update_ui=1;
+        gtk_combo_box_set_active(GTK_COMBO_BOX(lookup_widget(guiRootWindow,VIDEO_WIDGET)),i);
+        gtk_widget_set_sensitive(lookup_widget(guiRootWindow,"buttonConfV"),i);        
+        gtk_widget_set_sensitive(lookup_widget(guiRootWindow,"buttonFilters"),i);        
+        update_ui=0;
 
 }
 
@@ -703,12 +829,12 @@ void UI_PrintCurrentVCodec(const char *str)
 ADM_OUT_FORMAT UI_GetCurrentFormat( void )
 {
 
-	return (ADM_OUT_FORMAT) getRangeInMenu(lookup_widget(guiRootWindow,"optionmenu1"));
+	return (ADM_OUT_FORMAT)gtk_combo_box_get_active(GTK_COMBO_BOX(lookup_widget(guiRootWindow,FORMAT_WIDGET)));
 }
 uint8_t UI_SetCurrentFormat( ADM_OUT_FORMAT fmt )
 {
 
-	gtk_option_menu_set_history(GTK_OPTION_MENU(lookup_widget(guiRootWindow,"optionmenu1")), fmt);
+	 gtk_combo_box_set_active(GTK_COMBO_BOX(lookup_widget(guiRootWindow,FORMAT_WIDGET)),fmt);
 	return 1;
 }
 // DND CYB
@@ -761,5 +887,74 @@ void DNDDataReceived( GtkWidget *widget, GdkDragContext *dc,
     }
     gtk_drag_finish(dc,TRUE,FALSE,t);
 }
+void UI_toogleMain(void)
+{
+static int show=1;
+        show=show^1;
+        if(!show)
+                gtk_widget_hide(GTK_WIDGET(lookup_widget(guiRootWindow,"toolbar2")) );
+        else
+                gtk_widget_show(GTK_WIDGET(lookup_widget(guiRootWindow,"toolbar2")) );
+}
+void UI_toogleSide(void)
+{
+static int show=1;
+        show=show^1;
+        if(!show)
+                gtk_widget_hide(GTK_WIDGET(lookup_widget(guiRootWindow,"vbox9")));
+        else
+                gtk_widget_show(GTK_WIDGET(lookup_widget(guiRootWindow,"vbox9")));
+}
+uint8_t UI_getTimeShift(int *onoff,int *value)
+{
+
+        *onoff=gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (lookup_widget(guiRootWindow,"CheckButtonTimeshift")));
+        *value=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(lookup_widget(guiRootWindow,"spinbuttonTimeShift"))) ;
+        return 1;
+}
+uint8_t UI_setTimeShift(int onoff,int value)
+{
+
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (lookup_widget(guiRootWindow,"CheckButtonTimeshift")),onoff);
+        gtk_spin_button_set_value(GTK_SPIN_BUTTON(lookup_widget(guiRootWindow,"spinbuttonTimeShift")),value) ;
+        return 1;
+}
+uint8_t UI_updateRecentMenu( void )
+{
+const char **names;
+uint32_t nb_item=0;
+GtkWidget *button,*menu,*item[4];
+static Action recent[4]={ACT_RECENT0,ACT_RECENT1,ACT_RECENT2,ACT_RECENT3};
+
+        names=prefs->get_lastfiles();
+// count
+        for( nb_item=0;nb_item<4;nb_item++)
+        {
+                if(!names[nb_item]) break;
+        }
+        button=lookup_widget(guiRootWindow,"menutoolbuttonOpen");
+        if(!nb_item)
+        {
+                gtk_menu_tool_button_set_menu   (GTK_MENU_TOOL_BUTTON(button),NULL);
+                return 1;
+        }
+        menu=gtk_menu_new();
+        for(int i=0;i<nb_item;i++)
+        {
+                item[i]=gtk_menu_item_new_with_label(names[i]);
+                gtk_menu_attach(GTK_MENU(menu),item[i],0,1,i,i+1);
+                 gtk_signal_connect (GTK_OBJECT (item[i]), "activate", GTK_SIGNAL_FUNC (guiCallback), 
+                                (gpointer) recent[i]);
+                gtk_widget_show (item[i]);
+        }
+        gtk_menu_tool_button_set_menu   (GTK_MENU_TOOL_BUTTON(button),menu);
+        return 1;
+}
+
+uint8_t UI_shrink(uint32_t w,uint32_t h)
+{
+        gtk_widget_set_usize(guiRootWindow, w, h);
+        return 1;
+}
 
 // EOF
