@@ -19,6 +19,10 @@ void 	UI_setTitle(char *name);
 uint8_t UI_getPreviewToggleStatus( void );
 uint8_t UI_setPreviewToggleStatus( uint8_t status );
 
+uint8_t UI_getOutputToggleStatus( void );
+uint8_t UI_setOutputToggleStatus( uint8_t status );
+
+
 void UI_setAProcessToggleStatus( uint8_t status );
 void UI_setVProcessToggleStatus( uint8_t status );
 
@@ -35,5 +39,15 @@ void UI_setVideoCodec( int i);
 
 ADM_OUT_FORMAT 	UI_GetCurrentFormat( void );
 uint8_t 	UI_SetCurrentFormat( ADM_OUT_FORMAT fmt );
+
+void UI_toogleSide(void);
+void UI_toogleMain(void);
+
+uint8_t UI_getTimeShift(int *onoff,int *value);
+uint8_t UI_setTimeShift(int onoff,int value);
+
+uint8_t UI_updateRecentMenu( void );
+
+uint8_t UI_shrink(uint32_t w,uint32_t h);
 #endif
 // EOF
