@@ -56,7 +56,7 @@
 #include "ADM_audiofilter/audioprocess.hxx"
 #include "gui_action.hxx"
 #include "gtkgui.h"
-#include "ADM_gui/GUI_mux.h"
+//#include "ADM_gui/GUI_mux.h"
 #include "oplug_mpeg/op_mpeg.h"
 #include "oplug_mpegFF/oplug_vcdff.h"
 #include "ADM_audiofilter/audioeng_buildfilters.h"
@@ -103,7 +103,7 @@ void GUI_displayBitrate( void )
 	max=0;
 	if(!(frameEnd>frameStart))
 	{
-		GUI_Alert("No data!");
+		GUI_Error_HIG("No data", NULL);
 		return ;
 	}
 
@@ -135,7 +135,7 @@ void GUI_displayBitrate( void )
 	printf("\n Total : %lu bytes, max %d bytes round %d\n",total,max,round);
 	if(!max)
 	{
-		GUI_Alert("No data!");
+		GUI_Error_HIG("No data", NULL);
 		return ;
 	}
 	nb_frame=frameEnd-frameStart;
