@@ -260,7 +260,7 @@ uint8_t    h263Header::open(char *name)
 	{
 		default:
 			printf("\n incorrect size !\n");
-			GUI_Alert("Size is not (s)QCIF!");
+			GUI_Error_HIG("Size is not (s)QCIF", NULL);
 		
 		case 1:  w=128;h=96;break;
 		case 2:  w=176;h=144;break;
