@@ -93,7 +93,7 @@ lavMuxer::~lavMuxer()
 	close();
 }
 //___________________________________________________________________________
-uint8_t lavMuxer::open( char *filename, uint32_t inbitrate,ADM_MUXER_TYPE type, aviInfo *info, WAVHeader *audioheader)
+uint8_t lavMuxer::open(const char *filename, uint32_t inbitrate,ADM_MUXER_TYPE type, aviInfo *info, WAVHeader *audioheader)
 {
  AVCodecContext *c;
  	_type=type;
@@ -138,7 +138,7 @@ uint8_t lavMuxer::open( char *filename, uint32_t inbitrate,ADM_MUXER_TYPE type,
 		return 0;
 	}	
 	
-	c = &video_st->codec;
+	c = video_st->codec;
 	switch(_type)
 	{
                 case MUXER_TS:
@@ -198,8 +198,9 @@ uint8_t lavMuxer::open( char *filename, uint32_t inbitrate,ADM_MUXER_TYPE type,
     	switch(_fps1000)
 	{
 		case 25000:
-			c->frame_rate = 25025;  
-			c->frame_rate_base = 1001;	
+			 c->time_base= (AVRational){25025,1001};
+			//c->frame_rate = 25025;  
+			//c->frame_rate_base = 1001;	
 			break;
 		case 23976:
 /*
@@ -208,11 +209,12 @@ uint8_t lavMuxer::open( char *filename, uint32_t inbitrate,ADM_MUXER_TYPE type,
 			break;
 */
 		case  29970:
-			c->frame_rate = 30000;  
-			c->frame_rate_base = 1001;	
+			 c->time_base= (AVRational){30000,1001};
+			//c->frame_rate = 30000;  
+			//c->frame_rate_base = 1001;	
 			break;
 		default:
-			GUI_Alert("FPS is not suitable!");
+			GUI_Error_HIG("Incompatible frame rate", NULL);
 			return 0;
 	}
 
@@ -232,7 +234,7 @@ uint8_t lavMuxer::open( char *filename, uint32_t inbitrate,ADM_MUXER_TYPE type,
 	}
 
 		
-	c = &audio_st->codec;
+	c = audio_st->codec;
 	if(audioheader->encoding==WAV_AC3)
 		c->codec_id = CODEC_ID_AC3;
 	else
