@@ -47,6 +47,7 @@ typedef struct {
     int lpcm_align;
     uint8_t *fifo_iframe_ptr;
     int align_iframe;
+    int64_t vobu_start_pts;
 } StreamInfo;
 
 typedef struct {
@@ -76,7 +77,7 @@ typedef struct {
 #define PACKET_START_CODE_MASK      ((unsigned int)0xffffff00)
 #define PACKET_START_CODE_PREFIX    ((unsigned int)0x00000100)
 #define ISO_11172_END_CODE          ((unsigned int)0x000001b9)
-  
+
 /* mpeg2 */
 #define PROGRAM_STREAM_MAP 0x1bc
 #define PRIVATE_STREAM_1   0x1bd
@@ -89,22 +90,36 @@ typedef struct {
 #define AC3_ID   0x80
 #define DTS_ID   0x8a
 #define LPCM_ID  0xa0
+#define SUB_ID   0x20
+
+#define STREAM_TYPE_VIDEO_MPEG1     0x01
+#define STREAM_TYPE_VIDEO_MPEG2     0x02
+#define STREAM_TYPE_AUDIO_MPEG1     0x03
+#define STREAM_TYPE_AUDIO_MPEG2     0x04
+#define STREAM_TYPE_PRIVATE_SECTION 0x05
+#define STREAM_TYPE_PRIVATE_DATA    0x06
+#define STREAM_TYPE_AUDIO_AAC       0x0f
+#define STREAM_TYPE_VIDEO_MPEG4     0x10
+#define STREAM_TYPE_VIDEO_H264      0x1b
+
+#define STREAM_TYPE_AUDIO_AC3       0x81
+#define STREAM_TYPE_AUDIO_DTS       0x8a
 
 static const int lpcm_freq_tab[4] = { 48000, 96000, 44100, 32000 };
 
-#ifdef CONFIG_ENCODERS
+#ifdef CONFIG_MUXERS
 static AVOutputFormat mpeg1system_mux;
 static AVOutputFormat mpeg1vcd_mux;
 static AVOutputFormat mpeg2vob_mux;
 static AVOutputFormat mpeg2svcd_mux;
 static AVOutputFormat mpeg2dvd_mux;
 
-static int put_pack_header(AVFormatContext *ctx, 
+static int put_pack_header(AVFormatContext *ctx,
                            uint8_t *buf, int64_t timestamp)
 {
     MpegMuxContext *s = ctx->priv_data;
     PutBitContext pb;
-    
+
     init_put_bits(&pb, buf, 128);
 
     put_bits(&pb, 32, PACK_START_CODE);
@@ -146,7 +161,7 @@ static int put_system_header(AVFormatContext *ctx, uint8_t *buf,int only_for_str
     put_bits(&pb, 32, SYSTEM_HEADER_START_CODE);
     put_bits(&pb, 16, 0);
     put_bits(&pb, 1, 1);
-    
+
     put_bits(&pb, 22, s->mux_rate); /* maximum bit rate of the multiplexed stream */
     put_bits(&pb, 1, 1); /* marker */
     if (s->is_vcd && only_for_stream_id==VIDEO_ID) {
@@ -157,13 +172,13 @@ static int put_system_header(AVFormatContext *ctx, uint8_t *buf,int only_for_str
 
     if (s->is_vcd) {
         /* see VCD standard, p. IV-7*/
-        put_bits(&pb, 1, 0); 
+        put_bits(&pb, 1, 0);
         put_bits(&pb, 1, 1);
     } else {
         put_bits(&pb, 1, 0); /* variable bitrate*/
         put_bits(&pb, 1, 0); /* non constrainted bit stream */
     }
-    
+
     if (s->is_vcd || s->is_dvd) {
         /* see VCD standard p IV-7 */
         put_bits(&pb, 1, 1); /* audio locked */
@@ -180,24 +195,24 @@ static int put_system_header(AVFormatContext *ctx, uint8_t *buf,int only_for_str
         put_bits(&pb, 5, 0);
     } else
         put_bits(&pb, 5, s->video_bound);
-    
+
     if (s->is_dvd) {
         put_bits(&pb, 1, 0);    /* packet_rate_restriction_flag */
         put_bits(&pb, 7, 0x7f); /* reserved byte */
     } else
         put_bits(&pb, 8, 0xff); /* reserved byte */
-    
+
     /* DVD-Video Stream_bound entries
-    id (0xB9) video, maximum P-STD for stream 0xE0. (P-STD_buffer_bound_scale = 1) 
-    id (0xB8) audio, maximum P-STD for any MPEG audio (0xC0 to 0xC7) streams. If there are none set to 4096 (32x128). (P-STD_buffer_bound_scale = 0) 
-    id (0xBD) private stream 1 (audio other than MPEG and subpictures). (P-STD_buffer_bound_scale = 1) 
+    id (0xB9) video, maximum P-STD for stream 0xE0. (P-STD_buffer_bound_scale = 1)
+    id (0xB8) audio, maximum P-STD for any MPEG audio (0xC0 to 0xC7) streams. If there are none set to 4096 (32x128). (P-STD_buffer_bound_scale = 0)
+    id (0xBD) private stream 1 (audio other than MPEG and subpictures). (P-STD_buffer_bound_scale = 1)
     id (0xBF) private stream 2, NAV packs, set to 2x1024. */
     if (s->is_dvd) {
-        
+
         int P_STD_max_video = 0;
         int P_STD_max_mpeg_audio = 0;
         int P_STD_max_mpeg_PS1 = 0;
-        
+
         for(i=0;i<ctx->nb_streams;i++) {
             StreamInfo *stream = ctx->streams[i]->priv_data;
 
@@ -242,7 +257,7 @@ static int put_system_header(AVFormatContext *ctx, uint8_t *buf,int only_for_str
         private_stream_coded = 0;
         for(i=0;i<ctx->nb_streams;i++) {
             StreamInfo *stream = ctx->streams[i]->priv_data;
-            
+
 
             /* For VCDs, only include the stream info for the stream
             that the pack which contains this system belongs to.
@@ -308,7 +323,7 @@ static int get_system_header_size(AVFormatContext *ctx)
 static int mpeg_mux_init(AVFormatContext *ctx)
 {
     MpegMuxContext *s = ctx->priv_data;
-    int bitrate, i, mpa_id, mpv_id, ac3_id, dts_id, lpcm_id, j;
+    int bitrate, i, mpa_id, mpv_id, mps_id, ac3_id, dts_id, lpcm_id, j;
     AVStream *st;
     StreamInfo *stream;
     int audio_bitrate;
@@ -319,21 +334,22 @@ static int mpeg_mux_init(AVFormatContext *ctx)
     s->is_svcd = (ctx->oformat == &mpeg2svcd_mux);
     s->is_mpeg2 = (ctx->oformat == &mpeg2vob_mux || ctx->oformat == &mpeg2svcd_mux || ctx->oformat == &mpeg2dvd_mux);
     s->is_dvd = (ctx->oformat == &mpeg2dvd_mux);
-    
+
     if(ctx->packet_size)
         s->packet_size = ctx->packet_size;
     else
         s->packet_size = 2048;
-       
+
     s->vcd_padding_bytes_written = 0;
     s->vcd_padding_bitrate=0;
-        
+
     s->audio_bound = 0;
     s->video_bound = 0;
     mpa_id = AUDIO_ID;
     ac3_id = AC3_ID;
     dts_id = DTS_ID;
     mpv_id = VIDEO_ID;
+    mps_id = SUB_ID;
     lpcm_id = LPCM_ID;
     for(i=0;i<ctx->nb_streams;i++) {
         st = ctx->streams[i];
@@ -344,56 +360,59 @@ static int mpeg_mux_init(AVFormatContext *ctx)
 
         av_set_pts_info(st, 64, 1, 90000);
 
-        switch(st->codec.codec_type) {
+        switch(st->codec->codec_type) {
         case CODEC_TYPE_AUDIO:
-            if (st->codec.codec_id == CODEC_ID_AC3) {
+            if (st->codec->codec_id == CODEC_ID_AC3) {
                 stream->id = ac3_id++;
-            } else if (st->codec.codec_id == CODEC_ID_DTS) {
+            } else if (st->codec->codec_id == CODEC_ID_DTS) {
                 stream->id = dts_id++;
-            } else if (st->codec.codec_id == CODEC_ID_PCM_S16BE) {
+            } else if (st->codec->codec_id == CODEC_ID_PCM_S16BE) {
                 stream->id = lpcm_id++;
                 for(j = 0; j < 4; j++) {
-                    if (lpcm_freq_tab[j] == st->codec.sample_rate)
+                    if (lpcm_freq_tab[j] == st->codec->sample_rate)
                         break;
                 }
                 if (j == 4)
                     goto fail;
-                if (st->codec.channels > 8)
+                if (st->codec->channels > 8)
                     return -1;
                 stream->lpcm_header[0] = 0x0c;
-                stream->lpcm_header[1] = (st->codec.channels - 1) | (j << 4);
+                stream->lpcm_header[1] = (st->codec->channels - 1) | (j << 4);
                 stream->lpcm_header[2] = 0x80;
-                stream->lpcm_align = st->codec.channels * 2;
+                stream->lpcm_align = st->codec->channels * 2;
             } else {
                 stream->id = mpa_id++;
             }
 
             /* This value HAS to be used for VCD (see VCD standard, p. IV-7).
                Right now it is also used for everything else.*/
-            stream->max_buffer_size = 4 * 1024; 
+            stream->max_buffer_size = 4 * 1024;
             s->audio_bound++;
             break;
         case CODEC_TYPE_VIDEO:
             stream->id = mpv_id++;
-            if (st->codec.rc_buffer_size)
-                stream->max_buffer_size = 6*1024 + st->codec.rc_buffer_size/8;
+            if (st->codec->rc_buffer_size)
+                stream->max_buffer_size = 6*1024 + st->codec->rc_buffer_size/8;
             else
                 stream->max_buffer_size = 230*1024; //FIXME this is probably too small as default
 #if 0
                 /* see VCD standard, p. IV-7*/
-                stream->max_buffer_size = 46 * 1024; 
+                stream->max_buffer_size = 46 * 1024;
             else
                 /* This value HAS to be used for SVCD (see SVCD standard, p. 26 V.2.3.2).
                    Right now it is also used for everything else.*/
-                stream->max_buffer_size = 230 * 1024; 
+                stream->max_buffer_size = 230 * 1024;
 #endif
             s->video_bound++;
             break;
+        case CODEC_TYPE_SUBTITLE:
+            stream->id = mps_id++;
+            stream->max_buffer_size = 16 * 1024;
+            break;
         default:
             return -1;
         }
         fifo_init(&stream->fifo, 16);
-        stream->next_packet= &stream->premux_packet;
     }
     bitrate = 0;
     audio_bitrate = 0;
@@ -403,14 +422,14 @@ static int mpeg_mux_init(AVFormatContext *ctx)
         st = ctx->streams[i];
         stream = (StreamInfo*) st->priv_data;
 
-        if(st->codec.rc_max_rate || stream->id==VIDEO_ID)
-            codec_rate= st->codec.rc_max_rate;
+        if(st->codec->rc_max_rate || stream->id==VIDEO_ID)
+            codec_rate= st->codec->rc_max_rate;
         else
-            codec_rate= st->codec.bit_rate;
-                
+            codec_rate= st->codec->bit_rate;
+
         if(!codec_rate)
             codec_rate= (1<<21)*8*50/ctx->nb_streams;
-            
+
         bitrate += codec_rate;
 
         if (stream->id==AUDIO_ID)
@@ -418,7 +437,7 @@ static int mpeg_mux_init(AVFormatContext *ctx)
         else if (stream->id==VIDEO_ID)
             video_bitrate += codec_rate;
     }
-    
+
     if(ctx->mux_rate){
         s->mux_rate= (ctx->mux_rate + (8 * 50) - 1) / (8 * 50);
     } else {
@@ -453,11 +472,11 @@ static int mpeg_mux_init(AVFormatContext *ctx)
         overhead_rate = ((audio_bitrate / 8.0) / 2279) * (2324 - 2279);
         overhead_rate += ((video_bitrate / 8.0) / 2294) * (2324 - 2294);
         overhead_rate *= 8;
-        
+
         /* Add padding so that the full bitrate is 2324*75 bytes/sec */
         s->vcd_padding_bitrate = 2324 * 75 * 8 - (bitrate + overhead_rate);
     }
-    
+
     if (s->is_vcd || s->is_mpeg2)
         /* every packet */
         s->pack_header_freq = 1;
@@ -468,7 +487,7 @@ static int mpeg_mux_init(AVFormatContext *ctx)
     /* the above seems to make pack_header_freq zero sometimes */
     if (s->pack_header_freq == 0)
        s->pack_header_freq = 1;
-    
+
     if (s->is_mpeg2)
         /* every 200 packets. Need to look at the spec.  */
         s->system_header_freq = s->pack_header_freq * 40;
@@ -479,7 +498,7 @@ static int mpeg_mux_init(AVFormatContext *ctx)
         s->system_header_freq = 0x7fffffff;
     else
         s->system_header_freq = s->pack_header_freq * 5;
-    
+
     for(i=0;i<ctx->nb_streams;i++) {
         stream = ctx->streams[i]->priv_data;
         stream->packet_number = 0;
@@ -496,9 +515,9 @@ static int mpeg_mux_init(AVFormatContext *ctx)
 
 static inline void put_timestamp(ByteIOContext *pb, int id, int64_t timestamp)
 {
-    put_byte(pb, 
-             (id << 4) | 
-             (((timestamp >> 30) & 0x07) << 1) | 
+    put_byte(pb,
+             (id << 4) |
+             (((timestamp >> 30) & 0x07) << 1) |
              1);
     put_be16(pb, (uint16_t)((((timestamp >> 15) & 0x7fff) << 1) | 1));
     put_be16(pb, (uint16_t)((((timestamp) & 0x7fff) << 1) | 1));
@@ -515,7 +534,7 @@ static int get_vcd_padding_size(AVFormatContext *ctx, int64_t pts)
     if (s->vcd_padding_bitrate > 0 && pts!=AV_NOPTS_VALUE)
     {
         int64_t full_pad_bytes;
-        
+
         full_pad_bytes = (int64_t)((s->vcd_padding_bitrate * (pts / 90000.0)) / 8.0); //FIXME this is wrong
         pad_bytes = (int) (full_pad_bytes - s->vcd_padding_bytes_written);
 
@@ -529,6 +548,7 @@ static int get_vcd_padding_size(AVFormatContext *ctx, int64_t pts)
 }
 
 
+#if 0 /* unused, remove? */
 /* return the exact available payload size for the next packet for
    stream 'stream_index'. 'pts' and 'dts' are only used to know if
    timestamps are needed in the packet header. */
@@ -544,22 +564,22 @@ static int get_packet_payload_size(AVFormatContext *ctx, int stream_index,
     buf_index = 0;
     if (((s->packet_number % s->pack_header_freq) == 0)) {
         /* pack header size */
-        if (s->is_mpeg2) 
+        if (s->is_mpeg2)
             buf_index += 14;
         else
             buf_index += 12;
-        
+
         if (s->is_vcd) {
             /* there is exactly one system header for each stream in a VCD MPEG,
                One in the very first video packet and one in the very first
                audio packet (see VCD standard p. IV-7 and IV-8).*/
-            
+
             if (stream->packet_number==0)
                 /* The system headers refer only to the stream they occur in,
                    so they have a constant size.*/
                 buf_index += 15;
 
-        } else {            
+        } else {
             if ((s->packet_number % s->system_header_freq) == 0)
                 buf_index += s->system_header_size;
         }
@@ -568,7 +588,7 @@ static int get_packet_payload_size(AVFormatContext *ctx, int stream_index,
     if ((s->is_vcd && stream->packet_number==0)
         || (s->is_svcd && s->packet_number==0))
         /* the first pack of each stream contains only the pack header,
-           the system header and some padding (see VCD standard p. IV-6) 
+           the system header and some padding (see VCD standard p. IV-6)
            Add the padding size, so that the actual payload becomes 0.*/
         buf_index += s->packet_size - buf_index;
     else {
@@ -590,7 +610,7 @@ static int get_packet_payload_size(AVFormatContext *ctx, int stream_index,
             if (!s->is_mpeg2)
                 buf_index++;
         }
-    
+
         if (stream->id < 0xc0) {
             /* AC3/LPCM private data header */
             buf_index += 4;
@@ -610,15 +630,16 @@ static int get_packet_payload_size(AVFormatContext *ctx, int stream_index,
                each audio packet (see standard p. IV-8).*/
             buf_index+=20;
     }
-    return s->packet_size - buf_index; 
+    return s->packet_size - buf_index;
 }
+#endif
 
 /* Write an MPEG padding packet header. */
 static void put_padding_packet(AVFormatContext *ctx, ByteIOContext *pb,int packet_bytes)
 {
     MpegMuxContext *s = ctx->priv_data;
     int i;
-    
+
     put_be32(pb, PADDING_STREAM);
     put_be16(pb, packet_bytes - 6);
     if (!s->is_mpeg2) {
@@ -635,7 +656,7 @@ static int get_nb_frames(AVFormatContext *ctx, StreamInfo *stream, int len){
     int nb_frames=0;
     PacketDesc *pkt_desc= stream->premux_packet;
 
-    while(len>0){ 
+    while(len>0){
         if(pkt_desc->size == pkt_desc->unwritten_size)
             nb_frames++;
         len -= pkt_desc->unwritten_size;
@@ -646,7 +667,7 @@ static int get_nb_frames(AVFormatContext *ctx, StreamInfo *stream, int len){
 }
 
 /* flush the packet on stream stream_index */
-static int flush_packet(AVFormatContext *ctx, int stream_index, 
+static int flush_packet(AVFormatContext *ctx, int stream_index,
                          int64_t pts, int64_t dts, int64_t scr, int trailer_size)
 {
     MpegMuxContext *s = ctx->priv_data;
@@ -660,11 +681,11 @@ static int flush_packet(AVFormatContext *ctx, int stream_index,
     int pes_flags;
     int general_pack = 0;  /*"general" pack without data specific to one stream?*/
     int nb_frames;
-    
+
     id = stream->id;
-    
+
 #if 0
-    printf("packet ID=%2x PTS=%0.3f\n", 
+    printf("packet ID=%2x PTS=%0.3f\n",
            id, pts / 90000.0);
 #endif
 
@@ -680,7 +701,7 @@ static int flush_packet(AVFormatContext *ctx, int stream_index,
             /* there is exactly one system header for each stream in a VCD MPEG,
                One in the very first video packet and one in the very first
                audio packet (see VCD standard p. IV-7 and IV-8).*/
-            
+
             if (stream->packet_number==0) {
                 size = put_system_header(ctx, buf_ptr, id);
                 buf_ptr += size;
@@ -750,7 +771,7 @@ static int flush_packet(AVFormatContext *ctx, int stream_index,
         /* The VCD standard demands that 20 zero bytes follow
            each audio pack (see standard p. IV-8).*/
         zero_trail_bytes += 20;
-            
+
     if ((s->is_vcd && stream->packet_number==0)
         || (s->is_svcd && s->packet_number==0)) {
         /* for VCD the first pack of each stream contains only the pack header,
@@ -770,7 +791,7 @@ static int flush_packet(AVFormatContext *ctx, int stream_index,
 
         /* packet header size */
         packet_size -= 6;
-        
+
         /* packet header */
         if (s->is_mpeg2) {
             header_len = 3;
@@ -793,9 +814,12 @@ static int flush_packet(AVFormatContext *ctx, int stream_index,
         payload_size = packet_size - header_len;
         if (id < 0xc0) {
             startcode = PRIVATE_STREAM_1;
-            payload_size -= 4;
-            if (id >= 0xa0)
+            payload_size -= 1;
+            if (id >= 0x40) {
                 payload_size -= 3;
+                if (id >= 0xa0)
+                    payload_size -= 3;
+            }
         } else {
             startcode = 0x100 + id;
         }
@@ -805,7 +829,7 @@ static int flush_packet(AVFormatContext *ctx, int stream_index,
         // first byte doesnt fit -> reset pts/dts + stuffing
         if(payload_size <= trailer_size && pts != AV_NOPTS_VALUE){
             int timestamp_len=0;
-            if(dts != pts) 
+            if(dts != pts)
                 timestamp_len += 5;
             if(pts != AV_NOPTS_VALUE)
                 timestamp_len += s->is_mpeg2 ? 5 : 4;
@@ -841,13 +865,13 @@ static int flush_packet(AVFormatContext *ctx, int stream_index,
             payload_size -= stuffing_size;
             stuffing_size = 0;
         }
-        
+
         nb_frames= get_nb_frames(ctx, stream, payload_size - stuffing_size);
 
         put_be32(&ctx->pb, startcode);
 
         put_be16(&ctx->pb, packet_size);
-        
+
         if (!s->is_mpeg2)
             for(i=0;i<stuffing_size;i++)
                 put_byte(&ctx->pb, 0xff);
@@ -877,11 +901,11 @@ static int flush_packet(AVFormatContext *ctx, int stream_index,
                 put_timestamp(&ctx->pb, (pes_flags & 0x40) ? 0x03 : 0x02, pts);
             if (pes_flags & 0x40)  /*write dts*/
                 put_timestamp(&ctx->pb, 0x01, dts);
-            
+
             if (pes_flags & 0x01) {  /*write pes extension*/
                 put_byte(&ctx->pb, 0x10); /* flags */
 
-                /* P-STD buffer info */                
+                /* P-STD buffer info */
                 if (id == AUDIO_ID)
                     put_be16(&ctx->pb, 0x4000 | stream->max_buffer_size/128);
                 else
@@ -919,7 +943,7 @@ static int flush_packet(AVFormatContext *ctx, int stream_index,
                 put_byte(&ctx->pb, stream->lpcm_header[0]);
                 put_byte(&ctx->pb, stream->lpcm_header[1]);
                 put_byte(&ctx->pb, stream->lpcm_header[2]);
-            } else {
+            } else if (id >= 0x40) {
                 /* AC3 */
                 put_byte(&ctx->pb, nb_frames);
                 put_be16(&ctx->pb, trailer_size+1);
@@ -935,13 +959,13 @@ static int flush_packet(AVFormatContext *ctx, int stream_index,
     }
 
     if (pad_packet_bytes > 0)
-        put_padding_packet(ctx,&ctx->pb, pad_packet_bytes);    
+        put_padding_packet(ctx,&ctx->pb, pad_packet_bytes);
 
     for(i=0;i<zero_trail_bytes;i++)
         put_byte(&ctx->pb, 0x00);
-        
+
     put_flush_packet(&ctx->pb);
-    
+
     s->packet_number++;
 
     /* only increase the stream packet number if this pack actually contains
@@ -949,7 +973,7 @@ static int flush_packet(AVFormatContext *ctx, int stream_index,
        or some data.*/
     if (!general_pack)
         stream->packet_number++;
-    
+
     return payload_size - stuffing_size;
 }
 
@@ -968,9 +992,9 @@ static void put_vcd_padding_sector(AVFormatContext *ctx)
         put_byte(&ctx->pb, 0);
 
     s->vcd_padding_bytes_written += s->packet_size;
-        
+
     put_flush_packet(&ctx->pb);
-    
+
     /* increasing the packet number is correct. The SCR of the following packs
        is calculated from the packet_number and it has to include the padding
        sector (it represents the sector index, not the MPEG pack index)
@@ -978,6 +1002,7 @@ static void put_vcd_padding_sector(AVFormatContext *ctx)
     s->packet_number++;
 }
 
+#if 0 /* unused, remove? */
 static int64_t get_vcd_scr(AVFormatContext *ctx,int stream_index,int64_t pts)
 {
     MpegMuxContext *s = ctx->priv_data;
@@ -996,7 +1021,8 @@ static int64_t get_vcd_scr(AVFormatContext *ctx,int stream_index,int64_t pts)
         scr = 36000 + s->packet_number * 1200;
 
     return scr;
-}    
+}
+#endif
 
 static int remove_decoded_packets(AVFormatContext *ctx, int64_t scr){
 //    MpegMuxContext *s = ctx->priv_data;
@@ -1006,9 +1032,9 @@ static int remove_decoded_packets(AVFormatContext *ctx, int64_t scr){
         AVStream *st = ctx->streams[i];
         StreamInfo *stream = st->priv_data;
         PacketDesc *pkt_desc= stream->predecode_packet;
-        
+
         while(pkt_desc && scr > pkt_desc->dts){ //FIXME > vs >=
-            if(stream->buffer_index < pkt_desc->size || 
+            if(stream->buffer_index < pkt_desc->size ||
                stream->predecode_packet == stream->premux_packet){
                 av_log(ctx, AV_LOG_ERROR, "buffer underflow\n");
                 break;
@@ -1019,7 +1045,7 @@ static int remove_decoded_packets(AVFormatContext *ctx, int64_t scr){
             av_freep(&pkt_desc);
         }
     }
-    
+
     return 0;
 }
 
@@ -1044,7 +1070,10 @@ retry:
         int rel_space= 1024*space / stream->max_buffer_size;
         PacketDesc *next_pkt= stream->premux_packet;
 
-        if(s->packet_size > avail_data && !flush)
+        /* for subtitle, a single PES packet must be generated,
+           so we flush after every single subtitle packet */
+        if(s->packet_size > avail_data && !flush
+           && st->codec->codec_type != CODEC_TYPE_SUBTITLE)
             return 0;
         if(avail_data==0)
             continue;
@@ -1052,17 +1081,17 @@ retry:
 
         if(space < s->packet_size && !ignore_constraints)
             continue;
-            
+
         if(next_pkt && next_pkt->dts - scr > max_delay)
             continue;
-            
+
         if(rel_space > best_score){
             best_score= rel_space;
             best_i = i;
             avail_space= space;
         }
     }
-    
+
     if(best_i < 0){
         int64_t best_dts= INT64_MAX;
 
@@ -1075,7 +1104,7 @@ retry:
         }
 
 #if 0
-        av_log(ctx, AV_LOG_DEBUG, "bumping scr, scr:%f, dts:%f\n", 
+        av_log(ctx, AV_LOG_DEBUG, "bumping scr, scr:%f, dts:%f\n",
                scr/90000.0, best_dts/90000.0);
 #endif
         if(best_dts == INT64_MAX)
@@ -1092,14 +1121,14 @@ retry:
     }
 
     assert(best_i >= 0);
-    
+
     st = ctx->streams[best_i];
     stream = st->priv_data;
-    
+
     assert(fifo_size(&stream->fifo, stream->fifo.rptr) > 0);
 
     assert(avail_space >= s->packet_size || ignore_constraints);
-    
+
     timestamp_packet= stream->premux_packet;
     if(timestamp_packet->unwritten_size == timestamp_packet->size){
         trailer_size= 0;
@@ -1126,17 +1155,17 @@ retry:
             s->last_scr += s->packet_size*90000LL / (s->mux_rate*50LL); //FIXME rounding and first few bytes of each packet
         }
     }
-    
+
     stream->buffer_index += es_size;
     s->last_scr += s->packet_size*90000LL / (s->mux_rate*50LL); //FIXME rounding and first few bytes of each packet
-    
+
     while(stream->premux_packet && stream->premux_packet->unwritten_size <= es_size){
         es_size -= stream->premux_packet->unwritten_size;
         stream->premux_packet= stream->premux_packet->next;
     }
     if(es_size)
         stream->premux_packet->unwritten_size -= es_size;
-    
+
     if(remove_decoded_packets(ctx, s->last_scr) < 0)
         return -1;
 
@@ -1154,8 +1183,8 @@ static int mpeg_mux_write_packet(AVFormatContext *ctx, AVPacket *pkt)
     int64_t pts, dts;
     PacketDesc *pkt_desc;
     const int preload= av_rescale(ctx->preload, 90000, AV_TIME_BASE);
-    const int is_iframe = st->codec.codec_type == CODEC_TYPE_VIDEO && (pkt->flags & PKT_FLAG_KEY);
-    
+    const int is_iframe = st->codec->codec_type == CODEC_TYPE_VIDEO && (pkt->flags & PKT_FLAG_KEY);
+
     pts= pkt->pts;
     dts= pkt->dts;
 
@@ -1163,6 +1192,8 @@ static int mpeg_mux_write_packet(AVFormatContext *ctx, AVPacket *pkt)
     if(dts != AV_NOPTS_VALUE) dts += preload;
 
 //av_log(ctx, AV_LOG_DEBUG, "dts:%f pts:%f flags:%d stream:%d nopts:%d\n", dts/90000.0, pts/90000.0, pkt->flags, pkt->stream_index, pts != AV_NOPTS_VALUE);
+    if (!stream->premux_packet)
+        stream->next_packet = &stream->premux_packet;
     *stream->next_packet=
     pkt_desc= av_mallocz(sizeof(PacketDesc));
     pkt_desc->pts= pts;
@@ -1176,9 +1207,10 @@ static int mpeg_mux_write_packet(AVFormatContext *ctx, AVPacket *pkt)
     fifo_realloc(&stream->fifo, fifo_size(&stream->fifo, NULL) + size + 1);
 
     if (s->is_dvd){
-        if (is_iframe) {
+        if (is_iframe && (s->packet_number == 0 || (pts - stream->vobu_start_pts >= 36000))) { // min VOBU length 0.4 seconds (mpucoder)
             stream->fifo_iframe_ptr = stream->fifo.wptr;
             stream->align_iframe = 1;
+            stream->vobu_start_pts = pts;
         } else {
             stream->align_iframe = 0;
         }
@@ -1188,7 +1220,7 @@ static int mpeg_mux_write_packet(AVFormatContext *ctx, AVPacket *pkt)
 
     for(;;){
         int ret= output_packet(ctx, 0);
-        if(ret<=0) 
+        if(ret<=0)
             return ret;
     }
 }
@@ -1198,10 +1230,10 @@ static int mpeg_mux_end(AVFormatContext *ctx)
 //    MpegMuxContext *s = ctx->priv_data;
     StreamInfo *stream;
     int i;
-    
+
     for(;;){
         int ret= output_packet(ctx, 1);
-        if(ret<0) 
+        if(ret<0)
             return ret;
         else if(ret==0)
             break;
@@ -1221,7 +1253,7 @@ static int mpeg_mux_end(AVFormatContext *ctx)
     }
     return 0;
 }
-#endif //CONFIG_ENCODERS
+#endif //CONFIG_MUXERS
 
 /*********************************************/
 /* demux code */
@@ -1262,6 +1294,7 @@ static int mpegps_probe(AVProbeData *p)
 
 typedef struct MpegDemuxContext {
     int header_state;
+    unsigned char psm_es_type[256];
 } MpegDemuxContext;
 
 static int mpegps_read_header(AVFormatContext *s,
@@ -1290,7 +1323,7 @@ static int64_t get_pts(ByteIOContext *pb, int c)
     return pts;
 }
 
-static int find_next_start_code(ByteIOContext *pb, int *size_ptr, 
+static int find_next_start_code(ByteIOContext *pb, int *size_ptr,
                                 uint32_t *header_state)
 {
     unsigned int state, v;
@@ -1317,6 +1350,7 @@ static int find_next_start_code(ByteIOContext *pb, int *size_ptr,
     return val;
 }
 
+#if 0 /* unused, remove? */
 /* XXX: optimize */
 static int find_prev_start_code(ByteIOContext *pb, int *size_ptr)
 {
@@ -1349,12 +1383,47 @@ static int find_prev_start_code(ByteIOContext *pb, int *size_ptr)
     *size_ptr = pos_start - pos;
     return start_code;
 }
+#endif
 
-/* read the next PES header. Return its position in ppos 
+/**
+ * Extracts stream types from a program stream map
+ * According to ISO/IEC 13818-1 ('MPEG-2 Systems') table 2-35
+ *
+ * @return number of bytes occupied by PSM in the bitstream
+ */
+static long mpegps_psm_parse(MpegDemuxContext *m, ByteIOContext *pb)
+{
+    int psm_length, ps_info_length, es_map_length;
+
+    psm_length = get_be16(pb);
+    get_byte(pb);
+    get_byte(pb);
+    ps_info_length = get_be16(pb);
+
+    /* skip program_stream_info */
+    url_fskip(pb, ps_info_length);
+    es_map_length = get_be16(pb);
+
+    /* at least one es available? */
+    while (es_map_length >= 4){
+        unsigned char type = get_byte(pb);
+        unsigned char es_id = get_byte(pb);
+        uint16_t es_info_length = get_be16(pb);
+        /* remember mapping from stream id to stream type */
+        m->psm_es_type[es_id] = type;
+        /* skip program_stream_info */
+        url_fskip(pb, es_info_length);
+        es_map_length -= 4 + es_info_length;
+    }
+    get_be32(pb); /* crc32 */
+    return 2 + psm_length;
+}
+
+/* read the next PES header. Return its position in ppos
    (if not NULL), and its start code, pts and dts.
  */
 static int mpegps_read_pes_header(AVFormatContext *s,
-                                  int64_t *ppos, int *pstart_code, 
+                                  int64_t *ppos, int *pstart_code,
                                   int64_t *ppts, int64_t *pdts)
 {
     MpegDemuxContext *m = s->priv_data;
@@ -1381,6 +1450,11 @@ static int mpegps_read_pes_header(AVFormatContext *s,
         url_fskip(&s->pb, len);
         goto redo;
     }
+    if (startcode == PROGRAM_STREAM_MAP) {
+        mpegps_psm_parse(m, &s->pb);
+        goto redo;
+    }
+
     /* find matching stream */
     if (!((startcode >= 0x1c0 && startcode <= 0x1df) ||
           (startcode >= 0x1e0 && startcode <= 0x1ef) ||
@@ -1399,7 +1473,7 @@ static int mpegps_read_pes_header(AVFormatContext *s,
         c = get_byte(&s->pb);
         len--;
         /* XXX: for mpeg1, should test only bit 7 */
-        if (c != 0xff) 
+        if (c != 0xff)
             break;
     }
     if ((c & 0xc0) == 0x40) {
@@ -1455,7 +1529,7 @@ static int mpegps_read_pes_header(AVFormatContext *s,
     else if( c!= 0xf )
         goto redo;
 
-    if (startcode == 0x1bd) {
+    if (startcode == PRIVATE_STREAM_1 && !m->psm_es_type[startcode & 0xff]) {
         if (len < 1)
             goto redo;
         startcode = get_byte(&s->pb);
@@ -1474,11 +1548,11 @@ static int mpegps_read_pes_header(AVFormatContext *s,
         int i;
         for(i=0; i<s->nb_streams; i++){
             if(startcode == s->streams[i]->id) {
-                av_add_index_entry(s->streams[i], *ppos, dts, 0, 0 /* FIXME keyframe? */);
+                av_add_index_entry(s->streams[i], *ppos, dts, 0, AVINDEX_KEYFRAME /* FIXME keyframe? */);
             }
         }
     }
-    
+
     *pstart_code = startcode;
     *ppts = pts;
     *pdts = dts;
@@ -1488,36 +1562,68 @@ static int mpegps_read_pes_header(AVFormatContext *s,
 static int mpegps_read_packet(AVFormatContext *s,
                               AVPacket *pkt)
 {
+    MpegDemuxContext *m = s->priv_data;
     AVStream *st;
-    int len, startcode, i, type, codec_id = 0;
+    int len, startcode, i, type, codec_id = 0, es_type;
     int64_t pts, dts, dummy_pos; //dummy_pos is needed for the index building to work
 
  redo:
     len = mpegps_read_pes_header(s, &dummy_pos, &startcode, &pts, &dts);
     if (len < 0)
         return len;
-    
+
     /* now find stream */
     for(i=0;i<s->nb_streams;i++) {
         st = s->streams[i];
         if (st->id == startcode)
             goto found;
     }
-    if (startcode >= 0x1e0 && startcode <= 0x1ef) {
+
+    es_type = m->psm_es_type[startcode & 0xff];
+    if(es_type > 0){
+        if(es_type == STREAM_TYPE_VIDEO_MPEG1){
+            codec_id = CODEC_ID_MPEG2VIDEO;
+            type = CODEC_TYPE_VIDEO;
+        } else if(es_type == STREAM_TYPE_VIDEO_MPEG2){
+            codec_id = CODEC_ID_MPEG2VIDEO;
+            type = CODEC_TYPE_VIDEO;
+        } else if(es_type == STREAM_TYPE_AUDIO_MPEG1 ||
+                  es_type == STREAM_TYPE_AUDIO_MPEG2){
+            codec_id = CODEC_ID_MP3;
+            type = CODEC_TYPE_AUDIO;
+        } else if(es_type == STREAM_TYPE_AUDIO_AAC){
+            codec_id = CODEC_ID_AAC;
+            type = CODEC_TYPE_AUDIO;
+        } else if(es_type == STREAM_TYPE_VIDEO_MPEG4){
+            codec_id = CODEC_ID_MPEG4;
+            type = CODEC_TYPE_VIDEO;
+        } else if(es_type == STREAM_TYPE_VIDEO_H264){
+            codec_id = CODEC_ID_H264;
+            type = CODEC_TYPE_VIDEO;
+        } else if(es_type == STREAM_TYPE_AUDIO_AC3){
+            codec_id = CODEC_ID_AC3;
+            type = CODEC_TYPE_AUDIO;
+        } else {
+            goto skip;
+        }
+    } else if (startcode >= 0x1e0 && startcode <= 0x1ef) {
         type = CODEC_TYPE_VIDEO;
         codec_id = CODEC_ID_MPEG2VIDEO;
     } else if (startcode >= 0x1c0 && startcode <= 0x1df) {
         type = CODEC_TYPE_AUDIO;
         codec_id = CODEC_ID_MP2;
-    } else if (startcode >= 0x80 && startcode <= 0x89) {
+    } else if (startcode >= 0x80 && startcode <= 0x87) {
         type = CODEC_TYPE_AUDIO;
         codec_id = CODEC_ID_AC3;
-    } else if (startcode >= 0x8a && startcode <= 0x9f) {
+    } else if (startcode >= 0x88 && startcode <= 0x9f) {
         type = CODEC_TYPE_AUDIO;
         codec_id = CODEC_ID_DTS;
     } else if (startcode >= 0xa0 && startcode <= 0xbf) {
         type = CODEC_TYPE_AUDIO;
         codec_id = CODEC_ID_PCM_S16BE;
+    } else if (startcode >= 0x20 && startcode <= 0x3f) {
+        type = CODEC_TYPE_SUBTITLE;
+        codec_id = CODEC_ID_DVD_SUBTITLE;
     } else {
     skip:
         /* skip packet */
@@ -1526,13 +1632,15 @@ static int mpegps_read_packet(AVFormatContext *s,
     }
     /* no stream found: add a new stream */
     st = av_new_stream(s, startcode);
-    if (!st) 
+    if (!st)
         goto skip;
-    st->codec.codec_type = type;
-    st->codec.codec_id = codec_id;
+    st->codec->codec_type = type;
+    st->codec->codec_id = codec_id;
     if (codec_id != CODEC_ID_PCM_S16BE)
         st->need_parsing = 1;
  found:
+    if(st->discard >= AVDISCARD_ALL)
+        goto skip;
     if (startcode >= 0xa0 && startcode <= 0xbf) {
         int b1, freq;
 
@@ -1545,9 +1653,9 @@ static int mpegps_read_packet(AVFormatContext *s,
         get_byte(&s->pb); /* dynamic range control (0x80 = off) */
         len -= 3;
         freq = (b1 >> 4) & 3;
-        st->codec.sample_rate = lpcm_freq_tab[freq];
-        st->codec.channels = 1 + (b1 & 7);
-        st->codec.bit_rate = st->codec.channels * st->codec.sample_rate * 2;
+        st->codec->sample_rate = lpcm_freq_tab[freq];
+        st->codec->channels = 1 + (b1 & 7);
+        st->codec->bit_rate = st->codec->channels * st->codec->sample_rate * 2;
     }
     av_new_packet(pkt, len);
     get_buffer(&s->pb, pkt->data, pkt->size);
@@ -1555,8 +1663,8 @@ static int mpegps_read_packet(AVFormatContext *s,
     pkt->dts = dts;
     pkt->stream_index = st->index;
 #if 0
-    av_log(s, AV_LOG_DEBUG, "%d: pts=%0.3f dts=%0.3f\n",
-           pkt->stream_index, pkt->pts / 90000.0, pkt->dts / 90000.0);
+    av_log(s, AV_LOG_DEBUG, "%d: pts=%0.3f dts=%0.3f size=%d\n",
+           pkt->stream_index, pkt->pts / 90000.0, pkt->dts / 90000.0, pkt->size);
 #endif
 
     return 0;
@@ -1567,7 +1675,7 @@ static int mpegps_read_close(AVFormatContext *s)
     return 0;
 }
 
-static int64_t mpegps_read_dts(AVFormatContext *s, int stream_index, 
+static int64_t mpegps_read_dts(AVFormatContext *s, int stream_index,
                                int64_t *ppos, int64_t pos_limit)
 {
     int len, startcode;
@@ -1586,7 +1694,7 @@ static int64_t mpegps_read_dts(AVFormatContext *s, int stream_index,
 #endif
             return AV_NOPTS_VALUE;
         }
-        if (startcode == s->streams[stream_index]->id && 
+        if (startcode == s->streams[stream_index]->id &&
             dts != AV_NOPTS_VALUE) {
             break;
         }
@@ -1599,7 +1707,7 @@ static int64_t mpegps_read_dts(AVFormatContext *s, int stream_index,
     return dts;
 }
 
-#ifdef CONFIG_ENCODERS
+#ifdef CONFIG_MUXERS
 static AVOutputFormat mpeg1system_mux = {
     "mpeg",
     "MPEG1 System format",
@@ -1667,8 +1775,8 @@ static AVOutputFormat mpeg2dvd_mux = {
     mpeg_mux_end,
 };
 
-#endif //CONFIG_ENCODERS
-extern AVOutputFormat mpegts_mux;
+#endif //CONFIG_MUXERS
+
 AVInputFormat mpegps_demux = {
     "mpeg",
     "MPEG PS format",
@@ -1679,22 +1787,18 @@ AVInputFormat mpegps_demux = {
     mpegps_read_close,
     NULL, //mpegps_read_seek,
     mpegps_read_dts,
+    .flags = AVFMT_SHOW_IDS,
 };
 
 int mpegps_init(void)
 {
- //meanx
-        register_protocol(&file_protocol);
-
-#ifdef CONFIG_ENCODERS
+#ifdef CONFIG_MUXERS
     av_register_output_format(&mpeg1system_mux);
     av_register_output_format(&mpeg1vcd_mux);
     av_register_output_format(&mpeg2vob_mux);
     av_register_output_format(&mpeg2svcd_mux);
     av_register_output_format(&mpeg2dvd_mux);
-    
-#endif //CONFIG_ENCODERS
-    av_register_output_format(&mpegts_mux);
+#endif //CONFIG_MUXERS
     av_register_input_format(&mpegps_demux);
     return 0;
 }
