@@ -1,14 +1,16 @@
-//
-// C++ Implementation: %{MODULE}
-//
-// Description:
-//
-//
-// Author: %{AUTHOR} <%{EMAIL}>, (C) %{YEAR}
-//
-// Copyright: See COPYING file that comes with this distribution
-//
-//
+/***************************************************************************
+    copyright            : (C) 2003-2005 by mean
+    email                : fixounet@free.fr
+ ***************************************************************************/
+
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
 #include "config.h"
 
 #include <stdlib.h>
@@ -18,6 +20,7 @@
 #include "ADM_library/default.h"
 
 #include "ADM_library/ADM_image.h"
+#include "ADM_toolkit/ADM_cpuCap.h"
 //#include "ADM_assert.h"
 void ADMImage_stat( void );
 
@@ -53,6 +56,7 @@ void    ADMImage::commonInit(uint32_t w,uint32_t h)
         imgCurNb++;
         _planes[0]=_planes[1]=_planes[2]=NULL;
         _noPicture=0;
+        _colorspace=ADM_COLOR_YV12;
 
 }
 ADMImage::ADMImage(uint32_t width, uint32_t height)
@@ -94,27 +98,35 @@ ADMImage::~ADMImage()
 //
 //	Duplicate
 //
-uint8_t ADMImage::duplicate(ADMImage *src)
+uint8_t ADMImage::duplicateMacro(ADMImage *src,uint32_t swap)
 {
-	// Sanity check
-	ADM_assert(src->_width==_width);
-	ADM_assert(src->_height==_height);
+        // Sanity check
+        ADM_assert(src->_width==_width);
+        ADM_assert(src->_height==_height);
 
         ADM_assert(!_isRef); // could not duplicate to a linked data image
 
-	// cleanup if needed
-	if(quant) delete [] quant;
-	quant=NULL;
+        // cleanup if needed
+        if(quant) delete [] quant;
+        quant=NULL;
  
-       _qStride=0;	
-	_qSize=0;
-	
-	copyInfo(src);
+       _qStride=0;      
+        _qSize=0;
+        
+        copyInfo(src);
         if(!src->_isRef)
         {
-	       memcpy(YPLANE(this),YPLANE(src),_width*_height);
-	       memcpy(UPLANE(this),UPLANE(src),(_width*_height)>>2);
-	       memcpy(VPLANE(this),VPLANE(src),(_width*_height)>>2);
+               memcpy(YPLANE(this),YPLANE(src),_width*_height);
+                if(swap)
+                {
+                        memcpy(UPLANE(this),VPLANE(src),(_width*_height)>>2);
+                        memcpy(VPLANE(this),UPLANE(src),(_width*_height)>>2);
+                }
+                else
+                {
+                        memcpy(UPLANE(this),UPLANE(src),(_width*_height)>>2);
+                        memcpy(VPLANE(this),VPLANE(src),(_width*_height)>>2);
+                }
         }
         else
         {
@@ -160,19 +172,34 @@ uint8_t ADMImage::duplicate(ADMImage *src)
                 w>>=1;
                 h>>=1;
                 in=src->_planes[1];
-                out=UPLANE(this);
+                if(swap)
+                        out=VPLANE(this);
+                else
+                        out=UPLANE(this);
                 stride=src->_planeStride[1];
                 PLANE_CPY(h);
         
                 in=src->_planes[2];
-                out=VPLANE(this);
+                if(swap)
+                        out=UPLANE(this);
+                else
+                        out=VPLANE(this);
                 stride=src->_planeStride[2];
                 PLANE_CPY(h);
 
 
         }
-	return 1;
+        return 1;
 }
+uint8_t ADMImage::duplicate(ADMImage *src)
+{
+	return duplicateMacro(src,0);
+}
+uint8_t ADMImage::duplicateSwapUV(ADMImage *src)
+{
+        return duplicateMacro(src,0);
+}
+
 uint8_t ADMImage::duplicateFull(ADMImage *src)
 {
 	// Sanity check
@@ -224,7 +251,15 @@ uint8_t ADMImage::copyQuantInfo(ADMImage *src)
 	return 1;
 }
 
-
-
-
-
+uint8_t BitBlit(uint8_t *dst, uint32_t pitchDst,uint8_t *src,uint32_t pitchSrc,uint32_t width, uint32_t height)
+{
+    
+    for(int y=0;y<height;y++)
+    {
+        memcpy(dst,src,width);
+        src+=pitchSrc;
+        dst+=pitchDst;   
+    }
+    return 1;
+}
+//EOF
