@@ -23,7 +23,7 @@
 #ifndef ADM_IMAGE
 #define ADM_IMAGE
 #include "ADM_assert.h"
-
+#include "ADM_colorspace/ADM_rgb.h"
 
 typedef enum ADM_ASPECT
 {
@@ -59,9 +59,16 @@ public:
 	ADM_ASPECT	_aspect;	/// Aspect ratio
 	uint32_t	flags;		/// Flags for this image (AVI_KEY_FRAME/AVI_B_FRAME)
 
+// This 3 fields are only used to convery container (reference to other datas)
+// Between codec & editor
 	uint8_t         _isRef;         /// If True means the datas are just a link to data we don't own!
+        ADM_colorspace  _colorspace;    /// Colorspace we are moving, default is YV12
         uint8_t         _noPicture;     /// No picture to display
+
+// End of section dedicated to codec/editor transfer
+
         void            commonInit(uint32_t w,uint32_t h); /// sub constructor
+        
         uint32_t        GetPitch(ADM_PLANE plane)
                                 {
                                         switch(plane)
@@ -94,6 +101,7 @@ public:
                                                 default: ADM_assert(0);
                                         }
                                 };
+        uint8_t duplicateMacro(ADMImage *src,uint32_t swap);       /// copy an image to ourself, including info
 public:
 
         uint8_t         *_planes[3];     /// In case of linked data store y/u/v pointers
@@ -105,6 +113,7 @@ public:
                 
 		~ADMImage();
 	uint8_t duplicate(ADMImage *src);	/// copy an image to ourself, including info
+        uint8_t duplicateSwapUV(ADMImage *src); /// copy an image to ourself, including info
 	uint8_t duplicateFull(ADMImage *src);	/// copy an image to ourself, including info
 	uint8_t copyInfo(ADMImage *src);	/// copy all the flags, not the data themselves
 	uint8_t copyQuantInfo(ADMImage *src);	/// copy quant table if any
@@ -112,9 +121,15 @@ public:
         uint8_t setLinkInfos(uint8_t *y,        /// To fill in infos for linked image
                         uint8_t *u,uint8_t *v,uint32_t stridey,
                         uint32_t strideu, uint32_t stridev);
-
+        uint8_t merge(ADMImage *src1,ADMImage *src2);
+        uint8_t substract(ADMImage *src1,ADMImage *src2);
+static uint32_t lumaDiff(ADMImage *src1,ADMImage *src2,uint32_t noise);
 };
+void drawString(ADMImage *dst, int x, int y, const char *s) ;
 #define YPLANE(x) (x->data)
 #define UPLANE(x) (x->data+(x->_width*x->_height))
 #define VPLANE(x) (x->data+(5*(x->_width*x->_height)>>2))
+
+uint8_t BitBlit(uint8_t *dst, uint32_t pitchDest,uint8_t *src,uint32_t pitchSrc,uint32_t width, uint32_t height);
+
 #endif
