@@ -29,6 +29,7 @@
 
 
 #include <gtk/gtk.h>
+#include <ctype.h>
 
 
 #include "interface.h"
@@ -50,10 +51,10 @@
 
 #include "ADM_filter/vidVCD.h"
 
-#include "ADM_script/adm_command.h"
+//#include "ADM_script/adm_command.h"
 
 extern void filterListAll(void );
-extern void ADS_commandList( void );
+
 extern uint8_t loadVideoCodecConf( char *name);
 extern int A_saveJpg (char *name);
 extern void filterLoadXml(char *n);
@@ -62,26 +63,22 @@ extern int A_appendAvi (char *name);
 extern void A_saveAudio(char *name);
 extern int A_loadNone( void );
 extern void A_saveAudioDecodedTest(char *name);
-extern uint8_t indexMpeg(char *mpeg,char *file,uint8_t aid);
-extern void A_SaveAudioNVideo(char *name);
-extern int GUI_loadMP3(char *name);
+extern uint8_t A_SaveAudioNVideo(char *name);
+extern int A_loadMP3(char *name);
 extern int A_loadAC3(char *name);
 extern int A_loadWave(char *name);
 extern void GUI_Quiet( void);
-extern void parseScript(char *name);
+extern bool A_parseECMAScript(const char *name);
 extern void GUI_Verbose( void);
 extern void audioFilter_SetBitrate( int i);
-extern void A_Save(char *name);
+extern void A_Save(const char *name);
 extern void videoCodecSelectByName(const char *name);
 extern int videoCodecConfigure(char *p,uint32_t i, uint8_t  *c);
 #include "oplug_mpeg/op_mpeg.h"
-extern void encoderSetLogFile(char *name)     ;
 extern void updateLoaded( void );
 extern void setPostProc(int v,int s);
 extern void HandleAction(Action action) ;
 static void call_buildtimemap( char *p);
-static void call_audioproc(char *p) ;
-static void call_videoproc(char *p) ;
 static void call_quit(char *p) ;
 static void setBegin(char *p)   ;
 static void setEnd(char *p)      ;
@@ -94,7 +91,6 @@ static void call_downsample(char *p) 	;
 static void call_help(char *p) 	;
 static void call_setAudio(char *p) 	;
 //static void call_load(char *p) 	;
-static void call_indexMpeg(char *in,char *out,char *aid) 	;
 static void call_autosplit(char *p) 	;
 static void call_audiobitrate(char *p) 	;
 static void call_fps(char *p) 	;
@@ -103,7 +99,8 @@ static void call_videocodec(char *p) ;
 static void call_videoconf(char *p) ;
 static int searchReactionTable(char *string);
 static void call_setPP(char *v,char *s);
-static void call_toolame(char *p);
+static void call_v2v(char *a,char *b,char *c);
+
 extern void updateLoaded(void );
 extern void A_requantize2( float percent, uint32_t quality, char *out_name );
 static void save(char*name);
@@ -112,21 +109,24 @@ extern void show_info(char *p);
 extern const char *getStrFromAudioCodec( uint32_t codec);
 extern void frame2time(uint32_t frame, uint32_t fps, uint16_t * hh, uint16_t * mm, uint16_t * ss, uint16_t * ms);
 extern uint8_t ADM_aviSetSplitSize(uint32_t size);
-extern uint8_t ogmSave(char *fd);
+extern uint8_t ogmSave(const char *fd);
 static void set_autoindex(char *p);
-extern int A_SaveUnpackedVop( char *name);
+extern int A_SaveUnpackedVop(const char *name);
 extern int A_saveDVDPS(char *name);
 extern void A_saveWorkbench (char *name);
 extern uint8_t A_rebuildKeyFrame (void);
-extern uint8_t scriptAddVar(char *var,char *value);
+extern uint8_t A_setContainer(const char *cont);
+uint8_t scriptAddVar(char *var,char *value);
+extern uint8_t ADM_vob2vobsub(char *nameVob, char *nameVobSub, char *nameIfo);
 //
 static int call_bframe(void);
 static int call_packedvop(void);
 static int call_saveDVD(char *a);
 static int set_output_format(const char *str);
+static void set_reuse_2pass_log(char *p);
 static void setVar(char *in);
 //
-
+uint8_t trueFalse(char *p);
 //_________________________________________________________________________
 
 extern uint8_t audioShift;
@@ -134,7 +134,7 @@ extern int32_t audioDelay;
 
 extern int global_argc;
 extern char **global_argv;
-extern void	ADM_saveRaw(char *name );
+extern uint8_t	ADM_saveRaw(const char *name );
 //_________________________________________________________________________
 
 typedef 	void 			(*one_arg_type)(char *arg);
@@ -153,17 +153,15 @@ typedef struct AUTOMATON
 
 AUTOMATON reaction_table[]=
 {	
-		{"list",		0,"list functions available for scripting",(one_arg_type)ADS_commandList},
+		
 		{"listfilters",		0,"list all filters by name",		(one_arg_type)filterListAll}   ,
-		{"run",			1,"load and run a script",		parseScript},
-		{"audio-process",	0,"activate audio processing",		call_audioproc},
-		{"audio-normalize",	0,"activate normalization",		call_normalize},
-		{"audio-downsample",	0,"activate 48->44 downsampling",	call_downsample},
+		{"run",			1,"load and run a script",		(one_arg_type)A_parseECMAScript},
+		{"audio-normalize",	1,"activate normalization",		call_normalize},
+		{"audio-downsample",	1,"activate 48->44 downsampling",	call_downsample},
 		{"audio-resample",	1,"resample to x hz",			call_resample},
 		{"audio-mono2stereo",	0,"channel: convert mono to stereo",	call_mono2stereo},
 		{"audio-stereo2mono",	0,"channel: convert stereo tp mono",	call_stereo2mono},
 		
-		{"video-process",	0,"activate video processing",		call_videoproc},	
 		{"filters",		1,"load a filter preset",		filterLoadXml}   ,
 		{"codec-conf",		1,"load a codec configuration",		(one_arg_type )loadVideoCodecConf}   ,
 		{"vcd-res",		0,"set VCD resolution",			(one_arg_type)setVCD}              ,
@@ -178,10 +176,8 @@ AUTOMATON reaction_table[]=
 		{"save-unpacked-vop",	1,"save avi, unpacking vop",(one_arg_type)A_SaveUnpackedVop},		
 		{"save-ogm",		1,"save as ogm file ",			(one_arg_type)ogmSave},
 		{"save-raw-audio",	1,"save audio as-is ",			A_saveAudio},
-		{"save-raw-video",	1,"save raw video stream (mpeg/... ) ",	ADM_saveRaw},
+		{"save-raw-video",	1,"save raw video stream (mpeg/... ) ",	(one_arg_type)ADM_saveRaw},
 		{"save-uncompressed-audio",1,"save uncompressed audio",A_saveAudioDecodedTest},
-		{"index-mpeg",		3,"create index of vob/mpeg : vob.vob index.index audio#",
-								((one_arg_type )call_indexMpeg)},
 		{"load",		1,"load video or workbench",		(one_arg_type )A_openAvi},
 		{"load-workbench",	1,"load workbench file",		(one_arg_type)A_openAvi},
 		{"append",		1,"append video",			(one_arg_type)A_appendAvi},
@@ -193,7 +189,7 @@ AUTOMATON reaction_table[]=
 								,(one_arg_type)call_packedvop},
 		
 		
-		{"external-mp3",	1,"load external mpeg audio as audio track",(one_arg_type)GUI_loadMP3},
+		{"external-mp3",	1,"load external mpeg audio as audio track",(one_arg_type)A_loadMP3},
 		{"external-ac3",	1,"load external ac3 audio as audio track",(one_arg_type)A_loadAC3},
 		{"external-wav",	1,"load external wav audio as audio track",(one_arg_type)A_loadWave},
 		{"no-audio",		0,"load external wav audio as audio track",(one_arg_type)A_loadNone},
@@ -201,12 +197,13 @@ AUTOMATON reaction_table[]=
 		{"audio-map",		0,"build audio map (MP3 VBR)",	call_buildtimemap},
 		{"audio-bitrate",	1,"set audio encoding bitrate",	call_audiobitrate},
 		{"fps",	1	,"set frames per second",	call_fps},
-		{"audio-codec",		1,"set audio codec (MP2/MP3/AC3/NONE/TOOLAME)",call_audiocodec},
-		{"audio-toolame",	1,"pipe audio to toolame and save to file",call_toolame},
-		{"video-codec",		1,"set video codec (Divx/Xvid/FFmpeg4/VCD/SVCD/DVD/XVCD/XSVCD)",				call_videocodec},
+		{"audio-codec",		1,"set audio codec (MP2/MP3/AC3/NONE (WAV PCM)/TOOLAME/COPY)",call_audiocodec},
+		
+		{"video-codec",		1,"set video codec (Divx/Xvid/FFmpeg4/VCD/SVCD/DVD/XVCD/XSVCD/COPY)",				call_videocodec},
 		{"video-conf",		1	,"set video codec conf (cq=q|cbr=br|2pass=size)[,mbr=br][,matrix=(0|1|2|3)]",				call_videoconf},
-//		{"2pass-log",		1	,"select the log file for 2 passes mode",				encoderSetLogFile},
+		{"reuse-2pass-log",	0	,"reuse 2pass logfile if it exists",	set_reuse_2pass_log},
 		{"set-pp",		2	,"set post processing default value, value(1=hdeblok|2=vdeblock|4=dering) and strength (0-5)",	(one_arg_type )	call_setPP},
+                {"vobsub",              3       ,"Create vobsub file (vobfile vosubfile ifofile)",  (one_arg_type ) call_v2v},
 
 		{"autosplit",		1	,"split every N MBytes",call_autosplit},
 		{"requant",		3	,"requantize mpeg2 : percent quality[0..3] output_name",
@@ -330,12 +327,9 @@ int searchReactionTable(char *string)
 //_________________________________________________________________________
 
 void call_quit        (char *p) { UNUSED_ARG(p); exit(0);                            }
-void call_audioproc   (char *p) { UNUSED_ARG(p); HandleAction(ACT_AudioModeProcess); }
-void call_videoproc   (char *p) { UNUSED_ARG(p); HandleAction(ACT_VideoModeProcess); }
 
 
-extern  int  audioNormalizeMode;
-extern void audioForceDownSample( void );
+
 extern void audioSetResample(uint32_t fq);
 int call_saveDVD(char *a)
 {
@@ -345,15 +339,25 @@ int call_saveDVD(char *a)
 
 void call_normalize   (char *p)
 {
-	audioNormalizeMode=1; // Ugly
-	aprintf("normalize\n");
-	 UNUSED_ARG(p);
+        audioFilterNormalize(trueFalse(p));	
 }
 void call_downsample    (char *p)
 {
-	audioForceDownSample();
-	printf("downsample\n");
-	 UNUSED_ARG(p); 
+	audioFilterDownsample(trueFalse(p));	
+}
+void call_resample    (char *p)
+{
+int fq;
+        fq=atoi(p);
+        if(fq>1000)
+        {
+                audioSetResample(fq);
+                printf("resample to %d\n",fq);
+        }
+        else
+        {
+                printf("*** INVALID FREQUENCY***\n");
+        }        
 
 }
 // The form is name=value
@@ -378,21 +382,7 @@ char *equal;
                 printf("Warning setvar failed\n");        
 
 }
-void call_resample    (char *p)
-{
-int fq;
-	fq=atoi(p);
-	if(fq>1000)
-	{
-		audioSetResample(fq);
-		printf("resample to %d\n",fq);
-	}
-	else
-	{
-		printf("*** INVALID FREQUENCY***\n");
-	}	 
 
-}
 
 
 
@@ -409,27 +399,28 @@ void call_setAudio (char *p)
 	
 		int32_t i;
 		sscanf(p,"%ld",&i);
-		audioFilterDelay(i);		
+		audioFilterDelay(i);	
 }
 void call_audiocodec(char *p)
 {
-	if(!strcmp(p,"MP2"))
+	if(!strcasecmp(p,"MP2"))
 		audioCodecSetcodec( AUDIOENC_MP2 );
-	else if(!strcmp(p,"AC3"))
+	else if(!strcasecmp(p,"AC3"))
 		audioCodecSetcodec( AUDIOENC_AC3 );
 #ifdef HAVE_LIBMP3LAME		
-	else if(!strcmp(p,"MP3"))
+	else if(!strcasecmp(p,"MP3"))
 		 audioCodecSetcodec( AUDIOENC_MP3 );
 #endif
-	else if(!strcmp(p,"NONE"))
+	else if(!strcasecmp(p,"NONE"))
 		audioCodecSetcodec( AUDIOENC_NONE );
-	else if(!strcmp(p,"TOOLAME"))
+	else if(!strcasecmp(p,"TOOLAME"))
 		audioCodecSetcodec( AUDIOENC_2LAME );		
 #ifdef USE_VORBIS		
-	else if(!strcmp(p,"VORBIS"))
+	else if(!strcasecmp(p,"VORBIS"))
 		audioCodecSetcodec( AUDIOENC_VORBIS );		
 #endif		
-		
+	else if(!strcasecmp(p,"COPY"))
+		audioCodecSetcodec( AUDIOENC_COPY );		
 	else{
 		audioCodecSetcodec( AUDIOENC_NONE );
 		fprintf(stderr,"audio codec \"%s\" unknown.\n",p);
@@ -517,14 +508,6 @@ void call_help(char *p)
 	
 			call_quit(NULL);
 }
-void call_indexMpeg(char *in,char *out, char *id)
-{
-uint32_t aid;
-					      if(id==NULL) return;
-								sscanf(id,"%x",&aid);
-              	indexMpeg(in,out,(uint8_t)aid);
-               	printf("\n __\n");
-}
 void call_requant(char *p, char *q, char *n)
 {
 
@@ -540,10 +523,6 @@ void save(char*name)
 	A_Save(name);
 }
 
-void call_toolame(char *file)
-{
-	A_Pipe(P_TOOLAME,file);
-}
 
 void set_autoindex(char *p){
 	UNUSED_ARG(p);
@@ -572,7 +551,6 @@ void show_info(char *p){
    if( wavinfo )
     {
       printf("   Codec: %s\n",getStrFromAudioCodec(wavinfo->encoding));     
-      
       printf("   Mode: ");
       switch( wavinfo->channels ){
          case 1:  printf("MONO\n"); break;
@@ -581,7 +559,13 @@ void show_info(char *p){
       }
       printf("   BitRate: %u Bps / %u kbps\n", wavinfo->byterate, wavinfo->byterate*8/1000);
       printf("   Frequency: %u Hz\n", wavinfo->frequency);
-      printf("   Duration: %u MBytes\n", video_body->getAudioLength()>>20);
+      { double du = video_body->getAudioLength();
+        uint16_t hh, mm, ss, ms;
+         du*=1000;
+         du/=wavinfo->byterate;
+         ms2time((uint32_t)floor(du), &hh, &mm, &ss, &ms);
+         printf("   Duration: %02d:%02d:%02d.%03d (%lu MBytes)\n", hh, mm, ss, ms, video_body->getAudioLength()>>20);
+      }
    }else{
       printf("   Codec: NONE\n");
       printf("   Mode: NONE\n");
@@ -608,21 +592,7 @@ int call_packedvop(void)
 }
 
 int set_output_format(const char *str){
-  Arg map;
-  int rc;
-	/* map to adm_script function and args */
-	/*
-	** JSC: have to change (const char*) to (char *) with max compatibility
-	** there are many dependencies if map.arg.string is changed to (char *) native
-	**    won't check them all :-)
-	*/
-	map.type = APM_STRING;
-	map.arg.string  = (char *)ADM_alloc(strlen(str)+1);
-	assert( map.arg.string );
-	strcpy( map.arg.string, str );
-	rc = scriptOutputFormat(-1,&map);
-	ADM_dealloc( map.arg.string );
-	return(rc);
+  	return A_setContainer(str);
 }
 
 void call_mono2stereo(char *p){
@@ -632,5 +602,112 @@ void call_mono2stereo(char *p){
 void call_stereo2mono(char *p){
    audioFilterStereo2Mono(1);
 }
+/*
+        return 0 if p is 0 or false or off
+        else 1
 
+*/
+uint8_t trueFalse(char *p)
+{
+int notdigit=0;
+        if(!p) return 0; // should not happen...
+
+        int l=strlen(p);
+        for(int i=0;i<l;i++) if(!isdigit(p[i])) notdigit=1;
+        if(!notdigit) // looks like a digit
+        {
+                l=atoi(p);
+                if(l) return 1;
+                return 0;
+        }
+        // It is a string
+        
+        uint8_t ret=1;
+
+        if(!strcasecmp(p,"off")) ret=0;
+        if(!strcasecmp(p,"false")) ret=0;
+
+        
+        return ret;
+
+}
+#define ADM_MAX_VAR 50
+typedef struct scriptVar
+{
+        char *name;
+        char *string;
+        int  isString;
+}scriptVar;
+
+
+static scriptVar myVars[ADM_MAX_VAR];
+uint32_t nbVar=0;
+
+/*
+        Push a var into the stack var
+
+*/
+uint8_t scriptAddVar(char *var,char *value)
+{
+        if(!var || !strlen(var)) 
+        {
+                printf("Script : Var name invalid\n");
+                return 0;
+        }
+        if(!value || !strlen(value)) 
+        {
+                printf("Script : value invalid\n");
+                return 0;
+        }
+        myVars[nbVar].name=ADM_strdup(var);
+        myVars[nbVar].string=ADM_strdup(value);
+        // check it is a number
+        uint8_t digit=1;
+        for(int i=0;i<strlen(value);i++)
+        {
+                 if(!isdigit(value[i]))
+                        {digit=0;break;}
+        }
+        if(digit)
+             myVars[nbVar].isString=0;
+        else
+             myVars[nbVar].isString=1;
+        nbVar++;
+        return 1;
+
+}
+/*
+       Retrieve a var in the stack
+
+*/
+
+
+char *script_getVar(char *in, int *r)
+{
+
+        printf("Get var called with in=[%s]\n",in);
+        for(uint32_t i=0;i<nbVar;i++)
+        {
+                if(myVars[i].name)
+                {
+                        if(!strcmp(myVars[i].name,in)) // skip the  $ 
+                        {
+                                *r=myVars[i].isString;
+                                return ADM_strdup(myVars[i].string);
+                        }
+
+                }
+        }
+        printf("Warning: var [%s] is unknown !\n");
+        return NULL;
+
+}
+
+void set_reuse_2pass_log(char *p){
+   prefs->set(FEATURE_REUSE_2PASS_LOG,1);
+}
+void call_v2v(char *a,char *b,char *c)
+{
+         ADM_vob2vobsub(a,b,c); //char *nameVob, char *nameVobSub, char *nameIfo);
+}
 //EOF
