@@ -220,7 +220,24 @@ void ms2time(uint32_t len2,uint16_t * hh, uint16_t * mm,
     *ms = (uint32_t) floor(len2);
 
 }
+void            time2frame(uint32_t *frame, uint32_t fps, uint32_t hh, uint32_t mm,
+                                uint32_t ss, uint32_t ms)
+{
+// convert everything to ms : uint32_t = 1000 hours, should be plenty enough
+uint32_t count=0;
+                count+=ms;
+                count+=ss*1000;
+                count+=mm*60*1000;
+                count+=hh*3600*1000;
+double d;
+                d=count;                
+                // ms
+                d=d*fps;
+                d/=1000;
+                d/=1000;
+                *frame= (uint32_t)(floor(d+0.5));
 
+}
 void UI_purge( void )
 {
 	
@@ -303,6 +320,7 @@ void gtk_write_entry_string(GtkWidget *entry, char *value)
 {
 
 gint r;
+                if(!value) return;
 		
 		gtk_editable_delete_text(GTK_EDITABLE(entry), 0,-1);
 		gtk_editable_insert_text(GTK_EDITABLE(entry), value, strlen(value), &r);
@@ -380,5 +398,36 @@ char 		*ADM_index(const char *s, int c)
 	}
 	return NULL;
 }
+uint8_t         ADM_fileExist(char *name)
+{
+FILE *file;
+                file=fopen(name,"rb");
+                if(!file) return 0;
+                fclose(file);
+                return 1;
 
+}
+/*
+    In some case (e.g. javascript), the reader expects unixish path 
+    c:/foo/bar/c.c
+    and the "natural" path is c:\foo\bar
+    
+    This function convert the later to the former
+
+*/
+extern char *slashToBackSlash(char *in)
+{
+    char *out,*cout;
+    int n;
+    n=strlen(in);
+    cout=out=(char *)ADM_alloc(n+1);   
+    for(int i=0;i<n+1;i++)
+    {
+        if(   in[i]=='\\') out[i]='/';
+        else    out[i]=in[i];
+        
+    }
+    return cout;
+    
+}
 //EOF
