@@ -48,24 +48,25 @@ static FILTER_PARAM ppParam={3,{"postProcType","postProcStrength","forcedQuant"}
 SCRIPT_CREATE(forcedpp_script,ADMVideoForcedPP,ppParam);
 BUILD_CREATE(forcedpp_create,ADMVideoForcedPP);
 
-extern int DIA_getMPParams( int *pplevel, int *ppstrength,int *swap);
+extern int DIA_getMPParams( uint32_t *pplevel, uint32_t *ppstrength,uint32_t *swap);
 
 uint8_t ADMVideoForcedPP::configure( AVDMGenericVideoStream *instream)
 {
 	_in=instream;
-	int postproc, strength,uv;
-	
+	uint32_t postproc, strength,uv;
+	int forced;
 		postproc=_param->postProcType;
 		strength=_param->postProcStrength;
 		uv=0;
 		if( DIA_getMPParams( &postproc,&strength,&uv))
 		{
 				_param->postProcType=postproc;
-				_param->postProcStrength=strength;				
-				uv=_param->forcedQuant;
-				if( DIA_GetIntegerValue(&uv,2,31, "Quant Value","Enter forced Q:"))
+				_param->postProcStrength=strength;
+                                
+				forced=_param->forcedQuant;
+				if( DIA_GetIntegerValue(&forced,2,31, "Quant Value","Enter forced Q:"))
 				{
-					_param->forcedQuant=uv;
+					_param->forcedQuant=forced;
 				}
 
 				updatePostProc(&_postproc );				
@@ -171,12 +172,13 @@ uint8_t ADMVideoForcedPP::getFrameNumberNoAlloc(uint32_t frame,
 			 		return 0;
 
 			oBuff[0]=YPLANE(data);
-			oBuff[1]=UPLANE(data);
- 			oBuff[2]=VPLANE(data);
+                        oBuff[1]=VPLANE(data);
+                        oBuff[2]=UPLANE(data);
+
 				
 			iBuff[0]=YPLANE(_uncompressed);
-		 	iBuff[1]=UPLANE(_uncompressed);
- 		 	iBuff[2]=VPLANE(_uncompressed);
+		 	iBuff[1]=VPLANE(_uncompressed);
+ 		 	iBuff[2]=UPLANE(_uncompressed);
 				
 				
 		        strideTab[0]=strideTab2[0]=_info.width;
