@@ -137,30 +137,16 @@ uint32_t	ADMVideoSubtitle::search(uint32_t time)
 void ADMVideoSubtitle::displayString(subLine *string)
 {
  
-	uint32_t base,last=0,line=0;	
-	char *ptr=NULL;
+	uint32_t base=0;	
 	uint32_t nbLine=0;
 	uint32_t i=0;
-	uint32_t suggestedLen=0;
-	
+	uint32_t overflow=0;
 
       aprintf("Sub: Rendering string %s\n",string);
-
-
 // bbase is the final position in line
 // in the image
 
-
-	base=0;
-
-	memset(_bitmapBuffer,0,_info.height*_info.width);
-	memset(_maskBuffer,0,_info.height*_info.width);
-  	memset(_bgBitmapBuffer,0,(_info.height*_info.width)>>1);
-  	memset(_bgMaskBuffer,0,_info.height*_info.width);
-
-	
-		
-	
+	clearBuffers();
 	nbLine=string->nbLine;
 	if(nbLine>SRT_MAX_LINE )
 	{
@@ -175,54 +161,226 @@ void ADMVideoSubtitle::displayString(subLine *string)
 		case 1:
 			base=_conf->_fontsize;; // 1 or 2 lines we dont use the upper line		
 			break;
-		default:break;
-		
+		default:
+                        base=0;
+                        break;
 	}	
 		
-	aprintf("Sub: %d lines to render\n",nbLine);						
- 
-  
-  	line=0;
+	aprintf("Sub: %d lines to render\n",nbLine);
 	// scan and display each line
 	for(i=0;i<nbLine;i++)
 	{
 		
-			displayLine(string->string[i],base,string->lineSize[i]);
+			if(string->lineSize[i]!=displayLine(string->string[i],base,string->lineSize[i]))
+                                overflow=1;
 			base+=_conf->_fontsize;
-			line++;
 		
 	}
+        if(overflow && _conf->_selfAdjustable) 
+        {
+                printf("Do autosplit\n");
+                doAutoSplit(string);
+        }
+    	doChroma();
+	// Compute the dirty state
+        // If a line is not set as dirty, it means it has no pixel in it
+        // In fact we do top/bottom and add a tiny bit to it
+        memset(_dirty,1,_info.height);
 
-    	
+        // First to top
+
+        int top=0,bottom=_info.height-1,limit;
+        while(top<_info.height && !isDirty(top)) top++;
+        if(top>_conf->_fontsize>>1) top-=_conf->_fontsize>>1;
+        memset(&(_dirty[0]),0,top); // Clear top
+        
+        // Then bottom
+        limit=(SRT_MAX_LINE+1)*_conf->_fontsize;
+        if(limit>=_info.height) limit=_info.height-1;
+
+
+        bottom=limit;
+        while(bottom>top && !isDirty(bottom)) bottom--;
+        if(bottom+(_conf->_fontsize>>1)<limit) bottom+=_conf->_fontsize>>1;
+        ADM_assert(bottom<=limit);
+        memset(&(_dirty[bottom]),0,limit-bottom+1);
+        //printf("Top:%d bottom :%d limit:%d\n",top,bottom,limit);
 	
-	// now blur bitmap into mask..
-	memset(_maskBuffer,0,SRT_MAX_LINE*_conf->_fontsize*_info.width);
+}
+uint8_t ADMVideoSubtitle::isDirty(int line)
+{
+        uint8_t *base=_maskBuffer+_info.width*line;
+        for(int x=0;x<_info.width;x++)
+        {
+                if(base[x]) return 1;
+        }
+        return 0;
+}
+/*
+        We merge the whole lines into one then split it
+        to avoid truncated subs
+*/
+void ADMVideoSubtitle::doAutoSplit(subLine *string)
+{
+        uint32_t base=0;    
+        uint32_t nbLine=0;
+        uint32_t i=0;
+        int      total=0,start,end,pivot;
 
-	uint32_t off;
-	uint8_t *src,*dst;
+        aprintf("Sub: Autospliting \n");
+        nbLine=string->nbLine;
 
-	off=0;
+        // Merge all strings into one
 
-	src=_bitmapBuffer;
-	dst=_maskBuffer;
+        for(int i=0;i<nbLine;i++) 
+                total+=1+string->lineSize[i];
+
+        ADM_GLYPH_T allwords[total];
+        int         offset[total];
+        int         sentence[total];
+        int         nbWords=0;
+        //
+        start=0;
+        for(int i=0;i<nbLine;i++) 
+        {
+                memcpy(&(allwords[start]),string->string[i],string->lineSize[i]*sizeof(ADM_GLYPH_T));
+                start+=string->lineSize[i];
+                allwords[start]=' ';
+                start++;
+        }
+        // Remove the last ' '
+        start--;
+        end=start;
+        // Here we go, we have now one line made of all merged sub
+        // We will put as much as possible into one displayed line
+        // then switch to the next one
+        //
+        printf("The new stuff is :<");
+        for(i=0;i<end;i++)
+                printf("%c",allwords[i]);
+        printf(">\n");
+        
+        // Split into words
+        pivot=0;
+        int car;
+        offset[0]=0;
+        nbWords=1;
+        while(pivot<end)
+        {
+                car=ADM_ASC(allwords[pivot]);
+                if(car==' ' || car=='.' || car ==',')
+                        {
+                                offset[nbWords++]=pivot;
+                        }
+                pivot++;
+        }
+        printf("Found %d words\n",nbWords); 
+        // Now  split
+        int nbSentence=0,len;
+        pivot=0;
+        sentence[0]=0;
+        // Try to display as much as possible in one line
+        // We build sentence here
+        while(pivot<nbWords)
+        {
+                for(i=pivot+1;i<nbWords;i++)
+                {
+                        len=offset[i]-offset[pivot];
+                        if(len!=displayLine(&(allwords[offset[pivot]]),0,len)) break;
+                }
+                sentence[nbSentence]=offset[pivot];
+                nbSentence++;
+                if(i>1 && i!=nbWords) i--;
+                pivot=i;
+        }
+        printf("0: %d,off:%d\n",sentence[0],offset[0]);
+        // Take the last word
+        sentence[nbSentence]=end;
+
+        if(nbSentence>SRT_MAX_LINE) nbSentence=SRT_MAX_LINE;
+        // now display
+        printf("Nb sentence:%d\n",nbSentence);
+        for(int j=0;j<nbSentence;j++)
+        {
+                printf("Sentence %d:",j);
+                for(int k=sentence[j];k<sentence[j+1];k++)
+                        printf("%c",allwords[k]);
+                printf("\n");
+        }
+        // now display
+        
+        switch(nbSentence)
+        {
+                case 0:
+                        base=2*_conf->_fontsize;; // 1 or 2 lines we dont use the upper line            
+                        break;
+                case 1:
+                        base=_conf->_fontsize;; // 1 or 2 lines we dont use the upper line              
+                        break;
+                default:
+                        base=0;
+                        break;
+        }
+        // scan and display each line
+        clearBuffers();
+        printf("Display\n");
+        for(i=0;i<nbSentence;i++)
+        {
+                        len=sentence[i+1]-sentence[i];
+                        displayLine(&(allwords[sentence[i]]),base,len);
+                        //displayLine(allwords,base,10);
+                        base+=_conf->_fontsize;
+        }
+        printf("/Display\n");
+        
+}
+/*
+        Once we have the subtitle built, we do the u& v planes
+        and some smoothing to avoid over sharpening on the chroma plane
+
+*/
+uint8_t ADMVideoSubtitle::doChroma(void)
+{
+// now blur bitmap into mask..
+        memset(_maskBuffer,0,SRT_MAX_LINE*_conf->_fontsize*_info.width);
+
+        uint32_t off;
+        uint8_t *src,*dst;
+
+        off=0;
+
+        src=_bitmapBuffer;
+        dst=_maskBuffer;
 
 
-	// We shrink it down for u & v by 2x2
-	// mask buffer->bitmap buffer
+        // We shrink it down for u & v by 2x2
+        // mask buffer->bitmap buffer
 
-	uint8_t tmp[_info.width*_info.height];
+        uint8_t tmp[_info.width*_info.height];
 
-	decimate(src,tmp,_info.width,_info.height);
-	lowPass(src,dst,_info.width,_info.height);
-	lowPass(tmp,src,_info.width>>1,_info.height>>1);
+        decimate(src,tmp,_info.width,_info.height);
+        lowPass(src,dst,_info.width,_info.height);
+        lowPass(tmp,src,_info.width>>1,_info.height>>1);
 
-  	if (_conf->_useBackgroundColor) 
-	{
-    		decimate(_bgMaskBuffer,_bgBitmapBuffer,_info.width,_info.height);
-    		//lowPass(tmp,_bgBitmapBuffer,_info.width>>1,_info.height>>1);
-  	}
+        if (_conf->_useBackgroundColor) 
+        {
+                decimate(_bgMaskBuffer,_bgBitmapBuffer,_info.width,_info.height);
+                //lowPass(tmp,_bgBitmapBuffer,_info.width>>1,_info.height>>1);
+        }
   
 }
+/*
+        Clear the buffers in case we do a new sub or
+                redo one in case it overflows
+*/
+uint8_t ADMVideoSubtitle::clearBuffers(void)
+{
+        memset(_bitmapBuffer,0,_info.height*_info.width);
+        memset(_maskBuffer,0,_info.height*_info.width);
+        memset(_bgBitmapBuffer,0,(_info.height*_info.width)>>1);
+        memset(_bgMaskBuffer,0,_info.height*_info.width);
+        return 1;
+}
 // Display a full line centered on screen. It returns the
 // number of displayed chars.
 //____________________________________________________________
@@ -444,24 +602,65 @@ uint8_t ADMVideoSubtitle::blend(uint8_t *target,uint32_t baseLine)
 	mask=_maskBuffer;
   	bgMask=_bgMaskBuffer;
  	target+=start;
-  	for( y=hei;y>0;y--)
-	{
-      if(*mask) {
-	if(*mask>LUMA_LEVEL || _conf->_useBackgroundColor)
-			{
-				val=*mask*_conf->_Y_percent+128;
-				val>>=8;
-				*target=(uint8_t )val;
-			}
-	else { *target=0; }
-      } else if(_conf->_useBackgroundColor && *bgMask) {
-	*target=(uint8_t )_conf->_bg_Y_percent;
-      }	  
-      
-		target++;
-		mask++;
-      bgMask++;
-	}
+        // clip 
+        if(hei+start>_info.width*_info.height)
+        {
+                hei=_info.width*_info.height-start;
+        }
+// Luma
+        int bottom=baseLine+(SRT_MAX_LINE+1)*_conf->_fontsize;
+        if(bottom>_info.height) bottom=_info.height;
+        for( y=baseLine;y<bottom;y++)
+        {
+            if(!_dirty[y-baseLine])
+            {
+                target+=_info.width;
+                mask+=_info.width;
+                bgMask+=_info.width;
+                 continue;
+            }
+            for(int x=0;x<_info.width;x++)
+            {
+                if(*mask) {
+                                if(*mask>LUMA_LEVEL || _conf->_useBackgroundColor)
+                                {
+                                        val=*mask*_conf->_Y_percent+128;
+                                        val>>=8;
+                                        *target=(uint8_t )val;
+                                }
+                                else 
+                                        { *target=0; }
+                        } else 
+                        if(*bgMask)
+                        {
+                                if(_conf->_useBackgroundColor) 
+                                {
+                                        *target=(uint8_t )_conf->_bg_Y_percent;
+                                }
+                        }
+                        else
+                                {
+                                        switch(_conf->_blend)
+                                        {
+                                                case BLEND_SOLID: break;
+                                                case BLEND_DIMMER: *target=(*target*3)>>2;break;
+                                                case BLEND_DOTTED: 
+                                                {
+                                                        int odd;
+                                                                odd= y%_info.width;
+                                                                odd=odd&1;
+                                                                odd+=(1&(y/_info.width));
+                                                                odd&=1;
+                                                                if(odd) *target=0; 
+                                                }
+                                        }
+                                }
+                        
+                target++;
+                mask++;
+                bgMask++;
+              }
+        }
 	
 
 // do u & v
