@@ -40,8 +40,6 @@
 #include "ADM_video/ADM_vidFlipV.h"
 #include "ADM_filter/video_filters.h"
 
-#include "ADM_mpeg2dec/ADM_mpegpacket.h"
-#include "ADM_mpeg2dec/ADM_mpegpacket_PS.h"
 
 #include "ADM_toolkit/filesel.h"
 
@@ -60,7 +58,7 @@
 
 extern uint8_t DIA_vobsub(vobSubParam *param);
 
-static FILTER_PARAM vobsubParam={1,{"subname"}};
+static FILTER_PARAM vobsubParam={3,{"subname","index","subShift"}};
 //*************************************************************
 //
 
@@ -157,7 +155,8 @@ uint32_t top=0,bottom=0;
     ADM_assert(nb<_vobSubInfo->nbLines);
     
     // Seek & decode
-    _parser->_asyncJump2(0,_vobSubInfo->lines[nb].fileOffset);
+    //_parser->_asyncJump2(0,_vobSubInfo->lines[nb].fileOffset);
+    _parser->setPos(_vobSubInfo->lines[nb].fileOffset,0);
     if(!handleSub(nb))
         {
                 printf("Error reading getBimap\n");
@@ -171,7 +170,7 @@ uint32_t top=0,bottom=0;
         _original->buildYUV(_YUVPalette);
         ox=_original->_width;        
         oy=_original->_height;
-        printf("Original :%lu x %lu\n",ox,oy);
+        printf("Original :%lu x %lu (original  %d)\n",ox,oy,_vobSubInfo->height);
         ADM_assert(oy<=_vobSubInfo->height);
         
         // Search the 1st/last non null line
@@ -180,13 +179,16 @@ uint32_t top=0,bottom=0;
          *first=0;
          *last=oy-1;   
 #else
-        while(top<oy && !_original->isDirty(top)) top++;
+        if(oy>_original->_height) oy=_original->_height-1;
+
+        while(top<oy && !_original->isDirty(top) ) top++;
         
         if(top==oy)
         {
                 top=bottom=0;   // Empty bitmap ?
                 *first=top;
                 *last=bottom;
+                printf("Empry bitmap\n");
                 return NULL; 
         }
         bottom=oy-1;
@@ -246,9 +248,12 @@ uint8_t ADMVideoVobSub::setup(void)
                 {
                         printf("Opening index \n");
                        
-                        
-                        _parser=new ADM_mpegDemuxerProgramStream(_param->index+0x20,0xe0);
-                        
+                        MPEG_TRACK track;
+                        memset(&track,0,sizeof(track));
+                        track.pes=_param->index+0x20;
+                        track.pid=0;
+                       // _parser=new ADM_mpegDemuxerProgramStream(_param->index+0x20,0xe0);
+                        _parser=new dmx_demuxerPS(1,&track,0);
                         if(!_parser->open(dup))
                         {
                                 printf("Mpeg Parser : opening %s failed\n",_param->subname);
@@ -399,8 +404,9 @@ uint32_t sub;
         // If it is a new sub, decode it...
         if(sub!=_currentSub )
         {                
-                 _parser->_asyncJump2(0,_vobSubInfo->lines[sub].fileOffset);
-                 _initialPts=_parser->getPTS();
+                // _parser->_asyncJump2(0,_vobSubInfo->lines[sub].fileOffset);
+                _parser->setPos(_vobSubInfo->lines[sub].fileOffset,0);
+                 //_initialPts=_parser->getPTS();
                  handleSub(sub);
                 _currentSub=sub;
                 Palettte2Display(); // Create the bitmap
@@ -565,9 +571,18 @@ uint8_t ADMVideoVobSub::Palettte2Display( void )
         
         // Search the 1st/last non null line
         uint32_t top=0,bottom=0;
+
+        if(oy>_original->_height) oy=_original->_height-1;
+
         while(top<oy && !_original->isDirty(top)) top++;
         
         bottom=_original->_height-1;
+        if(top==bottom)
+        {
+                printf("Empty sub ?");
+                return 0;
+        }
+        
         while(bottom && !_original->isDirty(bottom)) bottom--;
         
         // If true it means we have 2 subs, one on top, one on bottom
