@@ -14,7 +14,8 @@
 #include "swscale.h"
 //#include "cpudetect.h"
 #include "../admmangle.h"
-#include "../../adm_lavcodec/bswap.h"
+#define always_inline inline
+#include "bswap.h"
 //#include "../libvo/fastmemcpy.h"
 #include "wrapper.h"
 #define FAST_BGR2YV12 // use 7 bit coeffs instead of 15bit
