@@ -53,7 +53,7 @@ untested special converters
 #include <string.h>
 #include <math.h>
 #include <stdio.h>
-//#include <unistd.h>
+#include <unistd.h>
 #include "../../config.h"
 #include "../admmangle.h"
 //#include <assert.h>
@@ -74,7 +74,8 @@ untested special converters
 #include "swscale.h"
 #include "swscale_internal.h"
 //#include "cpudetect.h"
-#include "../../adm_lavcodec/bswap.h"
+#define always_inline inline //MEANX
+#include "bswap.h"
 #include "img_format.h"
 #include "rgb2rgb.h"
 //#include "../libvo/fastmemcpy.h"
@@ -115,7 +116,7 @@ untested special converters
 #define isBGR(x)       (((x)&IMGFMT_BGR_MASK)==IMGFMT_BGR)
 #define isSupportedIn(x)  ((x)==IMGFMT_YV12 || (x)==IMGFMT_YUY2 || (x)==IMGFMT_UYVY\
 			|| (x)==IMGFMT_BGR32|| (x)==IMGFMT_BGR24|| (x)==IMGFMT_BGR16|| (x)==IMGFMT_BGR15\
-			|| (x)==IMGFMT_RGB32|| (x)==IMGFMT_RGB24\
+			|| (x)==IMGFMT_RGB32|| (x)==IMGFMT_RGB24|| (x)==IMGFMT_RGB16|| (x)==IMGFMT_RGB15\
 			|| (x)==IMGFMT_Y800 || (x)==IMGFMT_YVU9\
 			|| (x)==IMGFMT_444P || (x)==IMGFMT_422P || (x)==IMGFMT_411P)
 #define isSupportedOut(x) ((x)==IMGFMT_YV12 || (x)==IMGFMT_YUY2 || (x)==IMGFMT_UYVY\
