@@ -39,6 +39,7 @@
 #include "ADM_encoder/adm_encConfig.h"
 #include "prefs.h"
 #include "ADM_audiodevice/audio_out.h"
+#include "ADM_script/ADM_JSGlobal.h"
 
 #ifdef USE_XVID_4
 extern void xvid4_init(void);
@@ -72,16 +73,23 @@ extern uint8_t dloadXvidCVS( void );
 
 extern void  buildDistMatrix( void );
 extern void initScaleTab( void );
-extern void initEncoders( void );
 extern uint8_t initGUI( void );
 extern void ADM_memStat( void );
+extern uint8_t oplug_mpegInit(void);
+extern void     COL_init(void);
+extern uint8_t  initFileSelector(void);
+
 extern "C"
 {
 extern void     VPInitLibrary();
+
+
 };
 
+
 void sig_segfault_handler(int signo);
 
+extern uint8_t  quotaInit(void);
 extern void ADMImage_stat( void );
 int global_argc;
 char **global_argv;
@@ -121,7 +129,7 @@ printf("\n LARGE FILE AVAILABLE : %d offset\n",  __USE_FILE_OFFSET64	);
 	printf(" Code      : Mean & JSC \n");
 	printf(" GFX       : Nestor Di , nestordi@augcyl.org\n");
 	printf(" Testing   : Jakub Misak\n");
-	printf(" FreeBsd   : Anish Mistry, amistry@am-productions.biz\n");
+	printf(" FreeBSD   : Anish Mistry, amistry@am-productions.biz\n");
 
 
 #if (defined( ARCH_X86)  || defined(ARCH_X86_64))
@@ -146,8 +154,14 @@ printf("\n LARGE FILE AVAILABLE : %d offset\n",  __USE_FILE_OFFSET64	);
 #ifdef USE_XVID_4
 	xvid4_init();
 #endif
+        initFileSelector();
 	CpuCaps::init();
 	ADM_InitMemcpy();
+	
+// Load .avidemuxrc
+    quotaInit();
+    prefs->load();
+
    if(!initGUI())
     	{
 		printf("\n Fatal : could not init GUI\n");
@@ -166,15 +180,14 @@ printf("\n LARGE FILE AVAILABLE : %d offset\n",  __USE_FILE_OFFSET64	);
 				mpegps_init();
 	                  
 #endif
-// Load .avidemuxrc
-    prefs->load();
 #ifdef HAVE_AUDIO
     AVDM_audioInit();
 #endif    
     buildDistMatrix();
     initScaleTab();
-    initEncoders();
+
     loadEncoderConfig();
+    COL_init();
     
    
     if (argc >= 2)
@@ -188,7 +201,14 @@ printf("\n LARGE FILE AVAILABLE : %d offset\n",  __USE_FILE_OFFSET64	);
    	printf("Global SDL init...\n");
    	SDL_Init(0); //SDL_INIT_AUDIO+SDL_INIT_VIDEO);
    #endif
+    oplug_mpegInit();
+	if(SpidermonkeyInit() == true)
+		printf("Spidermonkey initialized.\n");
+
     gtk_main();
+
+	SpidermonkeyDestroy();
+
     return 0;
 }
 void onexit( void )
