@@ -21,12 +21,7 @@
 
 #include "mpeg2parm.h"
 #include "ADM_mpeg2Param.h"
-typedef struct MPEG2ENCConfig
-{
-		COMPRES_PARAMS generic;
-		Mpeg2encParam specific;
-		unsigned int configured; // 0 == defaults, 1 == configured by user or prefs or saved_file
-}MPEG2ENCConfig;
+
 
 #define MPG_4_3 	2
 #define MPG_16_9 	3
