@@ -42,6 +42,7 @@
 #include "avilist.h"
 #include "op_aviwrite.hxx"
 #include "ADM_toolkit/toolkit.hxx"
+#include "ADM_toolkit/ADM_quota.h"
 #include "ADM_library/ADM_fileio.h"
 
 // MOD Feb 2005 by GMV
@@ -271,6 +272,13 @@ uint32_t extraLen=0;
       
 	switch(wav.encoding)
 	{
+                case WAV_IMAADPCM:
+                        wav.blockalign=1024;
+                        header->dwScale         = wav.blockalign;
+                        header->dwSampleSize    = 1;
+                        header->dwInitialFrames =1;                             
+                        header->dwSuggestedBufferSize=2048;                                
+                        break;
 		case WAV_AAC:
 		{
 		// nb sample in stream  
@@ -368,6 +376,7 @@ uint32_t extraLen=0;
 			break;
           case WAV_8BITS_UNSIGNED:
                         wav.encoding=WAV_PCM;
+			header->dwScale 	= 1;
                         wav.bitspersample=8;
                         break;
                         
@@ -429,7 +438,7 @@ uint8_t aviWrite::saveBegin (char 	*name,
 
 //  Sanity Check
         ADM_assert (_out == NULL);
-        if (!(_out = fopen (name, "wb")))
+        if (!(_out = qfopen (name, "wb")))
         {
                 printf("Problem writing : %s\n",name);
                 return 0;
@@ -450,10 +459,11 @@ uint8_t aviWrite::saveBegin (char 	*name,
 //
         memcpy (&_mainheader, inmainheader, sizeof (MainAVIHeader));
         _mainheader.dwFlags = AVIF_HASINDEX + AVIF_ISINTERLEAVED;
-        if(!_mainheader.dwMicroSecPerFrame)
+        if(_mainheader.dwMicroSecPerFrame<10000) // Less than 10 ms
         {
                 _mainheader.dwMicroSecPerFrame=40000;
         }
+        
 // update main header codec with video codev
         if (inaudiostream)
         {
@@ -477,7 +487,15 @@ uint8_t aviWrite::saveBegin (char 	*name,
   	_videostream.dwLength = nb_frame;
 	_videostream.fccType=fourCC::get((uint8_t *)"vids");
 	memcpy(&_bih,bih,sizeof(_bih));
-	
+
+        // Recompute image size
+uint32_t is;	
+        is=_bih.biWidth*_bih.biHeight;
+        is*=(_bih.biBitCount+7)/8;
+        _bih.biSizeImage=is;
+
+
+
 	// MOD Feb 2005 by GMV: initialize ODML data
 	// test for free data structures
 	if(odml_indexes!=NULL){
@@ -502,7 +520,15 @@ uint8_t aviWrite::saveBegin (char 	*name,
 		odml_nbrof_streams=_mainheader.dwStreams;
 		aprintf("\nnumber of streams: %lu\n",odml_nbrof_streams);
 		// get number of frames per index
+
 		odml_index_size=(long)ceil(1000000.0/(double)_mainheader.dwMicroSecPerFrame*600.0);	// one index per 10 Minutes; decrease if 4GB are not enough for this amount of time 
+                aprintf("\n old number of frames per index: %lu\n",odml_index_size);
+                double fps=invideostream->dwRate/invideostream->dwScale;      
+
+                        aprintf("Fps1000:%f\n",fps);
+                        fps=600*fps; // 10 mn worth;
+                odml_index_size=floor(fps);
+
 		aprintf("\nnumber of frames per index: %lu\n",odml_index_size);
 		// get number or indexes per stream
 		odml_nbrof_index=(long)ceil((double)nb_frame/(double)odml_index_size);
@@ -739,7 +765,7 @@ if(doODML!=NORMAL){
   delete _file;
   _file=NULL;
   
-  fclose (_out);
+  qfclose (_out);
   _out = NULL;
   return 1;
 
@@ -857,7 +883,7 @@ void aviWrite::odml_write_dummy_chunk(AviList* alist, uint64_t* fpos, uint32_t s
 }
 bool aviWrite::odml_index_frame(int stream_nbr, uint32_t data_size, bool keyFrame){
 	if(doODML!=NO){
-		ADM_assert(!stream_nbr<odml_nbrof_streams);
+//		ADM_assert(!stream_nbr<odml_nbrof_streams);
 		odml_super_index_t* sidx=odml_indexes+stream_nbr;	// access to super index
 		if(sidx->odml_index[sidx->index_count].nEntriesInUse==odml_index_size){	// new index needed?
 			if(sidx->index_count<odml_nbrof_index-1)	// can index counter be increased?
