@@ -16,12 +16,12 @@
  ***************************************************************************/
 
 
-void oplug_mpeg_vcd(char *name);
-void oplug_mpeg_vcd_ps(char *name);
-void oplug_mpeg_svcd(char *name=NULL);
-void oplug_mpeg_dvd(char *name=NULL);
-void oplug_mpeg_dvd_ps(char *name=NULL);
-void oplug_mpeg_svcd_ps(char *inname=NULL);
-void oplug_mpeg_ts(char *inname=NULL);
+uint8_t oplug_mpeg_vcd(const char *name);
+uint8_t oplug_mpeg_vcd_ps(const char *name);
+uint8_t oplug_mpeg_svcd(const char *name=NULL);
+uint8_t oplug_mpeg_dvd(const char *name=NULL);
+uint8_t oplug_mpeg_dvd_ps(const char *name=NULL);
+uint8_t oplug_mpeg_svcd_ps(const char *inname=NULL);
+uint8_t oplug_mpeg_ts(const char *inname=NULL);
 
 
