@@ -36,6 +36,7 @@
 
 #include "ADM_lavcodec.h"
 #include "fourcc.h"
+#include "ADM_toolkit/ADM_quota.h"
 #include "avi_vars.h"
 #include "ADM_toolkit/toolkit.hxx"
 #include <ADM_assert.h>
@@ -90,8 +91,12 @@
 #warning FIXME: Duplicate define with mpeg2enc -> bad
 #define MPEG_PREFILL 5
 
-extern MPEG2ENCConfig mpeg2encSVCDConfig;
-extern MPEG2ENCConfig mpeg2encDVDConfig;
+#include "ADM_encoder/adm_encConfig.h"
+#include "ADM_encoder/ADM_vidEncode.hxx"
+
+extern Mpeg2encParam SVCDExtra,DVDExtra; 
+extern COMPRES_PARAMS SVCDCodec,DVDCodec;
+
 extern uint8_t audioShift;
 extern int32_t audioDelay;
 // IF set do 1st pass with CBR with max bitrate = average bitrate AND disabling padding
@@ -147,7 +152,7 @@ mpegWritter::~mpegWritter(  )
 
 }
 /*---------------------------------------------------------------------------------------*/
-uint8_t  mpegWritter::save_svcd(char *name)
+uint8_t  mpegWritter::save_svcd(const char *name)
 {
 	if(_outputAs)
 	{
@@ -164,36 +169,37 @@ uint8_t  mpegWritter::save_svcd(char *name)
 				break;
 		}
 	}
-	switch(mpeg2encSVCDConfig.generic.mode)
+	switch(SVCDCodec.mode)
 	{
 		case COMPRESS_CBR:
 			return  save_regular(name, ADM_SVCD,
 						0, 
-						mpeg2encSVCDConfig.generic.bitrate,
-						mpeg2encSVCDConfig.specific.user_matrix,
-						mpeg2encSVCDConfig.specific.interlaced,
-    						mpeg2encSVCDConfig.specific.bff,         // WLA
-						mpeg2encSVCDConfig.specific.widescreen
+						SVCDCodec.bitrate,
+						SVCDExtra.user_matrix,
+						SVCDExtra.interlaced,
+    					SVCDExtra.bff,         // WLA
+						SVCDExtra.widescreen
 						);
 			break;
 		case COMPRESS_CQ:
 			return  save_regular(name, ADM_SVCD,
-					 	mpeg2encSVCDConfig.generic.qz,
-						8*mpeg2encSVCDConfig.specific.maxBitrate,
-						mpeg2encSVCDConfig.specific.user_matrix,
-						mpeg2encSVCDConfig.specific.interlaced,
-						mpeg2encSVCDConfig.specific.bff,         // WLA
-						mpeg2encSVCDConfig.specific.widescreen
+					 	SVCDCodec.qz,
+						8*SVCDExtra.maxBitrate,
+						SVCDExtra.user_matrix,
+						SVCDExtra.interlaced,
+						SVCDExtra.bff,         // WLA
+						SVCDExtra.widescreen
 								);
 			break;
 		case COMPRESS_2PASS:
-			return  save_dualpass(name,mpeg2encSVCDConfig.generic.finalsize,
-						8*mpeg2encSVCDConfig.specific.maxBitrate,
+			return  save_dualpass(name,SVCDCodec.finalsize,
+						8*SVCDExtra.maxBitrate,
 						ADM_SVCD,
-						mpeg2encSVCDConfig.specific.user_matrix,
-						mpeg2encSVCDConfig.specific.interlaced,
-						mpeg2encSVCDConfig.specific.bff,         // WLA
-						mpeg2encSVCDConfig.specific.widescreen
+						SVCDExtra.user_matrix,
+						SVCDExtra.interlaced,
+						SVCDExtra.bff,         // WLA
+						SVCDExtra.widescreen
+								
 								);
 		break;
 	}
@@ -206,6 +212,7 @@ uint8_t  mpegWritter::save_svcd(char *name)
 #define PACK_AUDIO \
 { \
 	uint32_t samples; \
+        if(audioGot<sample_target) \
 	while(_muxer->needAudio()) \
 	{				\
 		if(!_audio->getPacket(_audioBuffer, &audiolen, &samples))	\
@@ -217,11 +224,11 @@ uint8_t  mpegWritter::save_svcd(char *name)
 			_muxer->writeAudioPacket(audiolen,_audioBuffer); \
 			encoding->feedAudioFrame(audiolen); \
 		}\
-		audioGot+=audiolen; \
+		audioGot+=samples; \
 	} \
 }
 /*---------------------------------------------------------------------------------------*/
-uint8_t  mpegWritter::save_dvd(char *name)
+uint8_t  mpegWritter::save_dvd(const char *name)
 {
 AVDMGenericAudioStream 	*tmp=NULL;
 WAVHeader		*info=NULL,tmpinfo;	
@@ -246,39 +253,39 @@ WAVHeader		*info=NULL,tmpinfo;
 		}
 	}
 
-	switch(mpeg2encDVDConfig.generic.mode)
+	switch(DVDCodec.mode)
 	{
 		case COMPRESS_CBR:
 			printf("Dvd encoding in CBR mode\n");
 			return  save_regular(name, ADM_DVD,0, 
-						mpeg2encDVDConfig.generic.bitrate ,
-						mpeg2encDVDConfig.specific.user_matrix,
-						mpeg2encDVDConfig.specific.interlaced,
-						mpeg2encDVDConfig.specific.bff,         // WLA
-						mpeg2encDVDConfig.specific.widescreen
+						DVDCodec.bitrate ,
+						DVDExtra.user_matrix,
+						DVDExtra.interlaced,
+						DVDExtra.bff,         // WLA
+						DVDExtra.widescreen
 						);
 			break;
 		case COMPRESS_CQ:
 			printf("Dvd encoding in CQ mode\n");
 			return  save_regular(name, ADM_DVD,
-						 mpeg2encDVDConfig.generic.qz,
-						 8*mpeg2encDVDConfig.specific.maxBitrate ,
-						 mpeg2encDVDConfig.specific.user_matrix,
-						 mpeg2encDVDConfig.specific.interlaced,
-						mpeg2encDVDConfig.specific.bff,         // WLA
-						mpeg2encDVDConfig.specific.widescreen
+						 DVDCodec.qz,
+						 8*DVDExtra.maxBitrate ,
+						 DVDExtra.user_matrix,
+						 DVDExtra.interlaced,
+						 DVDExtra.bff,         // WLA
+						 DVDExtra.widescreen
 						);
 			break;
 		case COMPRESS_2PASS:
 			printf("Dvd encoding in 2pass mode\n");
 			return  save_dualpass(name,
-						mpeg2encDVDConfig.generic.finalsize,
-						8*mpeg2encDVDConfig.specific.maxBitrate,
+						DVDCodec.finalsize,
+						8*DVDExtra.maxBitrate,
 						ADM_DVD,
-						mpeg2encDVDConfig.specific.user_matrix,
-						mpeg2encDVDConfig.specific.interlaced,
-						mpeg2encDVDConfig.specific.bff,         // WLA
-						mpeg2encDVDConfig.specific.widescreen
+						DVDExtra.user_matrix,
+						DVDExtra.interlaced,
+						DVDExtra.bff,         // WLA
+						DVDExtra.widescreen
 						);
 		break;
 	}
@@ -289,7 +296,7 @@ WAVHeader		*info=NULL,tmpinfo;
 // 										Do the actual save
 // ______________________________________________
 
-uint8_t  mpegWritter::save_vcd(char *name)
+uint8_t  mpegWritter::save_vcd(const char *name)
 {
 
 // look if we have a suitable audio
@@ -316,7 +323,7 @@ uint8_t  mpegWritter::save_vcd(char *name)
 	Save as with the external mpeg2enc
 
 */
-uint8_t mpegWritter::save_regular(char *name, ADM_MPEGTYPE mpegtype, int qz, int bitrate,int matrix,
+uint8_t mpegWritter::save_regular(const char *name, ADM_MPEGTYPE mpegtype, int qz, int bitrate,int matrix,
 					uint8_t interlaced,
 					uint8_t bff,        // WLA
 					uint8_t widescreen)
@@ -330,26 +337,31 @@ uint32_t		len,flags;
 uint32_t 		outquant;
 uint32_t		audiolen=0;
 DIA_encoding		*encoding;
+uint32_t                sample_target=0;
+double                  sample_time;
 
    	incoming = getLastVideoFilter (frameStart,frameEnd-frameStart);
 	_total=incoming->getInfo()->nb_frames;
 	_fps1000=incoming->getInfo()->fps1000;
-	if(!_total) return 0;
+	if(!_total){
+		GUI_Error_HIG("No frames to encode","Please check markers. Is \"A>\" == \">B\"?");
+		return 0;
+	}
 
 	printf("Br:%d, qz:%d\n",bitrate,qz);
 	if(!_audio)
 	{
-		fd=fopen(name,"wb");
-		if(!fd)
-		{
-			GUI_Alert("Problem opening file!");
+		if(!(fd=qfopen(name,"wb")))
 			return 0;			
-		}
 	}
 	else
 	{
 		ADM_assert(_muxer);
-		
+                sample_time=_total;
+                sample_time*=1000;
+                sample_time/=_fps1000; // target_time in second
+                sample_time*=_audio->getInfo()->frequency;
+                sample_target=(uint32_t)floor(sample_time);
 
 	}
 
@@ -423,7 +435,7 @@ DIA_encoding		*encoding;
 	printf("\n--encoding started--\n");
 	if(_muxer)
 	{
-            if(audioProcessMode)
+            if(audioProcessMode())
                 encoding->setAudioCodec(getStrFromAudioCodec(_audio->getInfo()->encoding));
             else
                 encoding->setAudioCodec("Copy");
@@ -447,9 +459,9 @@ DIA_encoding		*encoding;
 					aImage,&flags))
 				{
 						delete encoding;
-               					GUI_Alert("Encoding error !");
+               					GUI_Error_HIG("Encoding error", NULL);
 						if(fd)
-							fclose(fd);
+							qfclose(fd);
 						end();
 						return 0 ;
 				}
@@ -469,7 +481,7 @@ DIA_encoding		*encoding;
 						
 				}else
 				{
-					fwrite(_buffer_out,len,1,fd);
+					qfwrite(_buffer_out,len,1,fd);
 					fflush(fd);
 				}
 									
@@ -480,7 +492,7 @@ DIA_encoding		*encoding;
 						delete encoding;
 						end();
 						if(fd)
-						  fclose(fd);
+						  qfclose(fd);
 						 return 0;
 					}
 			}
@@ -491,7 +503,7 @@ DIA_encoding		*encoding;
 				total_size+=len;
 				encoding->feedFrame(len);
 				if(!_muxer)
-					fwrite(_buffer_out,len,1,fd);
+					qfwrite(_buffer_out,len,1,fd);
 				else
 				{
 					_muxer->writeVideoPacket(len,_buffer_out,
@@ -506,7 +518,7 @@ DIA_encoding		*encoding;
 			delete encoding;
 			
 			if(!_muxer)
-				fclose(fd);
+				qfclose(fd);
 			else
 			{
 				_muxer->close();
@@ -523,13 +535,14 @@ DIA_encoding		*encoding;
 
 DIA_encoding *encoding;
 /*-------------------------------------------------------------------------------------------------------------------*/
-uint8_t  mpegWritter::save_dualpass(char *name,uint32_t final_size,uint32_t bitrate,ADM_MPEGTYPE mpegtype,
+uint8_t  mpegWritter::save_dualpass(const char *name,uint32_t final_size,uint32_t bitrate,ADM_MPEGTYPE mpegtype,
 					int matrix,uint8_t interlaced,
 					uint8_t bff,        // WLA
 					uint8_t widescreen)
 {
 AVDMGenericVideoStream	 *incoming;
 char *statname;
+uint8_t reuse=0;
 
 	incoming = getLastVideoFilter (frameStart,frameEnd-frameStart);
 	_w=incoming->getInfo()->width;
@@ -553,14 +566,14 @@ char *statname;
 
 
 	// check if stat file exists ?
-	uint8_t reuse=0;
 #if 1 //ndef CYG_MANGLING	
-	FILE *fd;	
-	fd=fopen(statname,"rt");
-	if(fd)
-	{
-		fclose(fd);
-		if(GUI_Question("Reuse log file ?")) reuse=1;
+	{ FILE *fd;	
+		fd=fopen(statname,"rt");
+		if(fd){
+			fclose(fd);
+			prefs->get(FEATURE_REUSE_2PASS_LOG,(uint8_t*)&reuse);
+			if( !reuse && GUI_Question("Reuse log file ?") ) reuse=1;
+		}
 	}
 #endif	
 	//_ratecontrol=new ADM_oldXvidRc(_fps1000,statname);
@@ -573,7 +586,7 @@ if(!reuse)
 	// WLA
 	{
 		delete encoding;
-		GUI_Alert("Error in pass 1");
+		GUI_Error_HIG("Error in pass 1", NULL);
 		delete [] statname;
 		return 0;
 	}
@@ -583,7 +596,7 @@ if(!reuse)
 	// WLA
 	{
 		delete encoding;
-		GUI_Alert("Error in pass 2");
+		GUI_Error_HIG("Error in pass 2", NULL);
 		delete [] statname;
 		return 0;
 	}
@@ -592,7 +605,7 @@ if(!reuse)
 	return 1;
 }
 /*-------------------------------------------------------------------------------------------------------*/
-uint8_t  mpegWritter::dopass1(char *name,char *statname,uint32_t final_size,uint32_t bitrate,
+uint8_t  mpegWritter::dopass1(const char *name,char *statname,uint32_t final_size,uint32_t bitrate,
 				ADM_MPEGTYPE mpegtype,int matrix,uint8_t interlaced,
 					uint8_t bff,        // WLA
 					uint8_t widescreen)
@@ -679,7 +692,7 @@ int intra,q;
 		_codec->setQuantize(q);
         	if(!incoming->getFrameNumberNoAlloc(i, &size,aImage,&flags))
 		{
-        		GUI_Alert("Encoding error !");
+        		GUI_Error_HIG("Encoding error", NULL);
 			end();
 			return 0 ;
 		}
@@ -744,7 +757,7 @@ int intra,q;
 	return 1;
 }
 /*--------------------------------------------------------------------*/
-uint32_t		quantstat[] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
+uint32_t quantstat[32]; /* 0-31 ; 0 and 1 are unused */
 void print_quant_stat(const char *n){
   char *str = (char*)ADM_alloc( strlen(n) + 4 );
   unsigned int i=2,sum=0,total=0;
@@ -752,18 +765,18 @@ void print_quant_stat(const char *n){
    ADM_assert( str );
    strcpy(str,n);
    strcat(str,".qs");
-   if( (fd=fopen(str,"wb")) ){
+   if( (fd=qfopen(str,"wb")) ){
       for(;i<32;i++){
-         fprintf(fd,"Quant % 2u: % 7u times\n",i,quantstat[i]);
+         qfprintf(fd,"Quant % 2u: % 7u times\n",i,quantstat[i]);
          sum+=i*quantstat[i];
          total+=quantstat[i];
       }
-      fprintf(fd,"\nQuant over all: %2.2f\n",(float)sum/(float)total);
-      fclose(fd);
+      qfprintf(fd,"\nQuant over all: %2.2f\n",(float)sum/(float)total);
+      qfclose(fd);
    }
    ADM_dealloc( str );
 }
-uint8_t  mpegWritter::dopass2(char *name,char *statname,uint32_t final_size,uint32_t bitrate,
+uint8_t  mpegWritter::dopass2(const char *name,char *statname,uint32_t final_size,uint32_t bitrate,
 				ADM_MPEGTYPE mpegtype,int matrix,uint8_t interlaced,
 					uint8_t bff,        // WLA
 					uint8_t widescreen)
@@ -775,17 +788,16 @@ AVDMGenericVideoStream	*incoming;
 FILE			*fd=NULL;
 uint64_t		total_size=0;
 uint32_t		len,flags,type,outquant,audiolen;
+uint32_t                sample_target=0;
+double                  sample_time;
+
+	memset(quantstat,0,32);
 
    	incoming = getLastVideoFilter (frameStart,frameEnd-frameStart);
 	if(!_audio)
 	{
-		fd=fopen(name,"wb");
-		if(!fd)
-		{
-			GUI_Alert("Problem opening file!");
+		if( !(fd=qfopen(name,"wb")) )
 			return 0;
-
-		}
 	}
 
 //	if(!init(name,mpegtype,interlaced,widescreen))
@@ -846,15 +858,20 @@ uint32_t		len,flags,type,outquant,audiolen;
 	encoding->setPhasis("2nd Pass");
 	if(_muxer)
 	{
-		encoding->setAudioCodec(getStrFromAudioCodec(_audio->getInfo()->encoding));	
+		encoding->setAudioCodec(getStrFromAudioCodec(_audio->getInfo()->encoding));
+                sample_time=_total;
+                sample_time*=1000;
+                sample_time/=_fps1000; // target_time in second
+                sample_time*=_audio->getInfo()->frequency;
+                sample_target=(uint32_t)floor(sample_time);
 	}
 	for(uint32_t i=0;i<_total;i++)
 	{
         	if(!incoming->getFrameNumberNoAlloc(i, &size,aImage,&flags))
 		{
-               		GUI_Alert("Encoding error !");
+               		GUI_Error_HIG("Encoding error", NULL);
 			if(!_audio)
-				fclose(fd);
+				qfclose(fd);
 			end();
 			return 0 ;
 		}
@@ -897,7 +914,7 @@ uint32_t		len,flags,type,outquant,audiolen;
 	
 		if(!_muxer)
 			{			
-				fwrite(_buffer_out,len,1,fd);
+				qfwrite(_buffer_out,len,1,fd);
 				fflush(fd);
 			}
 		else
@@ -915,7 +932,7 @@ uint32_t		len,flags,type,outquant,audiolen;
 		{
 			 print_quant_stat(name);
 			 end();
-			 fclose(fd);
+			 qfclose(fd);
 			 return 0;
 		}
 	}
@@ -946,7 +963,7 @@ uint32_t		len,flags,type,outquant,audiolen;
 		total_size+=len;
 		if(!_muxer)
 		{		
-			fwrite(_buffer_out,len,1,fd);
+			qfwrite(_buffer_out,len,1,fd);
 			fflush(fd);
 		}
 		else
@@ -964,7 +981,7 @@ uint32_t		len,flags,type,outquant,audiolen;
 	}
 //--			
 	if(!_muxer)	
-		fclose(fd);
+		qfclose(fd);
 	else
 	{
 		_muxer->close();
@@ -982,13 +999,13 @@ uint32_t		len,flags,type,outquant,audiolen;
 //	Construct mpeg2enc string parameter
 // ______________________________________________
 
-uint8_t mpegWritter::init(char *name,ADM_MPEGTYPE type,uint8_t interlaced,uint8_t bff,uint8_t widescreen) // WLA
+uint8_t mpegWritter::init(const char *name,ADM_MPEGTYPE type,uint8_t interlaced,uint8_t bff,uint8_t widescreen) // WLA
 {
 	UNUSED_ARG(name);
 	UNUSED_ARG(type);
        if(! 	identMovieType(_fps1000))
 	{
-               		GUI_Alert("Frame rate incompatible !");
+               		GUI_Error_HIG("Incompatible frame rate", NULL);
 			return 0;
 	}
 
@@ -1038,7 +1055,7 @@ int dummy_func_mpeg( int i )
 //
 //	Set up the audio chain for audio+video writting
 //
-uint8_t mpegWritter::initLveMux( char *name,ADM_MUXER_TYPE type )
+uint8_t mpegWritter::initLveMux(const char *name,ADM_MUXER_TYPE type )
 {
 double one_pcm_audio_frame;
 uint32_t fps1000;
@@ -1083,7 +1100,7 @@ uint32_t fps1000;
 AVDMGenericAudioStream *mpt_getAudioStream(void)
 {
 AVDMGenericAudioStream *audio=NULL;
-	if (audioProcessMode)	// else Raw copy mode
+	if (audioProcessMode())	// else Raw copy mode
 	{
 		if (currentaudiostream->isCompressed ())
 		{
@@ -1093,7 +1110,7 @@ AVDMGenericAudioStream *audio=NULL;
 			}
 		}
 	      	audio = buildAudioFilter (currentaudiostream,video_body->getTime (frameStart),
-				  (uint32_t) 0xffffffff);
+				  video_body->getTime (frameEnd-frameStart));
 	}
   	else // copymode
 	{
