@@ -49,20 +49,20 @@ class ADM_ogmWrite
 				
 				AVDMGenericAudioStream	*audioFilter;
 				
-			virtual uint8_t		initVideo(char *name);
+			virtual uint8_t		initVideo(const char *name);
 			virtual uint8_t		writeVideo(uint32_t frame);
 					
 	public:
 					ADM_ogmWrite(void);				
 					~ADM_ogmWrite(void);
-			uint8_t 	save(char *name);
+			uint8_t 	save(const char *name);
 };
 
 class ADM_ogmWriteCopy : public ADM_ogmWrite
 {
 protected:
 			
-			virtual uint8_t		initVideo(char *name);			
+			virtual uint8_t		initVideo(const char *name);			
 			virtual uint8_t		writeVideo(uint32_t frame);
 			uint32_t 		searchForward(uint32_t startframe);
 			uint32_t		_lastIPFrameSent;	
@@ -76,7 +76,7 @@ class ADM_ogmWriteProcess : public ADM_ogmWrite
 protected:
 			AVDMGenericVideoStream  *_incoming;
 			Encoder 		*_encode;
-			virtual uint8_t	initVideo(char *name);			
+			virtual uint8_t	initVideo(const char *name);			
 			virtual uint8_t	writeVideo(uint32_t frame);	
 public:
 			ADM_ogmWriteProcess(void);
