@@ -52,7 +52,7 @@
 #define aprintf printf
 
 //________________________________________________
-uint8_t	ADM_ogmWriteProcess::initVideo(char *name)
+uint8_t	ADM_ogmWriteProcess::initVideo(const char *name)
 {		
 uint32_t w,h,fps1000,fcc;
 		
@@ -72,7 +72,7 @@ uint32_t w,h,fps1000,fcc;
     	{
       		delete 	_encode;
       		_encode = NULL;
-      		GUI_Alert ("Init of filter failed");
+      		GUI_Error_HIG ("Filter init failed", NULL);
       		return 0;
     	};
  	w= _incoming->getInfo ()->width;
@@ -194,7 +194,11 @@ uint8_t	ADM_ogmWriteProcess::writeVideo(uint32_t frame)
 uint32_t len,flags;
 uint8_t ret;
 		 ret= _encode->encode ( frame, &len, _videoBuffer, &flags);
-		 if(!ret) return 0;
+		 if(!ret)
+                 {
+                        printf("OgmWrite: Error encoding frame %d\n",frame);
+                        return 0;
+                 }
 		 encoding_gui->feedFrame(len);
 		 encoding_gui->setQuant(_encode->getLastQz());		 
 		 return videoStream->write(len,_videoBuffer,flags,frame);
