@@ -4,9 +4,11 @@
 #include <strings.h>
 #include <unistd.h>	/* access(), R_OK */
 #include <errno.h>	/* errno, ENOENT */
+#include <dirent.h>
 
 #include "ADM_library/default.h"
 #include "ADM_toolkit/toolkit.hxx"
+#include "ADM_toolkit/ADM_quota.h"
 
 #include "config.h"
 
@@ -17,9 +19,11 @@
 #include <ADM_assert.h>
 
 #undef free
-
+extern char *getBaseDir(void);
+#define CONFIG "config"
 extern char *PathCanonize(const char *tmpname);
-
+extern int  qxmlSaveFormatFile(const char *filename, xmlDocPtr cur, int format);
+static char *checkDirAccess(char *home);
 // <prefs_gen>
 typedef enum {
 	UINT,
@@ -64,6 +68,7 @@ static opt_def opt_defs [] = {
 	{"codecs.xvid.quantizer",		UINT,	"4",	NULL,	"2",	"32"	},
 	{"codecs.xvid.bitrate",		UINT,	"1500000",NULL,	"17",	"5900000"},
 	{"codecs.xvid.finalsize",	UINT,	"700",	NULL,	"0",	"3999"	},
+	{"codecs.preferredcodec",		STRING,"FFmpeg4",NULL, NULL, NULL },
 	{"filters.subtitle.fontname",		STRING,"/usr/X11R6/lib/X11/fonts/truetype/arial.ttf",NULL, NULL, NULL },
 	{"filters.subtitle.charset",		STRING,"ISO-8859-1",NULL, NULL, NULL },
 	{"filters.subtitle.fontsize",		UINT,	"24",	NULL,	"1",	"576"	},
@@ -72,17 +77,12 @@ static opt_def opt_defs [] = {
 	{"filters.subtitle.vpercent",		INT,	"0",	NULL,	"0",	"255"	},
 	{"filters.subtitle.selfadjustable",		UINT,	"0",	NULL,	"0",	"1"	},
 	{"filters.subtitle.usebackgroundcolor",		UINT,	"0",	NULL,	"0",	"1"	},
-	{"test.string",		STRING,"abcdhfgd",NULL, NULL, NULL },
-	{"test.int",		INT,	"0",	NULL,	"-3",	"3"	},
-	{"test.uint",		UINT,	"1",	NULL,	"0",	"3"	},
-	{"test.long",		LONG,	"1",	NULL,	"-4",	"999999999999"},
-	{"test.ulong",		ULONG,	"2",	NULL,	"0",	"999999999999"},
-	{"test.float",	FLOAT,	"0.0",	NULL,	"-0.35","0.35"	},
 	{"settings.mpegsplit",	UINT,	"790",	NULL,	"400",	"5000"	},
-	{"codecs.preferredcodec",		STRING,"FFmpeg4",NULL, NULL, NULL },
 	{"device.audiodevice",	STRING,"OSS",	NULL, NULL, NULL },
 	{"device.audio.alsa_device",		STRING,"plughw:0,0",NULL, NULL, NULL },
 	{"device.videodevice",		UINT,	"0",	NULL,	"0",	"10"	},
+	{"default.postproc_type",		UINT,	"3",	NULL,	"0",	"7"	},
+	{"default.postproc_value",		UINT,	"3",	NULL,	"0",	"5"	},
 	{"lastfiles.file1",		STRING,"",	NULL, NULL, NULL },
 	{"lastfiles.file2",		STRING,"",	NULL, NULL, NULL },
 	{"lastfiles.file3",		STRING,"",	NULL, NULL, NULL },
@@ -96,6 +96,7 @@ static opt_def opt_defs [] = {
 	{"toolame_path",		STRING,"",	NULL, NULL, NULL },
 	{"lvemux_path",		STRING,"",	NULL, NULL, NULL },
 	{"requant_path",		STRING,"",	NULL, NULL, NULL },
+	{"message_level",		UINT,	"2",	NULL,	"0",	"2"	},
 	{"feature.swap_if_A_greater_than_B",		UINT,	"1",	NULL,	"0",	"1"	},
 	{"feature.svcdres.preferedsourceratio",		STRING,"1:1",	NULL, NULL, NULL },
 	{"feature.saveprefsonexit",		UINT,	"1",	NULL,	"0",	"1"	},
@@ -103,14 +104,16 @@ static opt_def opt_defs [] = {
 	{"feature.use_lavcodec_mpeg",		UINT,	"0",	NULL,	"0",	"1"	},
 	{"feature.disable_nuv_resync",		UINT,	"0",	NULL,	"0",	"1"	},
 	{"feature.tryautoidx",		UINT,	"0",	NULL,	"0",	"1"	},
-	{"feature.use_odml",		UINT,	"0",	NULL,	"0",	"1"	}
+	{"feature.use_odml",		UINT,	"0",	NULL,	"0",	"1"	},
+	{"feature.use_systray",		UINT,	"0",	NULL,	"0",	"1"	},
+	{"feature.reuse_2pass_log",		UINT,	"0",	NULL,	"0",	"1"	},
+	{"feature.audiobar_uses_master",		UINT,	"0",	NULL,	"0",	"1"	}
 };
 
 int num_opts = 64;
 // </prefs_gen>
 
 #ifdef USE_LIBXML2
-
 /*
 ** we cannot put this into the header file, cause libxml headers
 ** are not reachable in all directories/Makefiles
@@ -229,30 +232,36 @@ int preferences::load(){
 #else
 int preferences::load(){
    xmlNodePtr p;
-   char rcfile[1024];
+   char *rcfile;
    char *home;
+   char *dir_adm;
+   
    char buf[1024];
-#if defined(CYG_MANGLING)
-	home="c:/";
-#else
-	if( ! (home=getenv("HOME")) )
-	{
-		fprintf(stderr,"can't determine $HOME.\n");
-		return RC_FAILED;
-	}
-#endif
-	snprintf(rcfile, 1024, "%s/.avidemuxrc", home);
-	rcfile[1023] = '\0';
+   DIR   *dir;
+
+        dir_adm=getBaseDir();
+        if(!dir_adm) return RC_FAILED;
+
+        rcfile=new char[strlen(dir_adm)+4+strlen(CONFIG)];
+        strcpy(rcfile,dir_adm);
+        strcat(rcfile,"/");
+        strcat(rcfile,CONFIG);
+
+        
+        // Now build the filename
 	if( access(rcfile,R_OK) == -1 ){
 		if( errno != ENOENT )
 			fprintf(stderr,"can't read(%s): %d (%s)\n",
 				rcfile, errno, strerror(errno) );
+                delete [] rcfile;
 		return RC_FAILED;
 	}
 	if( !(xdoc = xmlParseFile(rcfile)) ){
 		fprintf(stderr,"can't parse \"rcfile\".\n");
+                delete [] rcfile;
 		return RC_FAILED;
 	}
+        delete [] rcfile;
 	erase_blank_nodes(xdoc->children);
 	p = xdoc->children; // ->avidemux
 	buf[0] = '\0';
@@ -368,51 +377,65 @@ int preferences::save(){
 }
 
 int preferences::save_xml_to_file(){
-   char *home;
-   char rcfile[1024];
-   char rcfilenew[1024];
+   char *dir_adm;
+   char *rcfile;
+   char *rcfilenew;
+
+        dir_adm=getBaseDir();
+        if(!dir_adm) return RC_FAILED;
+
+        rcfile=new char[strlen(dir_adm)+4+strlen(CONFIG)];
+        strcpy(rcfile,dir_adm);
+        strcat(rcfile,"/");
+        strcat(rcfile,CONFIG);
+
+
 #if defined(CYG_MANGLING)
-	home="c:/";
-	snprintf(rcfile,1024,"%s/.avidemuxrc",home);
-	rcfile[1023] = '\0';
 	xmlSetDocCompressMode(xdoc,9);
 	if( xmlSaveFormatFile(rcfile,xdoc,1) == -1 ){
            fprintf(stderr,"\ncan't save xml tree to file. Filesystem full?\n\n");
+           delete [] rcfile;
 	   return RC_FAILED;
 	}
+        delete [] rcfile;
 	return RC_OK;
 
 #else
-	if( !(home=getenv("HOME")) )
-	{
-		fprintf(stderr,"can't getenv(HOME).\n");
-		return RC_FAILED;
-	}
-	snprintf(rcfilenew,1024,"%s/.avidemuxrc.new",home);
-	rcfilenew[1023] = '\0';
+	
+        
+         rcfilenew=new char[strlen(rcfile)+5];
+        strcpy(rcfilenew,rcfile);
+        strcat(rcfilenew,".new");
         if( unlink(rcfilenew) == -1 && errno != ENOENT ){
            fprintf(stderr,"can't unlink(%s): %d (%s)\n",
                    rcfilenew, errno, strerror(errno));
+           delete [] rcfilenew;
            return RC_FAILED;
         }
 	xmlSetDocCompressMode(xdoc,9);
-	if( xmlSaveFormatFile(rcfilenew,xdoc,1) == -1 ){
-           fprintf(stderr,"\ncan't save xml tree to file. Filesystem full?\n\n");
+	if( qxmlSaveFormatFile(rcfilenew,xdoc,1) == -1 ){
+           delete [] rcfilenew;
+           delete [] rcfile;
 	   return RC_FAILED;
 	}
-	snprintf(rcfile,1024,"%s/.avidemuxrc",home);
-	rcfile[1023] = '\0';
+
         if( unlink(rcfile) == -1 && errno != ENOENT ){
            fprintf(stderr,"can't unlink(%s): %d (%s)\n",
                    rcfile, errno, strerror(errno));
+           delete [] rcfilenew;
+           delete [] rcfile;
            return RC_FAILED;
         }
         if( link(rcfilenew,rcfile) == -1 ){
            fprintf(stderr,"can't create \"%s\": %d (%s)\n",
                    rcfile, errno, strerror(errno));
+           delete [] rcfilenew;
+           delete [] rcfile;
            return RC_FAILED;
         }
         unlink(rcfilenew); // rc/errno handling is done on next call ;-)
+        delete [] rcfilenew;
+        delete [] rcfile;
 	return RC_OK;
 #endif
 }
@@ -888,4 +911,4 @@ const char **preferences::get_lastfiles(void){
 
 // the one and only global preferences object
 preferences *prefs = new preferences();
-
+// EOF
